#increase memory limit of R to 3000 MB
memory.limit(size = 4000)

#read in packages
library(rgdal)
library(sp)
library(SDMTools)
library(igraph)

#read in total historic wetlands shapefile, clipped to RWB Bounds
ContWetsAndPits <- readOGR("ContWetsAndPitsPntsGeographic.shp", "ContWetsAndPitsPntsGeographic", verbose = TRUE, p4s = NULL)
head(ContWetsAndPits@data)
ContWetsAndPits@data$ID <- 1:nrow(ContWetsAndPits@data)
ContWetsAndPits@data$ID <- factor(ContWetsAndPits@data$ID)
retain <- c("NodeID", "XCoord", "YCoord")
ContWetsAndPits@data <- ContWetsAndPits@data[retain]
head(ContWetsAndPits@data)

#generate combinations of wetland ids at 4 dispersal distances (0.5, 1, 1.5, 2 km)
#Part1
PathCombinations1 <- list(NA)
for(i in 1:1500){
	PathCombinations1[[i]] <- data.frame(FromNode = ContWetsAndPits@data[i,]$NodeID)
	PathCombinations1[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[i,]$NodeID
	PathCombinations1[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations1[[i]]$FromNodeXCoord <- ContWetsAndPits@data[i,]$XCoord
	PathCombinations1[[i]]$FromNodeYCoord <- ContWetsAndPits@data[i,]$YCoord
	PathCombinations1[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations1[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations1[[i]]$Repeat <- PathCombinations1[[i]]$FromNode != PathCombinations1[[i]]$ToNode
	PathCombinations1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$Repeat, ]
	PathCombinations1[[i]]$Distance <- distance(PathCombinations1[[i]]$FromNodeYCoord, PathCombinations1[[i]]$FromNodeXCoord, PathCombinations1[[i]]$ToNodeYCoord, PathCombinations1[[i]]$ToNodeXCoord)	
	PathCombinations1[[i]]$HalfKM <- PathCombinations1[[i]]$Distance$distance <= 500
	PathCombinations1[[i]]$OneKM <- PathCombinations1[[i]]$Distance$distance <= 1000
	PathCombinations1[[i]]$OneAndHalfKM <- PathCombinations1[[i]]$Distance$distance <= 1500
	PathCombinations1[[i]]$TwoKM <- PathCombinations1[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections1 <- list(NA)
OneKMConnections1 <- list(NA)
OneAndHalfKMConnections1 <- list(NA)
TwoKMConnections1 <- list(NA)
for(i in 1:1500){
	PathCombinations1[[i]] <- PathCombinations1[[i]][i:nrow(PathCombinations1[[i]]), ]
	HalfKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$HalfKM, ]
	OneKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$OneKM, ]
	OneAndHalfKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$OneAndHalfKM, ]
	TwoKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections1 <- HalfKMConnections1[sapply(HalfKMConnections1, function(x) dim(x)[1]) > 0]
OneKMConnections1 <- OneKMConnections1[sapply(OneKMConnections1, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections1 <- OneAndHalfKMConnections1[sapply(OneAndHalfKMConnections1, function(x) dim(x)[1]) > 0]
TwoKMConnections1 <- TwoKMConnections1[sapply(TwoKMConnections1, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(HalfKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(HalfKMConnections1[[i]]$FromNode, HalfKMConnections1[[i]]$ToNode),
	c(HalfKMConnections1[[i]]$FromNode, HalfKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
HalfKMPaths1 <- cbind(FromNodes1, ToNodes1)
HalfKMPaths1 <- unique(HalfKMPaths1, incomparables = FALSE)
class(HalfKMPaths1)
write.csv(HalfKMPaths1, "HalfKMPaths1.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(OneKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(OneKMConnections1[[i]]$FromNode, OneKMConnections1[[i]]$ToNode),
	c(OneKMConnections1[[i]]$FromNode, OneKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
OneKMPaths1 <- cbind(FromNodes1, ToNodes1)
OneKMPaths1 <- unique(OneKMPaths1, incomparables = FALSE)
class(OneKMPaths1)
write.csv(OneKMPaths1, "OneKMPaths1.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections1[[i]]$FromNode, OneAndHalfKMConnections1[[i]]$ToNode),
	c(OneAndHalfKMConnections1[[i]]$FromNode, OneAndHalfKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
OneAndHalfKMPaths1 <- cbind(FromNodes1, ToNodes1)
OneAndHalfKMPaths1 <- unique(OneAndHalfKMPaths1, incomparables = FALSE)
class(OneAndHalfKMPaths1)
write.csv(OneAndHalfKMPaths1, "OneAndHalfKMPaths1.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(TwoKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(TwoKMConnections1[[i]]$FromNode, TwoKMConnections1[[i]]$ToNode),
	c(TwoKMConnections1[[i]]$FromNode, TwoKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
TwoKMPaths1 <- cbind(FromNodes1, ToNodes1)
TwoKMPaths1 <- unique(TwoKMPaths1, incomparables = FALSE)
class(TwoKMPaths1)
write.csv(TwoKMPaths1, "TwoKMPaths1.csv")

#Part2
PathCombinations2 <- list(NA)
for(i in 1:1500){
	PathCombinations2[[i]] <- data.frame(FromNode = ContWetsAndPits@data[1500 + i,]$NodeID)
	PathCombinations2[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[1500 + i,]$NodeID
	PathCombinations2[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations2[[i]]$FromNodeXCoord <- ContWetsAndPits@data[1500 + i,]$XCoord
	PathCombinations2[[i]]$FromNodeYCoord <- ContWetsAndPits@data[1500 + i,]$YCoord
	PathCombinations2[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations2[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations2[[i]]$Repeat <- PathCombinations2[[i]]$FromNode != PathCombinations2[[i]]$ToNode
	PathCombinations2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$Repeat, ]
	PathCombinations2[[i]]$Distance <- distance(PathCombinations2[[i]]$FromNodeYCoord, PathCombinations2[[i]]$FromNodeXCoord, PathCombinations2[[i]]$ToNodeYCoord, PathCombinations2[[i]]$ToNodeXCoord)	
	PathCombinations2[[i]]$HalfKM <- PathCombinations2[[i]]$Distance$distance <= 500
	PathCombinations2[[i]]$OneKM <- PathCombinations2[[i]]$Distance$distance <= 1000
	PathCombinations2[[i]]$OneAndHalfKM <- PathCombinations2[[i]]$Distance$distance <= 1500
	PathCombinations2[[i]]$TwoKM <- PathCombinations2[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections2 <- list(NA)
OneKMConnections2 <- list(NA)
OneAndHalfKMConnections2 <- list(NA)
TwoKMConnections2 <- list(NA)
for(i in 1:1500){
	PathCombinations2[[i]] <- PathCombinations2[[i]][(1500 + i):nrow(PathCombinations2[[i]]), ]
	HalfKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$HalfKM, ]
	OneKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$OneKM, ]
	OneAndHalfKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$OneAndHalfKM, ]
	TwoKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections2 <- HalfKMConnections2[sapply(HalfKMConnections2, function(x) dim(x)[1]) > 0]
OneKMConnections2 <- OneKMConnections2[sapply(OneKMConnections2, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections2 <- OneAndHalfKMConnections2[sapply(OneAndHalfKMConnections2, function(x) dim(x)[1]) > 0]
TwoKMConnections2 <- TwoKMConnections2[sapply(TwoKMConnections2, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(HalfKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(HalfKMConnections2[[i]]$FromNode, HalfKMConnections2[[i]]$ToNode),
	c(HalfKMConnections2[[i]]$FromNode, HalfKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
HalfKMPaths2 <- cbind(FromNodes2, ToNodes2)
HalfKMPaths2 <- unique(HalfKMPaths2, incomparables = FALSE)
class(HalfKMPaths2)
write.csv(HalfKMPaths2, "HalfKMPaths2.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(OneKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(OneKMConnections2[[i]]$FromNode, OneKMConnections2[[i]]$ToNode),
	c(OneKMConnections2[[i]]$FromNode, OneKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
OneKMPaths2 <- cbind(FromNodes2, ToNodes2)
OneKMPaths2 <- unique(OneKMPaths2, incomparables = FALSE)
class(OneKMPaths2)
write.csv(OneKMPaths2, "OneKMPaths2.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections2[[i]]$FromNode, OneAndHalfKMConnections2[[i]]$ToNode),
	c(OneAndHalfKMConnections2[[i]]$FromNode, OneAndHalfKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
OneAndHalfKMPaths2 <- cbind(FromNodes2, ToNodes2)
OneAndHalfKMPaths2 <- unique(OneAndHalfKMPaths2, incomparables = FALSE)
class(OneAndHalfKMPaths2)
write.csv(OneAndHalfKMPaths2, "OneAndHalfKMPaths2.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(TwoKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(TwoKMConnections2[[i]]$FromNode, TwoKMConnections2[[i]]$ToNode),
	c(TwoKMConnections2[[i]]$FromNode, TwoKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
TwoKMPaths2 <- cbind(FromNodes2, ToNodes2)
TwoKMPaths2 <- unique(TwoKMPaths2, incomparables = FALSE)
class(TwoKMPaths2)
write.csv(TwoKMPaths2, "TwoKMPaths2.csv")

#Part3
PathCombinations3 <- list(NA)
for(i in 1:1500){
	PathCombinations3[[i]] <- data.frame(FromNode = ContWetsAndPits@data[3000 + i,]$NodeID)
	PathCombinations3[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[3000 + i,]$NodeID
	PathCombinations3[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations3[[i]]$FromNodeXCoord <- ContWetsAndPits@data[3000 + i,]$XCoord
	PathCombinations3[[i]]$FromNodeYCoord <- ContWetsAndPits@data[3000 + i,]$YCoord
	PathCombinations3[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations3[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations3[[i]]$Repeat <- PathCombinations3[[i]]$FromNode != PathCombinations3[[i]]$ToNode
	PathCombinations3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$Repeat, ]
	PathCombinations3[[i]]$Distance <- distance(PathCombinations3[[i]]$FromNodeYCoord, PathCombinations3[[i]]$FromNodeXCoord, PathCombinations3[[i]]$ToNodeYCoord, PathCombinations3[[i]]$ToNodeXCoord)	
	PathCombinations3[[i]]$HalfKM <- PathCombinations3[[i]]$Distance$distance <= 500
	PathCombinations3[[i]]$OneKM <- PathCombinations3[[i]]$Distance$distance <= 1000
	PathCombinations3[[i]]$OneAndHalfKM <- PathCombinations3[[i]]$Distance$distance <= 1500
	PathCombinations3[[i]]$TwoKM <- PathCombinations3[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections3 <- list(NA)
OneKMConnections3 <- list(NA)
OneAndHalfKMConnections3 <- list(NA)
TwoKMConnections3 <- list(NA)
for(i in 1:1500){
	PathCombinations3[[i]] <- PathCombinations3[[i]][(3000 + i):nrow(PathCombinations3[[i]]), ]
	HalfKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$HalfKM, ]
	OneKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$OneKM, ]
	OneAndHalfKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$OneAndHalfKM, ]
	TwoKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections3 <- HalfKMConnections3[sapply(HalfKMConnections3, function(x) dim(x)[1]) > 0]
OneKMConnections3 <- OneKMConnections3[sapply(OneKMConnections3, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections3 <- OneAndHalfKMConnections3[sapply(OneAndHalfKMConnections3, function(x) dim(x)[1]) > 0]
TwoKMConnections3 <- TwoKMConnections3[sapply(TwoKMConnections3, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(HalfKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(HalfKMConnections3[[i]]$FromNode, HalfKMConnections3[[i]]$ToNode),
	c(HalfKMConnections3[[i]]$FromNode, HalfKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
HalfKMPaths3 <- cbind(FromNodes3, ToNodes3)
HalfKMPaths3 <- unique(HalfKMPaths3, incomparables = FALSE)
class(HalfKMPaths3)
write.csv(HalfKMPaths3, "HalfKMPaths3.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(OneKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(OneKMConnections3[[i]]$FromNode, OneKMConnections3[[i]]$ToNode),
	c(OneKMConnections3[[i]]$FromNode, OneKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
OneKMPaths3 <- cbind(FromNodes3, ToNodes3)
OneKMPaths3 <- unique(OneKMPaths3, incomparables = FALSE)
class(OneKMPaths3)
write.csv(OneKMPaths3, "OneKMPaths3.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections3[[i]]$FromNode, OneAndHalfKMConnections3[[i]]$ToNode),
	c(OneAndHalfKMConnections3[[i]]$FromNode, OneAndHalfKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
OneAndHalfKMPaths3 <- cbind(FromNodes3, ToNodes3)
OneAndHalfKMPaths3 <- unique(OneAndHalfKMPaths3, incomparables = FALSE)
class(OneAndHalfKMPaths3)
write.csv(OneAndHalfKMPaths3, "OneAndHalfKMPaths3.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(TwoKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(TwoKMConnections3[[i]]$FromNode, TwoKMConnections3[[i]]$ToNode),
	c(TwoKMConnections3[[i]]$FromNode, TwoKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
TwoKMPaths3 <- cbind(FromNodes3, ToNodes3)
TwoKMPaths3 <- unique(TwoKMPaths3, incomparables = FALSE)
class(TwoKMPaths3)
write.csv(TwoKMPaths3, "TwoKMPaths3.csv")

#Part4
PathCombinations4 <- list(NA)
for(i in 1:1500){
	PathCombinations4[[i]] <- data.frame(FromNode = ContWetsAndPits@data[4500 + i,]$NodeID)
	PathCombinations4[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[4500 + i,]$NodeID
	PathCombinations4[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations4[[i]]$FromNodeXCoord <- ContWetsAndPits@data[4500 + i,]$XCoord
	PathCombinations4[[i]]$FromNodeYCoord <- ContWetsAndPits@data[4500 + i,]$YCoord
	PathCombinations4[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations4[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations4[[i]]$Repeat <- PathCombinations4[[i]]$FromNode != PathCombinations4[[i]]$ToNode
	PathCombinations4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$Repeat, ]
	PathCombinations4[[i]]$Distance <- distance(PathCombinations4[[i]]$FromNodeYCoord, PathCombinations4[[i]]$FromNodeXCoord, PathCombinations4[[i]]$ToNodeYCoord, PathCombinations4[[i]]$ToNodeXCoord)	
	PathCombinations4[[i]]$HalfKM <- PathCombinations4[[i]]$Distance$distance <= 500
	PathCombinations4[[i]]$OneKM <- PathCombinations4[[i]]$Distance$distance <= 1000
	PathCombinations4[[i]]$OneAndHalfKM <- PathCombinations4[[i]]$Distance$distance <= 1500
	PathCombinations4[[i]]$TwoKM <- PathCombinations4[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections4 <- list(NA)
OneKMConnections4 <- list(NA)
OneAndHalfKMConnections4 <- list(NA)
TwoKMConnections4 <- list(NA)
for(i in 1:1500){
	PathCombinations4[[i]] <- PathCombinations4[[i]][(4500 + i):nrow(PathCombinations4[[i]]), ]
	HalfKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$HalfKM, ]
	OneKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$OneKM, ]
	OneAndHalfKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$OneAndHalfKM, ]
	TwoKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections4 <- HalfKMConnections4[sapply(HalfKMConnections4, function(x) dim(x)[1]) > 0]
OneKMConnections4 <- OneKMConnections4[sapply(OneKMConnections4, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections4 <- OneAndHalfKMConnections4[sapply(OneAndHalfKMConnections4, function(x) dim(x)[1]) > 0]
TwoKMConnections4 <- TwoKMConnections4[sapply(TwoKMConnections4, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(HalfKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(HalfKMConnections4[[i]]$FromNode, HalfKMConnections4[[i]]$ToNode),
	c(HalfKMConnections4[[i]]$FromNode, HalfKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
HalfKMPaths4 <- cbind(FromNodes4, ToNodes4)
HalfKMPaths4 <- unique(HalfKMPaths4, incomparables = FALSE)
class(HalfKMPaths4)
write.csv(HalfKMPaths4, "HalfKMPaths4.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(OneKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(OneKMConnections4[[i]]$FromNode, OneKMConnections4[[i]]$ToNode),
	c(OneKMConnections4[[i]]$FromNode, OneKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
OneKMPaths4 <- cbind(FromNodes4, ToNodes4)
OneKMPaths4 <- unique(OneKMPaths4, incomparables = FALSE)
class(OneKMPaths4)
write.csv(OneKMPaths4, "OneKMPaths4.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections4[[i]]$FromNode, OneAndHalfKMConnections4[[i]]$ToNode),
	c(OneAndHalfKMConnections4[[i]]$FromNode, OneAndHalfKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
OneAndHalfKMPaths4 <- cbind(FromNodes4, ToNodes4)
OneAndHalfKMPaths4 <- unique(OneAndHalfKMPaths4, incomparables = FALSE)
class(OneAndHalfKMPaths4)
write.csv(OneAndHalfKMPaths4, "OneAndHalfKMPaths4.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(TwoKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(TwoKMConnections4[[i]]$FromNode, TwoKMConnections4[[i]]$ToNode),
	c(TwoKMConnections4[[i]]$FromNode, TwoKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
TwoKMPaths4 <- cbind(FromNodes4, ToNodes4)
TwoKMPaths4 <- unique(TwoKMPaths4, incomparables = FALSE)
class(TwoKMPaths4)
write.csv(TwoKMPaths4, "TwoKMPaths4.csv")

#Part5
PathCombinations5 <- list(NA)
for(i in 1:1500){
	PathCombinations5[[i]] <- data.frame(FromNode = ContWetsAndPits@data[6000 + i,]$NodeID)
	PathCombinations5[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[6000 + i,]$NodeID
	PathCombinations5[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations5[[i]]$FromNodeXCoord <- ContWetsAndPits@data[6000 + i,]$XCoord
	PathCombinations5[[i]]$FromNodeYCoord <- ContWetsAndPits@data[6000 + i,]$YCoord
	PathCombinations5[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations5[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations5[[i]]$Repeat <- PathCombinations5[[i]]$FromNode != PathCombinations5[[i]]$ToNode
	PathCombinations5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$Repeat, ]
	PathCombinations5[[i]]$Distance <- distance(PathCombinations5[[i]]$FromNodeYCoord, PathCombinations5[[i]]$FromNodeXCoord, PathCombinations5[[i]]$ToNodeYCoord, PathCombinations5[[i]]$ToNodeXCoord)	
	PathCombinations5[[i]]$HalfKM <- PathCombinations5[[i]]$Distance$distance <= 500
	PathCombinations5[[i]]$OneKM <- PathCombinations5[[i]]$Distance$distance <= 1000
	PathCombinations5[[i]]$OneAndHalfKM <- PathCombinations5[[i]]$Distance$distance <= 1500
	PathCombinations5[[i]]$TwoKM <- PathCombinations5[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections5 <- list(NA)
OneKMConnections5 <- list(NA)
OneAndHalfKMConnections5 <- list(NA)
TwoKMConnections5 <- list(NA)
for(i in 1:1500){
	PathCombinations5[[i]] <- PathCombinations5[[i]][(6000 + i):nrow(PathCombinations5[[i]]), ]
	HalfKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$HalfKM, ]
	OneKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$OneKM, ]
	OneAndHalfKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$OneAndHalfKM, ]
	TwoKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections5 <- HalfKMConnections5[sapply(HalfKMConnections5, function(x) dim(x)[1]) > 0]
OneKMConnections5 <- OneKMConnections5[sapply(OneKMConnections5, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections5 <- OneAndHalfKMConnections5[sapply(OneAndHalfKMConnections5, function(x) dim(x)[1]) > 0]
TwoKMConnections5 <- TwoKMConnections5[sapply(TwoKMConnections5, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(HalfKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(HalfKMConnections5[[i]]$FromNode, HalfKMConnections5[[i]]$ToNode),
	c(HalfKMConnections5[[i]]$FromNode, HalfKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
HalfKMPaths5 <- cbind(FromNodes5, ToNodes5)
HalfKMPaths5 <- unique(HalfKMPaths5, incomparables = FALSE)
class(HalfKMPaths5)
write.csv(HalfKMPaths5, "HalfKMPaths5.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(OneKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(OneKMConnections5[[i]]$FromNode, OneKMConnections5[[i]]$ToNode),
	c(OneKMConnections5[[i]]$FromNode, OneKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
OneKMPaths5 <- cbind(FromNodes5, ToNodes5)
OneKMPaths5 <- unique(OneKMPaths5, incomparables = FALSE)
class(OneKMPaths5)
write.csv(OneKMPaths5, "OneKMPaths5.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections5[[i]]$FromNode, OneAndHalfKMConnections5[[i]]$ToNode),
	c(OneAndHalfKMConnections5[[i]]$FromNode, OneAndHalfKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
OneAndHalfKMPaths5 <- cbind(FromNodes5, ToNodes5)
OneAndHalfKMPaths5 <- unique(OneAndHalfKMPaths5, incomparables = FALSE)
class(OneAndHalfKMPaths5)
write.csv(OneAndHalfKMPaths5, "OneAndHalfKMPaths5.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(TwoKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(TwoKMConnections5[[i]]$FromNode, TwoKMConnections5[[i]]$ToNode),
	c(TwoKMConnections5[[i]]$FromNode, TwoKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
TwoKMPaths5 <- cbind(FromNodes5, ToNodes5)
TwoKMPaths5 <- unique(TwoKMPaths5, incomparables = FALSE)
class(TwoKMPaths5)
write.csv(TwoKMPaths5, "TwoKMPaths5.csv")

#Part6
PathCombinations6 <- list(NA)
for(i in 1:1500){
	PathCombinations6[[i]] <- data.frame(FromNode = ContWetsAndPits@data[7500 + i,]$NodeID)
	PathCombinations6[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[7500 + i,]$NodeID
	PathCombinations6[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations6[[i]]$FromNodeXCoord <- ContWetsAndPits@data[7500 + i,]$XCoord
	PathCombinations6[[i]]$FromNodeYCoord <- ContWetsAndPits@data[7500 + i,]$YCoord
	PathCombinations6[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations6[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations6[[i]]$Repeat <- PathCombinations6[[i]]$FromNode != PathCombinations6[[i]]$ToNode
	PathCombinations6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$Repeat, ]
	PathCombinations6[[i]]$Distance <- distance(PathCombinations6[[i]]$FromNodeYCoord, PathCombinations6[[i]]$FromNodeXCoord, PathCombinations6[[i]]$ToNodeYCoord, PathCombinations6[[i]]$ToNodeXCoord)	
	PathCombinations6[[i]]$HalfKM <- PathCombinations6[[i]]$Distance$distance <= 500
	PathCombinations6[[i]]$OneKM <- PathCombinations6[[i]]$Distance$distance <= 1000
	PathCombinations6[[i]]$OneAndHalfKM <- PathCombinations6[[i]]$Distance$distance <= 1500
	PathCombinations6[[i]]$TwoKM <- PathCombinations6[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections6 <- list(NA)
OneKMConnections6 <- list(NA)
OneAndHalfKMConnections6 <- list(NA)
TwoKMConnections6 <- list(NA)
for(i in 1:1500){
	PathCombinations6[[i]] <- PathCombinations6[[i]][(7500 + i):nrow(PathCombinations6[[i]]), ]
	HalfKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$HalfKM, ]
	OneKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$OneKM, ]
	OneAndHalfKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$OneAndHalfKM, ]
	TwoKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections6 <- HalfKMConnections6[sapply(HalfKMConnections6, function(x) dim(x)[1]) > 0]
OneKMConnections6 <- OneKMConnections6[sapply(OneKMConnections6, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections6 <- OneAndHalfKMConnections6[sapply(OneAndHalfKMConnections6, function(x) dim(x)[1]) > 0]
TwoKMConnections6 <- TwoKMConnections6[sapply(TwoKMConnections6, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(HalfKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(HalfKMConnections6[[i]]$FromNode, HalfKMConnections6[[i]]$ToNode),
	c(HalfKMConnections6[[i]]$FromNode, HalfKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
HalfKMPaths6 <- cbind(FromNodes6, ToNodes6)
HalfKMPaths6 <- unique(HalfKMPaths6, incomparables = FALSE)
class(HalfKMPaths6)
write.csv(HalfKMPaths6, "HalfKMPaths6.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(OneKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(OneKMConnections6[[i]]$FromNode, OneKMConnections6[[i]]$ToNode),
	c(OneKMConnections6[[i]]$FromNode, OneKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
OneKMPaths6 <- cbind(FromNodes6, ToNodes6)
OneKMPaths6 <- unique(OneKMPaths6, incomparables = FALSE)
class(OneKMPaths6)
write.csv(OneKMPaths6, "OneKMPaths6.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections6[[i]]$FromNode, OneAndHalfKMConnections6[[i]]$ToNode),
	c(OneAndHalfKMConnections6[[i]]$FromNode, OneAndHalfKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
OneAndHalfKMPaths6 <- cbind(FromNodes6, ToNodes6)
OneAndHalfKMPaths6 <- unique(OneAndHalfKMPaths6, incomparables = FALSE)
class(OneAndHalfKMPaths6)
write.csv(OneAndHalfKMPaths6, "OneAndHalfKMPaths6.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(TwoKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(TwoKMConnections6[[i]]$FromNode, TwoKMConnections6[[i]]$ToNode),
	c(TwoKMConnections6[[i]]$FromNode, TwoKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
TwoKMPaths6 <- cbind(FromNodes6, ToNodes6)
TwoKMPaths6 <- unique(TwoKMPaths6, incomparables = FALSE)
class(TwoKMPaths6)
write.csv(TwoKMPaths6, "TwoKMPaths6.csv")

#Part7
PathCombinations7 <- list(NA)
for(i in 1:1161){
	PathCombinations7[[i]] <- data.frame(FromNode = ContWetsAndPits@data[9000 + i,]$NodeID)
	PathCombinations7[[i]][1:nrow(ContWetsAndPits@data),] <- ContWetsAndPits@data[9000 + i,]$NodeID
	PathCombinations7[[i]]$ToNode <- ContWetsAndPits@data$NodeID
	PathCombinations7[[i]]$FromNodeXCoord <- ContWetsAndPits@data[9000 + i,]$XCoord
	PathCombinations7[[i]]$FromNodeYCoord <- ContWetsAndPits@data[9000 + i,]$YCoord
	PathCombinations7[[i]]$ToNodeXCoord <- ContWetsAndPits@data$XCoord
	PathCombinations7[[i]]$ToNodeYCoord <- ContWetsAndPits@data$YCoord
	PathCombinations7[[i]]$Repeat <- PathCombinations7[[i]]$FromNode != PathCombinations7[[i]]$ToNode
	PathCombinations7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$Repeat, ]
	PathCombinations7[[i]]$Distance <- distance(PathCombinations7[[i]]$FromNodeYCoord, PathCombinations7[[i]]$FromNodeXCoord, PathCombinations7[[i]]$ToNodeYCoord, PathCombinations7[[i]]$ToNodeXCoord)	
	PathCombinations7[[i]]$HalfKM <- PathCombinations7[[i]]$Distance$distance <= 500
	PathCombinations7[[i]]$OneKM <- PathCombinations7[[i]]$Distance$distance <= 1000
	PathCombinations7[[i]]$OneAndHalfKM <- PathCombinations7[[i]]$Distance$distance <= 1500
	PathCombinations7[[i]]$TwoKM <- PathCombinations7[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections7 <- list(NA)
OneKMConnections7 <- list(NA)
OneAndHalfKMConnections7 <- list(NA)
TwoKMConnections7 <- list(NA)
for(i in 1:1161){
	PathCombinations7[[i]] <- PathCombinations7[[i]][(9000 + i):nrow(PathCombinations7[[i]]), ]
	HalfKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$HalfKM, ]
	OneKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$OneKM, ]
	OneAndHalfKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$OneAndHalfKM, ]
	TwoKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections7 <- HalfKMConnections7[sapply(HalfKMConnections7, function(x) dim(x)[1]) > 0]
OneKMConnections7 <- OneKMConnections7[sapply(OneKMConnections7, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections7 <- OneAndHalfKMConnections7[sapply(OneAndHalfKMConnections7, function(x) dim(x)[1]) > 0]
TwoKMConnections7 <- TwoKMConnections7[sapply(TwoKMConnections7, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(HalfKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(HalfKMConnections7[[i]]$FromNode, HalfKMConnections7[[i]]$ToNode),
	c(HalfKMConnections7[[i]]$FromNode, HalfKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
HalfKMPaths7 <- cbind(FromNodes7, ToNodes7)
HalfKMPaths7 <- unique(HalfKMPaths7, incomparables = FALSE)
class(HalfKMPaths7)
write.csv(HalfKMPaths7, "HalfKMPaths7.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(OneKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(OneKMConnections7[[i]]$FromNode, OneKMConnections7[[i]]$ToNode),
	c(OneKMConnections7[[i]]$FromNode, OneKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
OneKMPaths7 <- cbind(FromNodes7, ToNodes7)
OneKMPaths7 <- unique(OneKMPaths7, incomparables = FALSE)
class(OneKMPaths7)
write.csv(OneKMPaths7, "OneKMPaths7.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections7[[i]]$FromNode, OneAndHalfKMConnections7[[i]]$ToNode),
	c(OneAndHalfKMConnections7[[i]]$FromNode, OneAndHalfKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
OneAndHalfKMPaths7 <- cbind(FromNodes7, ToNodes7)
OneAndHalfKMPaths7 <- unique(OneAndHalfKMPaths7, incomparables = FALSE)
class(OneAndHalfKMPaths7)
write.csv(OneAndHalfKMPaths7, "OneAndHalfKMPaths7.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(TwoKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(TwoKMConnections7[[i]]$FromNode, TwoKMConnections7[[i]]$ToNode),
	c(TwoKMConnections7[[i]]$FromNode, TwoKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
TwoKMPaths7 <- cbind(FromNodes7, ToNodes7)
TwoKMPaths7 <- unique(TwoKMPaths7, incomparables = FALSE)
class(TwoKMPaths7)
write.csv(TwoKMPaths7, "TwoKMPaths7.csv")