#increase memory limit of R to 3000 MB
memory.limit(size = 3000)

#read in packages
library(rgdal)
library(sp)
library(SDMTools)
library(igraph)

#read in contemporary wetlands shapefile, clipped to RWB Bounds
ContWets <- readOGR("ContWetsPntsGeographic.shp", "ContWetsPntsGeographic", verbose = TRUE, p4s = NULL)
head(ContWets@data)

#generate combinations of wetland ids at 4 dispersal distances (0.5, 1, 1.5, 2 km)
PathCombinations <- list(NA)
for(i in 1:nrow(ContWets@data)){
	PathCombinations[[i]] <- data.frame(FromNode = ContWets@data[i,]$FP_ID)
	PathCombinations[[i]][1:1856,] <- ContWets@data[i,]$FP_ID
	PathCombinations[[i]]$ToNode <- ContWets@data$FP_ID
	PathCombinations[[i]]$FromNodeXCoord <- ContWets@data[i,]$XCoord
	PathCombinations[[i]]$FromNodeYCoord <- ContWets@data[i,]$YCoord
	PathCombinations[[i]]$ToNodeXCoord <- ContWets@data$XCoord
	PathCombinations[[i]]$ToNodeYCoord <- ContWets@data$YCoord
	PathCombinations[[i]]$Repeat <- PathCombinations[[i]]$FromNode != PathCombinations[[i]]$ToNode
	PathCombinations[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$Repeat, ]
	PathCombinations[[i]]$Distance <- distance(PathCombinations[[i]]$FromNodeYCoord, PathCombinations[[i]]$FromNodeXCoord, PathCombinations[[i]]$ToNodeYCoord, PathCombinations[[i]]$ToNodeXCoord)	
	PathCombinations[[i]]$HalfKM <- PathCombinations[[i]]$Distance$distance <= 500
	PathCombinations[[i]]$OneKM <- PathCombinations[[i]]$Distance$distance <= 1000
	PathCombinations[[i]]$OneAndHalfKM <- PathCombinations[[i]]$Distance$distance <= 1500
	PathCombinations[[i]]$TwoKM <- PathCombinations[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections <- list(NA)
OneKMConnections <- list(NA)
OneAndHalfKMConnections <- list(NA)
TwoKMConnections <- list(NA)
for(i in 1:nrow(PathCombinations[[1]])){
	PathCombinations[[i]] <- PathCombinations[[i]][i:nrow(PathCombinations[[i]]), ]
	HalfKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$HalfKM, ]
	OneKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$OneKM, ]
	OneAndHalfKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$OneAndHalfKM, ]
	TwoKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections <- HalfKMConnections[sapply(HalfKMConnections, function(x) dim(x)[1]) > 0]
OneKMConnections <- OneKMConnections[sapply(OneKMConnections, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections <- OneAndHalfKMConnections[sapply(OneAndHalfKMConnections, function(x) dim(x)[1]) > 0]
TwoKMConnections <- TwoKMConnections[sapply(TwoKMConnections, function(x) dim(x)[1]) > 0]

#Create paths between points
#####
#####
#####
#0.5 KM
#obtain matrices of point-point combinations for contructing lines
CoordCombos <- list(NA)
ToNodeCoords <- list(NA)
FromNodeCoords <- list(NA)
for(i in 1:length(HalfKMConnections)){
	CoordCombos[[i]] <- as.matrix(cbind(c(HalfKMConnections[[i]]$FromNodeXCoord, HalfKMConnections[[i]]$ToNodeXCoord),
	c(HalfKMConnections[[i]]$FromNodeYCoord, HalfKMConnections[[i]]$ToNodeYCoord)))
	j1 <- nrow(CoordCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(CoordCombos[[i]])
	ToNodeCoords[[i]] <- CoordCombos[[i]][j2:j3, ]
	FromNodeCoords[[i]] <- data.frame(rbind(CoordCombos[[i]][j1, ]))
	FromNodeCoords[[i]][1:j1, ] <- FromNodeCoords[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNodeCoords))
XCoords <- subset(FromNodes, unlist.FromNodeCoords. < 0)
YCoords <- subset(FromNodes, unlist.FromNodeCoords. > 0)
FromNodes <- data.frame(XCoords, YCoords)
FromNodes$XCoord <- FromNodes[,1]
FromNodes$YCoord <- FromNodes[,2]
retain <- c("XCoord", "YCoord")
FromNodes <- FromNodes[retain]
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNodeCoords))
XCoords <- subset(ToNodes, unlist.ToNodeCoords. < 0)
YCoords <- subset(ToNodes, unlist.ToNodeCoords. > 0)
ToNodes <- data.frame(XCoords, YCoords)
ToNodes$XCoord <- ToNodes[,1]
ToNodes$YCoord <- ToNodes[,2]
ToNodes <- ToNodes[retain]
ToNodes <- as.matrix(ToNodes)

#bring nodes together as lines
HalfKMCoords <- list(NA)
HalfKMPaths <- list(NA)
for(i in 1:nrow(ToNodes)){
	HalfKMCoords[[i]] <- as.matrix(rbind(FromNodes[i, ], ToNodes[i, ]))
	HalfKMPaths[[i]] <- Line(HalfKMCoords[[i]])
	HalfKMPaths[[i]] <- Lines(HalfKMPaths[[i]], ID = i)
}

#Convert lines to spatial lines object
HalfKMPathsSpatial <- SpatialLines(HalfKMPaths, proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"))

#Convert spatial lines oject to spatial lines data frame
Numbers <- c(1:length(HalfKMPathsSpatial))
DataFrameHalfKM <- data.frame(Numbers)
HalfKMPathsFinal <- SpatialLinesDataFrame(HalfKMPathsSpatial, DataFrameHalfKM)

#add coordinates to the attribute table of dispersal paths
HalfKMPathsFinal@data$FromNodeXCoord <- NA
HalfKMPathsFinal@data$FromNodeYCoord <- NA
HalfKMPathsFinal@data$ToNodeXCoord <- NA
HalfKMPathsFinal@data$ToNodeYCoord <- NA
for(i in 1:nrow(HalfKMPathsFinal@data)){
	HalfKMPathsFinal@data[i, ]$FromNodeXCoord <- FromNodes[i,1]
	HalfKMPathsFinal@data[i, ]$FromNodeYCoord <- FromNodes[i,2]
	HalfKMPathsFinal@data[i, ]$ToNodeXCoord <- ToNodes[i,1]
	HalfKMPathsFinal@data[i, ]$ToNodeYCoord <- ToNodes[i,2]
}

#find number of overlaps between contemporary coordinates and dispersal paths
ConnectionsHalfKM <- list(NA)
ContWets@data$PathConnectionsHalfKM <- NA
for(i in 1:nrow(ContWets@data)){
	ConnectionsHalfKM[[i]] <- ContWets@data[i,]$XCoord == HalfKMPathsFinal@data$FromNodeXCoord & ContWets@data[i,]$YCoord == HalfKMPathsFinal@data$FromNodeYCoord
	ConnectionsHalfKM[[i]] <- ConnectionsHalfKM[[i]][-which(ConnectionsHalfKM[[i]] == 'FALSE')]
	ContWets@data[i,]$PathConnectionsHalfKM <- length(ConnectionsHalfKM[[i]])
}

TotalConnectionsHalfKM <- sum(ContWets@data$PathConnectionsHalfKM)
TotalConnectionsHalfKM
MeanConnectionsHalfKM <- mean(ContWets@data$PathConnectionsHalfKM)
MeanConnectionsHalfKM

#write to an ESRI shapefile
writeOGR(HalfKMPathsFinal, "ContPathsHalfKM", "ContPathsHalfKM", driver = 'ESRI Shapefile', verbose = TRUE)
Test1 <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/base/ContPathsHalfKM/ContPathsHalfKM.shp", "ContPathsHalfKM", verbose = TRUE, p4s = NULL)
plot(Test1)

#####
#####
#####
#1 KM
#obtain matrices of point-point combinations for contructing lines
CoordCombos <- list(NA)
ToNodeCoords <- list(NA)
FromNodeCoords <- list(NA)
for(i in 1:length(OneKMConnections)){
	CoordCombos[[i]] <- as.matrix(cbind(c(OneKMConnections[[i]]$FromNodeXCoord, OneKMConnections[[i]]$ToNodeXCoord),
	c(OneKMConnections[[i]]$FromNodeYCoord, OneKMConnections[[i]]$ToNodeYCoord)))
	j1 <- nrow(CoordCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(CoordCombos[[i]])
	ToNodeCoords[[i]] <- CoordCombos[[i]][j2:j3, ]
	FromNodeCoords[[i]] <- data.frame(rbind(CoordCombos[[i]][j1, ]))
	FromNodeCoords[[i]][1:j1, ] <- FromNodeCoords[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNodeCoords))
XCoords <- subset(FromNodes, unlist.FromNodeCoords. < 0)
YCoords <- subset(FromNodes, unlist.FromNodeCoords. > 0)
FromNodes <- data.frame(XCoords, YCoords)
FromNodes$XCoord <- FromNodes[,1]
FromNodes$YCoord <- FromNodes[,2]
retain <- c("XCoord", "YCoord")
FromNodes <- FromNodes[retain]
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNodeCoords))
XCoords <- subset(ToNodes, unlist.ToNodeCoords. < 0)
YCoords <- subset(ToNodes, unlist.ToNodeCoords. > 0)
ToNodes <- data.frame(XCoords, YCoords)
ToNodes$XCoord <- ToNodes[,1]
ToNodes$YCoord <- ToNodes[,2]
ToNodes <- ToNodes[retain]
ToNodes <- as.matrix(ToNodes)

#bring nodes together as lines
OneKMCoords <- list(NA)
OneKMPaths <- list(NA)
for(i in 1:nrow(ToNodes)){
	OneKMCoords[[i]] <- as.matrix(rbind(FromNodes[i, ], ToNodes[i, ]))
	OneKMPaths[[i]] <- Line(OneKMCoords[[i]])
	OneKMPaths[[i]] <- Lines(OneKMPaths[[i]], ID = i)
}

#Convert lines to spatial lines object
OneKMPathsSpatial <- SpatialLines(OneKMPaths, proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"))

#Convert spatial lines oject to spatial lines data frame
Numbers <- c(1:length(OneKMPathsSpatial))
DataFrameOneKM <- data.frame(Numbers)
OneKMPathsFinal <- SpatialLinesDataFrame(OneKMPathsSpatial, DataFrameOneKM)

#add coordinates to the attribute table of dispersal paths
OneKMPathsFinal@data$FromNodeXCoord <- NA
OneKMPathsFinal@data$FromNodeYCoord <- NA
OneKMPathsFinal@data$ToNodeXCoord <- NA
OneKMPathsFinal@data$ToNodeYCoord <- NA
for(i in 1:nrow(OneKMPathsFinal@data)){
	OneKMPathsFinal@data[i, ]$FromNodeXCoord <- FromNodes[i,1]
	OneKMPathsFinal@data[i, ]$FromNodeYCoord <- FromNodes[i,2]
	OneKMPathsFinal@data[i, ]$ToNodeXCoord <- ToNodes[i,1]
	OneKMPathsFinal@data[i, ]$ToNodeYCoord <- ToNodes[i,2]
}

#find number of overlaps between contemporary coordinates and dispersal paths
ConnectionsOneKM <- list(NA)
ContWets@data$PathConnectionsOneKM <- NA
for(i in 1:nrow(ContWets@data)){
	ConnectionsOneKM[[i]] <- ContWets@data[i,]$XCoord == OneKMPathsFinal@data$FromNodeXCoord & ContWets@data[i,]$YCoord == OneKMPathsFinal@data$FromNodeYCoord
	ConnectionsOneKM[[i]] <- ConnectionsOneKM[[i]][-which(ConnectionsOneKM[[i]] == 'FALSE')]
	ContWets@data[i,]$PathConnectionsOneKM <- length(ConnectionsOneKM[[i]])
}

TotalConnectionsOneKM <- sum(ContWets@data$PathConnectionsOneKM)
TotalConnectionsOneKM
MeanConnectionsOneKM <- mean(ContWets@data$PathConnectionsOneKM)
MeanConnectionsOneKM

#write to an ESRI shapefile
writeOGR(OneKMPathsFinal, "ContPathsOneKM", "ContPathsOneKM", driver = 'ESRI Shapefile', verbose = TRUE)
Test2 <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/base/ContPathsOneKM/ContPathsOneKM.shp", "ContPathsOneKM", verbose = TRUE, p4s = NULL)
plot(Test2)

#####
#####
#####
#1.5 KM
#obtain matrices of point-point combinations for contructing lines
CoordCombos <- list(NA)
ToNodeCoords <- list(NA)
FromNodeCoords <- list(NA)
for(i in 1:length(OneAndHalfKMConnections)){
	CoordCombos[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections[[i]]$FromNodeXCoord, OneAndHalfKMConnections[[i]]$ToNodeXCoord),
	c(OneAndHalfKMConnections[[i]]$FromNodeYCoord, OneAndHalfKMConnections[[i]]$ToNodeYCoord)))
	j1 <- nrow(CoordCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(CoordCombos[[i]])
	ToNodeCoords[[i]] <- CoordCombos[[i]][j2:j3, ]
	FromNodeCoords[[i]] <- data.frame(rbind(CoordCombos[[i]][j1, ]))
	FromNodeCoords[[i]][1:j1, ] <- FromNodeCoords[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNodeCoords))
XCoords <- subset(FromNodes, unlist.FromNodeCoords. < 0)
YCoords <- subset(FromNodes, unlist.FromNodeCoords. > 0)
FromNodes <- data.frame(XCoords, YCoords)
FromNodes$XCoord <- FromNodes[,1]
FromNodes$YCoord <- FromNodes[,2]
retain <- c("XCoord", "YCoord")
FromNodes <- FromNodes[retain]
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNodeCoords))
XCoords <- subset(ToNodes, unlist.ToNodeCoords. < 0)
YCoords <- subset(ToNodes, unlist.ToNodeCoords. > 0)
ToNodes <- data.frame(XCoords, YCoords)
ToNodes$XCoord <- ToNodes[,1]
ToNodes$YCoord <- ToNodes[,2]
ToNodes <- ToNodes[retain]
ToNodes <- as.matrix(ToNodes)

#bring nodes together as lines
OneAndHalfKMCoords <- list(NA)
OneAndHalfKMPaths <- list(NA)
for(i in 1:nrow(ToNodes)){
	OneAndHalfKMCoords[[i]] <- as.matrix(rbind(FromNodes[i, ], ToNodes[i, ]))
	OneAndHalfKMPaths[[i]] <- Line(OneAndHalfKMCoords[[i]])
	OneAndHalfKMPaths[[i]] <- Lines(OneAndHalfKMPaths[[i]], ID = i)
}

#Convert lines to spatial lines object
OneAndHalfKMPathsSpatial <- SpatialLines(OneAndHalfKMPaths, proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"))

#Convert spatial lines oject to spatial lines data frame
Numbers <- c(1:length(OneAndHalfKMPathsSpatial))
DataFrameOneAndHalfKM <- data.frame(Numbers)
OneAndHalfKMPathsFinal <- SpatialLinesDataFrame(OneAndHalfKMPathsSpatial, DataFrameOneAndHalfKM)

#add coordinates to the attribute table of dispersal paths
OneAndHalfKMPathsFinal@data$FromNodeXCoord <- NA
OneAndHalfKMPathsFinal@data$FromNodeYCoord <- NA
OneAndHalfKMPathsFinal@data$ToNodeXCoord <- NA
OneAndHalfKMPathsFinal@data$ToNodeYCoord <- NA
for(i in 1:nrow(OneAndHalfKMPathsFinal@data)){
	OneAndHalfKMPathsFinal@data[i, ]$FromNodeXCoord <- FromNodes[i,1]
	OneAndHalfKMPathsFinal@data[i, ]$FromNodeYCoord <- FromNodes[i,2]
	OneAndHalfKMPathsFinal@data[i, ]$ToNodeXCoord <- ToNodes[i,1]
	OneAndHalfKMPathsFinal@data[i, ]$ToNodeYCoord <- ToNodes[i,2]
}

#find number of overlaps between contemporary coordinates and dispersal paths
ConnectionsOneAndHalfKM <- list(NA)
ContWets@data$PathConnectionsOneAndHalfKM <- NA
for(i in 1:nrow(ContWets@data)){
	ConnectionsOneAndHalfKM[[i]] <- ContWets@data[i,]$XCoord == OneAndHalfKMPathsFinal@data$FromNodeXCoord & ContWets@data[i,]$YCoord == OneAndHalfKMPathsFinal@data$FromNodeYCoord
	ConnectionsOneAndHalfKM[[i]] <- ConnectionsOneAndHalfKM[[i]][-which(ConnectionsOneAndHalfKM[[i]] == 'FALSE')]
	ContWets@data[i,]$PathConnectionsOneAndHalfKM <- length(ConnectionsOneAndHalfKM[[i]])
}

TotalConnectionsOneAndHalfKM <- sum(ContWets@data$PathConnectionsOneAndHalfKM)
TotalConnectionsOneAndHalfKM
MeanConnectionsOneAndHalfKM <- mean(ContWets@data$PathConnectionsOneAndHalfKM)
MeanConnectionsOneAndHalfKM

#write to an ESRI shapefile
writeOGR(OneAndHalfKMPathsFinal, "ContPathsOneAndHalfKM", "ContPathsOneAndHalfKM", driver = 'ESRI Shapefile', verbose = TRUE)
Test3 <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/base/ContPathsOneAndHalfKM/ContPathsOneAndHalfKM.shp", "ContPathsOneAndHalfKM", verbose = TRUE, p4s = NULL)
plot(Test3)

#####
#####
#####
#2 KM
#obtain matrices of point-point combinations for contructing lines
CoordCombos <- list(NA)
ToNodeCoords <- list(NA)
FromNodeCoords <- list(NA)
for(i in 1:length(TwoKMConnections)){
	CoordCombos[[i]] <- as.matrix(cbind(c(TwoKMConnections[[i]]$FromNodeXCoord, TwoKMConnections[[i]]$ToNodeXCoord),
	c(TwoKMConnections[[i]]$FromNodeYCoord, TwoKMConnections[[i]]$ToNodeYCoord)))
	j1 <- nrow(CoordCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(CoordCombos[[i]])
	ToNodeCoords[[i]] <- CoordCombos[[i]][j2:j3, ]
	FromNodeCoords[[i]] <- data.frame(rbind(CoordCombos[[i]][j1, ]))
	FromNodeCoords[[i]][1:j1, ] <- FromNodeCoords[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNodeCoords))
XCoords <- subset(FromNodes, unlist.FromNodeCoords. < 0)
YCoords <- subset(FromNodes, unlist.FromNodeCoords. > 0)
FromNodes <- data.frame(XCoords, YCoords)
FromNodes$XCoord <- FromNodes[,1]
FromNodes$YCoord <- FromNodes[,2]
retain <- c("XCoord", "YCoord")
FromNodes <- FromNodes[retain]
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNodeCoords))
XCoords <- subset(ToNodes, unlist.ToNodeCoords. < 0)
YCoords <- subset(ToNodes, unlist.ToNodeCoords. > 0)
ToNodes <- data.frame(XCoords, YCoords)
ToNodes$XCoord <- ToNodes[,1]
ToNodes$YCoord <- ToNodes[,2]
ToNodes <- ToNodes[retain]
ToNodes <- as.matrix(ToNodes)

#bring nodes together as lines
TwoKMCoords <- list(NA)
TwoKMPaths <- list(NA)
for(i in 1:nrow(ToNodes)){
	TwoKMCoords[[i]] <- as.matrix(rbind(FromNodes[i, ], ToNodes[i, ]))
	TwoKMPaths[[i]] <- Line(TwoKMCoords[[i]])
	TwoKMPaths[[i]] <- Lines(TwoKMPaths[[i]], ID = i)
}


#Convert lines to spatial lines object
TwoKMPathsSpatial <- SpatialLines(TwoKMPaths, proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"))

#Convert spatial lines oject to spatial lines data frame
Numbers <- c(1:length(TwoKMPathsSpatial))
DataFrameTwoKM <- data.frame(Numbers)
TwoKMPathsFinal <- SpatialLinesDataFrame(TwoKMPathsSpatial, DataFrameTwoKM)

#add coordinates to the attribute table of dispersal paths
TwoKMPathsFinal@data$FromNodeXCoord <- NA
TwoKMPathsFinal@data$FromNodeYCoord <- NA
TwoKMPathsFinal@data$ToNodeXCoord <- NA
TwoKMPathsFinal@data$ToNodeYCoord <- NA
for(i in 1:nrow(TwoKMPathsFinal@data)){
	TwoKMPathsFinal@data[i, ]$FromNodeXCoord <- FromNodes[i,1]
	TwoKMPathsFinal@data[i, ]$FromNodeYCoord <- FromNodes[i,2]
	TwoKMPathsFinal@data[i, ]$ToNodeXCoord <- ToNodes[i,1]
	TwoKMPathsFinal@data[i, ]$ToNodeYCoord <- ToNodes[i,2]
}

#find number of overlaps between contemporary coordinates and dispersal paths
ConnectionsTwoKM <- list(NA)
ContWets@data$PathConnectionsTwoKM <- NA
for(i in 1:nrow(ContWets@data)){
	ConnectionsTwoKM[[i]] <- ContWets@data[i,]$XCoord == TwoKMPathsFinal@data$FromNodeXCoord & ContWets@data[i,]$YCoord == TwoKMPathsFinal@data$FromNodeYCoord
	ConnectionsTwoKM[[i]] <- ConnectionsTwoKM[[i]][-which(ConnectionsTwoKM[[i]] == 'FALSE')]
	ContWets@data[i,]$PathConnectionsTwoKM <- length(ConnectionsTwoKM[[i]])
}

TotalConnectionsTwoKM <- sum(ContWets@data$PathConnectionsTwoKM)
TotalConnectionsTwoKM
MeanConnectionsTwoKM <- mean(ContWets@data$PathConnectionsTwoKM)
MeanConnectionsTwoKM

#write to an ESRI shapefile
writeOGR(TwoKMPathsFinal, "ContPathsTwoKM", "ContPathsTwoKM", driver = 'ESRI Shapefile', verbose = TRUE)
Test4 <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/base/ContPathsTwoKM/ContPathsTwoKM.shp", "ContPathsTwoKM", verbose = TRUE, p4s = NULL)
plot(Test4)

		
