#increase memory limit of R to 3000 MB
memory.limit(size = 3000)

#read in packages
library(rgdal)
library(sp)
library(SDMTools)
library(igraph)

#read in contemporary wetlands shapefile, clipped to RWB Bounds
ContWets <- readOGR("ContWetsPntsGeographic.shp", "ContWetsPntsGeographic", verbose = TRUE, p4s = NULL)
head(ContWets@data)

#prepare nodes
ContWets@data$NodeID <- ContWets@data$ORIG_FID + 1
retain <- c("FP_ID", "XCoord", "YCoord", "NodeID")
ContWets@data <- ContWets@data[retain]
head(ContWets@data)

#generate combinations of wetland ids at 4 dispersal distances (0.5, 1, 1.5, 2 km)
PathCombinations <- list(NA)
for(i in 1:nrow(ContWets@data)){
	PathCombinations[[i]] <- data.frame(FromNode = ContWets@data[i,]$NodeID)
	PathCombinations[[i]][1:1856,] <- ContWets@data[i,]$NodeID
	PathCombinations[[i]]$ToNode <- ContWets@data$NodeID
	PathCombinations[[i]]$FromNodeXCoord <- ContWets@data[i,]$XCoord
	PathCombinations[[i]]$FromNodeYCoord <- ContWets@data[i,]$YCoord
	PathCombinations[[i]]$ToNodeXCoord <- ContWets@data$XCoord
	PathCombinations[[i]]$ToNodeYCoord <- ContWets@data$YCoord
	PathCombinations[[i]]$Repeat <- PathCombinations[[i]]$FromNode != PathCombinations[[i]]$ToNode
	PathCombinations[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$Repeat, ]
	PathCombinations[[i]]$Distance <- distance(PathCombinations[[i]]$FromNodeYCoord, PathCombinations[[i]]$FromNodeXCoord, PathCombinations[[i]]$ToNodeYCoord, PathCombinations[[i]]$ToNodeXCoord)	
	PathCombinations[[i]]$HalfKM <- PathCombinations[[i]]$Distance$distance <= 500
	PathCombinations[[i]]$OneKM <- PathCombinations[[i]]$Distance$distance <= 1000
	PathCombinations[[i]]$OneAndHalfKM <- PathCombinations[[i]]$Distance$distance <= 1500
	PathCombinations[[i]]$TwoKM <- PathCombinations[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections <- list(NA)
OneKMConnections <- list(NA)
OneAndHalfKMConnections <- list(NA)
TwoKMConnections <- list(NA)
for(i in 1:nrow(PathCombinations[[1]])){
	PathCombinations[[i]] <- PathCombinations[[i]][i:nrow(PathCombinations[[i]]), ]
	HalfKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$HalfKM, ]
	OneKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$OneKM, ]
	OneAndHalfKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$OneAndHalfKM, ]
	TwoKMConnections[[i]] <- PathCombinations[[i]][PathCombinations[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections <- HalfKMConnections[sapply(HalfKMConnections, function(x) dim(x)[1]) > 0]
OneKMConnections <- OneKMConnections[sapply(OneKMConnections, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections <- OneAndHalfKMConnections[sapply(OneAndHalfKMConnections, function(x) dim(x)[1]) > 0]
TwoKMConnections <- TwoKMConnections[sapply(TwoKMConnections, function(x) dim(x)[1]) > 0]

#Create paths between nodes
#####
#####
#####
#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos <- list(NA)
ToNode <- list(NA)
FromNode <- list(NA)
for(i in 1:length(HalfKMConnections)){
	NodeCombos[[i]] <- as.matrix(cbind(c(HalfKMConnections[[i]]$FromNode, HalfKMConnections[[i]]$ToNode),
	c(HalfKMConnections[[i]]$FromNode, HalfKMConnections[[i]]$ToNode)))
	j1 <- nrow(NodeCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos[[i]])
	ToNode[[i]] <- NodeCombos[[i]][j2:j3, ]
	FromNode[[i]] <- data.frame(rbind(NodeCombos[[i]][j1, ]))
	FromNode[[i]][1:j1, ] <- FromNode[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNode))
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNode))
ToNodes <- as.matrix(ToNodes)

#bring nodes together as edges
HalfKMPaths <- cbind(FromNodes, ToNodes)
HalfKMPaths <- unique(HalfKMPaths, incomparables = FALSE)
class(HalfKMPaths)

#create graph object
HalfKMNetwork <- graph(n = 1856, edges = HalfKMPaths, directed = FALSE)
class(HalfKMNetwork)
#plot(HalfKMNetwork)

#calculate degree (number of adjacent edges for each node)
DegreeHalfKMNetwork <- degree(HalfKMNetwork, v = V(HalfKMNetwork), loops = TRUE)
DegreeHalfKMNetwork
MeanDegreeHalfKMNetwork <- mean(DegreeHalfKMNetwork)
MeanDegreeHalfKMNetwork

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
HalfKMNodeBetweenness <- betweenness(HalfKMNetwork, v = V(HalfKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
HalfKMNodeBetweenness
MeanNodeBetweennessHalfKM <- mean(HalfKMNodeBetweenness)
MeanNodeBetweennessHalfKM

HalfKMEdgeBetweenness <- edge.betweenness(HalfKMNetwork, e = E(HalfKMNetwork), directed = FALSE, weights = NULL)
HalfKMEdgeBetweenness
MeanEdgeBetweennessHalfKM <- mean(HalfKMEdgeBetweenness)
MeanEdgeBetweennessHalfKM

#calculate centralization degree (graph-level centrality derived from degree of individual nodes)
HalfKMNetworkCentralizationDegree <- centralization.degree(HalfKMNetwork, loops = TRUE, normalized = FALSE)
HalfKMNetworkCentralizationDegree

#find number of clusters (groups of connected graph components)
HalfKMNetworkNumberClusters <- no.clusters(HalfKMNetwork)
HalfKMNetworkNumberClusters[[1]]

#find mean number of vertices per cluster
HalfKMNetworkClusters <- clusters(HalfKMNetwork)
summary(HalfKMNetworkClusters$csize)
HalfKMNetworkMeanClusterSize <- mean(HalfKMNetworkClusters$csize)
HalfKMNetworkMeanClusterSize

#decompose graph into multiple graphs of connected vertices (with isolated vertices ignored)
HalfKMNetworkDecomposed <- decompose.graph(HalfKMNetwork, max.comps = NA, min.vertices = 2)
HalfKMNetworkDecomposed

#calculate modularity score (how modular is a given division of graphs into subgraphs/how good separation is)
HalfKMNetworkModularity <- modularity(HalfKMNetwork, V(HalfKMNetwork))
HalfKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
HalfKMNetworkSC <- list(NA)
NumberReachedHalfKM <- list(NA)
for(i in 1:nrow(ContWets@data)){
	HalfKMNetworkSC[[i]] <- subcomponent(HalfKMNetwork, v = i)
	NumberReachedHalfKM[[i]] <- length(HalfKMNetworkSC[[i]]) - 1
}
NumberReachedHalfKM <- unlist(NumberReachedHalfKM)
NumberReachedHalfKM
NumberReachedHalfKMMean <- mean(NumberReachedHalfKM)
NumberReachedHalfKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
HalfKMNetworkEBC <- edge.betweenness.community(HalfKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
HalfKMNetworkEVCENT <- evcent(HalfKMNetwork, directed = FALSE, scale = TRUE)
HalfKMNetworkEVCENT
MeanHalfKMNetworkEVCENT <- mean(HalfKMNetworkEVCENT$vector)
MeanHalfKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
HalfKMNetworkGraphDensity <- graph.density(HalfKMNetwork, loops = TRUE)
HalfKMNetworkGraphDensity

#calculate degree and betweenness centrality for graph, without removing any nodes
HalfKMNetworkDegreeCentrality <- centralization.degree(HalfKMNetwork, loops = TRUE, normalized = TRUE)
HalfKMNetworkDegreeCentrality <- HalfKMNetworkDegreeCentrality$centralization
HalfKMNetworkDegreeCentrality
HalfKMNetworkBetweennessCentrality <- centralization.betweenness(HalfKMNetwork, directed = FALSE, nobigint = FALSE, normalized = TRUE)
HalfKMNetworkBetweennessCentrality <- HalfKMNetworkBetweennessCentrality$centralization
HalfKMNetworkBetweennessCentrality

#experiment with deleting vertices/edges
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = FALSE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#add a degree and betweenness centralization importance scores for each vertice
NodeRemove <- list(NA)
DegreeCentralizationRemoval <- list(NA)
DegCentImp <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
BtwCentImp <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = TRUE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	DegCentImp[[i]] <- ((HalfKMNetworkDegreeCentrality - DegreeCentralizationRemoval[[i]])/HalfKMNetworkDegreeCentrality) * 100
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = FALSE, nobigint = FALSE, normalized = TRUE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	BtwCentImp[[i]] <- ((HalfKMNetworkBetweennessCentrality - BetweennessCentralizationRemoval[[i]])/HalfKMNetworkBetweennessCentrality) * 100
}

#unlist degree importance scores for each node
DegCentImp <- unlist(DegCentImp)
DegCentImp <- data.frame(DegCentImp)
DegCentImp$centralization <- DegCentImp[,1]
DegCentImp$NodeID <- ContWets@data$NodeID
DegCentImp$FP_ID <- ContWets@data$FP_ID
DegCentImp <- DegCentImp[,-1]
head(DegCentImp)

#unlist betweenness importance scores for each node
BtwCentImp <- unlist(BtwCentImp)
BtwCentImp <- data.frame(BtwCentImp)
BtwCentImp$centralization <- BtwCentImp[,1]
BtwCentImp$NodeID <- ContWets@data$NodeID
BtwCentImp$FP_ID <- ContWets@data$FP_ID
BtwCentImp <- BtwCentImp[,-1]
head(BtwCentImp)

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWets@data$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWets@data$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWets@data$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWets@data$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWets@data$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWets@data$NodeID
MeanEVCENTRemoval$FP_ID <- ContWets@data$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWets@data$NodeID
NumberClustersRemoval$FP_ID <- ContWets@data$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWets@data$NodeID
ModularityRemoval$FP_ID <- ContWets@data$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWets@data$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWets@data$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#add new outputs to attribute table
ContWets@data$Degree <- DegreeHalfKMNetwork
ContWets@data$DegRem <- MeanNodeDegreeRemoval$Degree
ContWets@data$DegRemCent <- DegreeCentralizationRemoval$DegreeCent
ContWets@data$NodeBetween <- HalfKMNodeBetweenness
ContWets@data$NodeBetweenRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWets@data$EdgeBetweenRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWets@data$BetweenRemCent <- BetweennessCentralizationRemoval$BetweenCent
ContWets@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWets@data$NoClustersRem <- NumberClustersRemoval$NoClusters
ContWets@data$ModRem <- ModularityRemoval$Modularity
ContWets@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWets, "ContWetsHalfKMNetwork", "ContWetsHalfKMNetwork", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that closeness centrality can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/HalfKM/ContWetsHalfKMNetwork/ContWetsHalfKMNetwork.shp", "ContWetsHalfKMNetwork", verbose = TRUE, p4s = NULL)

ContWets@data$CloseRemCent <- ClosenessCentralityRemoval$CloseCent
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsHalfKMNetwork1", "ContWetsHalfKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that degree and betweenness importance percentages can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/HalfKM/ContWetsHalfKMNetwork1/ContWetsHalfKMNetwork1.shp", "ContWetsHalfKMNetwork1", verbose = TRUE, p4s = NULL)

ContWets@data$DegCentImp <- DegCentImp$centralization
ContWets@data$BtwCentImp <- BtwCentImp$centralization
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsHalfKMNetwork3", "ContWetsHalfKMNetwork3", driver = 'ESRI Shapefile', verbose = TRUE)


#####
#####
#####
#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos <- list(NA)
ToNode <- list(NA)
FromNode <- list(NA)
for(i in 1:length(OneKMConnections)){
	NodeCombos[[i]] <- as.matrix(cbind(c(OneKMConnections[[i]]$FromNode, OneKMConnections[[i]]$ToNode),
	c(OneKMConnections[[i]]$FromNode, OneKMConnections[[i]]$ToNode)))
	j1 <- nrow(NodeCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos[[i]])
	ToNode[[i]] <- NodeCombos[[i]][j2:j3, ]
	FromNode[[i]] <- data.frame(rbind(NodeCombos[[i]][j1, ]))
	FromNode[[i]][1:j1, ] <- FromNode[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNode))
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNode))
ToNodes <- as.matrix(ToNodes)

#bring nodes together as edges
OneKMPaths <- cbind(FromNodes, ToNodes)
OneKMPaths <- unique(OneKMPaths, incomparables = FALSE)
class(OneKMPaths)

#create graph object
OneKMNetwork <- graph(n = 1856, edges = OneKMPaths, directed = FALSE)
class(OneKMNetwork)
plot(OneKMNetwork)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
OneKMNodeBetweenness <- betweenness(OneKMNetwork, v = V(OneKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
OneKMNodeBetweenness
MeanNodeBetweennessOneKM <- mean(OneKMNodeBetweenness)
MeanNodeBetweennessOneKM

OneKMEdgeBetweenness <- edge.betweenness(OneKMNetwork, e = E(OneKMNetwork), directed = FALSE, weights = NULL)
OneKMEdgeBetweenness
MeanEdgeBetweennessOneKM <- mean(OneKMEdgeBetweenness)
MeanEdgeBetweennessOneKM

#calculate degree (number of adjacent edges for each node)
DegreeOneKMNetwork <- degree(OneKMNetwork, v = V(OneKMNetwork), loops = TRUE)
DegreeOneKMNetwork
MeanDegreeOneKMNetwork <- mean(DegreeOneKMNetwork)
MeanDegreeOneKMNetwork

#find number of clusters (groups of connected graph components)
OneKMNetworkNumberClusters <- no.clusters(OneKMNetwork)
OneKMNetworkNumberClusters

#find mean number of vertices per cluster
OneKMNetworkClusters <- clusters(OneKMNetwork)
summary(OneKMNetworkClusters$csize)
OneKMNetworkMeanClusterSize <- mean(OneKMNetworkClusters$csize)
OneKMNetworkMeanClusterSize

#calculate modularity
OneKMNetworkModularity <- modularity(OneKMNetwork, V(OneKMNetwork))
OneKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
OneKMNetworkSC <- list(NA)
NumberReachedOneKM <- list(NA)
for(i in 1:nrow(ContWets@data)){
	OneKMNetworkSC[[i]] <- subcomponent(OneKMNetwork, v = i)
	NumberReachedOneKM[[i]] <- length(OneKMNetworkSC[[i]]) - 1
}
NumberReachedOneKM <- unlist(NumberReachedOneKM)
NumberReachedOneKMMean <- mean(NumberReachedOneKM)
NumberReachedOneKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
OneKMNetworkEBC <- edge.betweenness.community(OneKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
OneKMNetworkEVCENT <- evcent(OneKMNetwork, directed = FALSE, scale = FALSE)
OneKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
OneKMNetworkGraphDensity <- graph.density(OneKMNetwork, loops = TRUE)
OneKMNetworkGraphDensity

#identify neighbors of each vertice
OneKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWets@data)){
	OneKMNetworkNeighbors[[i]] <- neighbors(OneKMNetwork, v = i)
}
OneKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
OneKMNetworkNeighborSize <- neighborhood.size(OneKMNetwork, order = 1, nodes = V(OneKMNetwork))
OneKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
OneKMNetworkGraphCohesion <- graph.cohesion(OneKMNetwork)
OneKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
OneKMNetworkAPL <- average.path.length(OneKMNetwork, directed = FALSE, unconnected = TRUE)
OneKMNetworkAPL

#generate histogram of shortest path lengths
OneKMNetworkAPLHist <- path.length.hist(OneKMNetwork, directed = FALSE)
OneKMNetworkAPLHist

#calculate degree and betweenness centrality for graph, without removing any nodes
OneKMNetworkDegreeCentrality <- centralization.degree(OneKMNetwork, loops = TRUE, normalized = TRUE)
OneKMNetworkDegreeCentrality <- OneKMNetworkDegreeCentrality$centralization
OneKMNetworkDegreeCentrality
OneKMNetworkBetweennessCentrality <- centralization.betweenness(OneKMNetwork, directed = FALSE, nobigint = FALSE, normalized = TRUE)
OneKMNetworkBetweennessCentrality <- OneKMNetworkBetweennessCentrality$centralization
OneKMNetworkBetweennessCentrality

#experiment with deleting vertices/edges
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#add a degree and betweenness centralization importance scores for each vertice
NodeRemove <- list(NA)
DegreeCentralizationRemoval <- list(NA)
DegCentImp <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
BtwCentImp <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = TRUE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	DegCentImp[[i]] <- ((OneKMNetworkDegreeCentrality - DegreeCentralizationRemoval[[i]])/OneKMNetworkDegreeCentrality) * 100
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = FALSE, nobigint = FALSE, normalized = TRUE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	BtwCentImp[[i]] <- ((OneKMNetworkBetweennessCentrality - BetweennessCentralizationRemoval[[i]])/OneKMNetworkBetweennessCentrality) * 100
}

#unlist degree importance scores for each node
DegCentImp <- unlist(DegCentImp)
DegCentImp <- data.frame(DegCentImp)
DegCentImp$centralization <- DegCentImp[,1]
DegCentImp$NodeID <- ContWets@data$NodeID
DegCentImp$FP_ID <- ContWets@data$FP_ID
DegCentImp <- DegCentImp[,-1]
head(DegCentImp)

#unlist betweenness importance scores for each node
BtwCentImp <- unlist(BtwCentImp)
BtwCentImp <- data.frame(BtwCentImp)
BtwCentImp$centralization <- BtwCentImp[,1]
BtwCentImp$NodeID <- ContWets@data$NodeID
BtwCentImp$FP_ID <- ContWets@data$FP_ID
BtwCentImp <- BtwCentImp[,-1]
head(BtwCentImp)

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWets@data$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWets@data$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWets@data$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWets@data$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWets@data$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWets@data$NodeID
MeanEVCENTRemoval$FP_ID <- ContWets@data$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWets@data$NodeID
NumberClustersRemoval$FP_ID <- ContWets@data$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWets@data$NodeID
ModularityRemoval$FP_ID <- ContWets@data$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWets@data$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWets@data$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#add new outputs to attribute table
ContWets@data$Degree <- DegreeOneKMNetwork
ContWets@data$DegRem <- MeanNodeDegreeRemoval$Degree
ContWets@data$DegRemCent <- DegreeCentralizationRemoval$DegreeCent
ContWets@data$NodeBetween <- OneKMNodeBetweenness
ContWets@data$NodeBetweenRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWets@data$EdgeBetweenRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWets@data$BetweenRemCent <- BetweennessCentralizationRemoval$BetweenCent
ContWets@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWets@data$NoClustersRem <- NumberClustersRemoval$NoClusters
ContWets@data$ModRem <- ModularityRemoval$Modularity
ContWets@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWets, "ContWetsOneKMNetwork", "ContWetsOneKMNetwork", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that closeness centrality can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/OneKM/ContWetsOneKMNetwork/ContWetsOneKMNetwork.shp", "ContWetsOneKMNetwork", verbose = TRUE, p4s = NULL)

ContWets@data$CloseRemCent <- ClosenessCentralityRemoval$CloseCent
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsOneKMNetwork1", "ContWetsOneKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that degree and betweenness importance percentages can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/OneKM/ContWetsOneKMNetwork1/ContWetsOneKMNetwork1.shp", "ContWetsOneKMNetwork1", verbose = TRUE, p4s = NULL)

ContWets@data$DegCentImp <- DegCentImp$centralization
ContWets@data$BtwCentImp <- BtwCentImp$centralization
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsOneKMNetwork3", "ContWetsOneKMNetwork3", driver = 'ESRI Shapefile', verbose = TRUE)


#####
#####
#####
#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos <- list(NA)
ToNode <- list(NA)
FromNode <- list(NA)
for(i in 1:length(OneAndHalfKMConnections)){
	NodeCombos[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections[[i]]$FromNode, OneAndHalfKMConnections[[i]]$ToNode),
	c(OneAndHalfKMConnections[[i]]$FromNode, OneAndHalfKMConnections[[i]]$ToNode)))
	j1 <- nrow(NodeCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos[[i]])
	ToNode[[i]] <- NodeCombos[[i]][j2:j3, ]
	FromNode[[i]] <- data.frame(rbind(NodeCombos[[i]][j1, ]))
	FromNode[[i]][1:j1, ] <- FromNode[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNode))
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNode))
ToNodes <- as.matrix(ToNodes)

#bring nodes together as edges
OneAndHalfKMPaths <- cbind(FromNodes, ToNodes)
OneAndHalfKMPaths <- unique(OneAndHalfKMPaths, incomparables = FALSE)
class(OneAndHalfKMPaths)

#create graph object
OneAndHalfKMNetwork <- graph(n = 1856, edges = OneAndHalfKMPaths, directed = FALSE)
class(OneAndHalfKMNetwork)
plot(OneAndHalfKMNetwork)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
OneAndHalfKMNodeBetweenness <- betweenness(OneAndHalfKMNetwork, v = V(OneAndHalfKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
OneAndHalfKMNodeBetweenness
MeanNodeBetweennessOneAndHalfKM <- mean(OneAndHalfKMNodeBetweenness)
MeanNodeBetweennessOneAndHalfKM

OneAndHalfKMEdgeBetweenness <- edge.betweenness(OneAndHalfKMNetwork, e = E(OneAndHalfKMNetwork), directed = FALSE, weights = NULL)
OneAndHalfKMEdgeBetweenness
MeanEdgeBetweennessOneAndHalfKM <- mean(OneAndHalfKMEdgeBetweenness)
MeanEdgeBetweennessOneAndHalfKM

#calculate degree (number of adjacent edges for each node)
DegreeOneAndHalfKMNetwork <- degree(OneAndHalfKMNetwork, v = V(OneAndHalfKMNetwork), loops = TRUE)
DegreeOneAndHalfKMNetwork
MeanDegreeOneAndHalfKMNetwork <- mean(DegreeOneAndHalfKMNetwork)
MeanDegreeOneAndHalfKMNetwork

#find number of clusters (groups of connected graph components)
OneAndHalfKMNetworkNumberClusters <- no.clusters(OneAndHalfKMNetwork)
OneAndHalfKMNetworkNumberClusters

#find mean number of vertices per cluster
OneAndHalfKMNetworkClusters <- clusters(OneAndHalfKMNetwork)
summary(OneAndHalfKMNetworkClusters$csize)
OneAndHalfKMNetworkMeanClusterSize <- mean(OneAndHalfKMNetworkClusters$csize)
OneAndHalfKMNetworkMeanClusterSize

#calculate modularity
OneAndHalfKMNetworkModularity <- modularity(OneAndHalfKMNetwork, V(OneAndHalfKMNetwork))
OneAndHalfKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
OneAndHalfKMNetworkSC <- list(NA)
NumberReachedOneAndHalfKM <- list(NA)
for(i in 1:nrow(ContWets@data)){
	OneAndHalfKMNetworkSC[[i]] <- subcomponent(OneAndHalfKMNetwork, v = i)
	NumberReachedOneAndHalfKM[[i]] <- length(OneAndHalfKMNetworkSC[[i]]) - 1
}
NumberReachedOneAndHalfKM <- unlist(NumberReachedOneAndHalfKM)
NumberReachedOneAndHalfKMMean <- mean(NumberReachedOneAndHalfKM)
NumberReachedOneAndHalfKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
OneAndHalfKMNetworkEBC <- edge.betweenness.community(OneAndHalfKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
OneAndHalfKMNetworkEVCENT <- evcent(OneAndHalfKMNetwork, directed = FALSE, scale = FALSE)
OneAndHalfKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
OneAndHalfKMNetworkGraphDensity <- graph.density(OneAndHalfKMNetwork, loops = TRUE)
OneAndHalfKMNetworkGraphDensity

#identify neighbors of each vertice
OneAndHalfKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWets@data)){
	OneAndHalfKMNetworkNeighbors[[i]] <- neighbors(OneAndHalfKMNetwork, v = i)
}
OneAndHalfKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
OneAndHalfKMNetworkNeighborSize <- neighborhood.size(OneAndHalfKMNetwork, order = 1, nodes = V(OneAndHalfKMNetwork))
OneAndHalfKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
OneAndHalfKMNetworkGraphCohesion <- graph.cohesion(OneAndHalfKMNetwork)
OneAndHalfKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
OneAndHalfKMNetworkAPL <- average.path.length(OneAndHalfKMNetwork, directed = FALSE, unconnected = TRUE)
OneAndHalfKMNetworkAPL

#generate histogram of shortest path lengths
OneAndHalfKMNetworkAPLHist <- path.length.hist(OneAndHalfKMNetwork, directed = FALSE)
OneAndHalfKMNetworkAPLHist

#calculate degree and betweenness centrality for graph, without removing any nodes
OneAndHalfKMNetworkDegreeCentrality <- centralization.degree(OneAndHalfKMNetwork, loops = TRUE, normalized = TRUE)
OneAndHalfKMNetworkDegreeCentrality <- OneAndHalfKMNetworkDegreeCentrality$centralization
OneAndHalfKMNetworkDegreeCentrality
OneAndHalfKMNetworkBetweennessCentrality <- centralization.betweenness(OneAndHalfKMNetwork, directed = FALSE, nobigint = FALSE, normalized = TRUE)
OneAndHalfKMNetworkBetweennessCentrality <- OneAndHalfKMNetworkBetweennessCentrality$centralization
OneAndHalfKMNetworkBetweennessCentrality

#experiment with deleting vertices/edges
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneAndHalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneAndHalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#add a degree and betweenness centralization importance scores for each vertice
NodeRemove <- list(NA)
DegreeCentralizationRemoval <- list(NA)
DegCentImp <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
BtwCentImp <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- OneAndHalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = TRUE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	DegCentImp[[i]] <- ((OneAndHalfKMNetworkDegreeCentrality - DegreeCentralizationRemoval[[i]])/OneAndHalfKMNetworkDegreeCentrality) * 100
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = FALSE, nobigint = FALSE, normalized = TRUE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	BtwCentImp[[i]] <- ((OneAndHalfKMNetworkBetweennessCentrality - BetweennessCentralizationRemoval[[i]])/OneAndHalfKMNetworkBetweennessCentrality) * 100
}

#unlist degree importance scores for each node
DegCentImp <- unlist(DegCentImp)
DegCentImp <- data.frame(DegCentImp)
DegCentImp$centralization <- DegCentImp[,1]
DegCentImp$NodeID <- ContWets@data$NodeID
DegCentImp$FP_ID <- ContWets@data$FP_ID
DegCentImp <- DegCentImp[,-1]
head(DegCentImp)

#unlist betweenness importance scores for each node
BtwCentImp <- unlist(BtwCentImp)
BtwCentImp <- data.frame(BtwCentImp)
BtwCentImp$centralization <- BtwCentImp[,1]
BtwCentImp$NodeID <- ContWets@data$NodeID
BtwCentImp$FP_ID <- ContWets@data$FP_ID
BtwCentImp <- BtwCentImp[,-1]
head(BtwCentImp)

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWets@data$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWets@data$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWets@data$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWets@data$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWets@data$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWets@data$NodeID
MeanEVCENTRemoval$FP_ID <- ContWets@data$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWets@data$NodeID
NumberClustersRemoval$FP_ID <- ContWets@data$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWets@data$NodeID
ModularityRemoval$FP_ID <- ContWets@data$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWets@data$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWets@data$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#add new outputs to attribute table
ContWets@data$Degree <- DegreeOneAndHalfKMNetwork
ContWets@data$DegRem <- MeanNodeDegreeRemoval$Degree
ContWets@data$DegRemCent <- DegreeCentralizationRemoval$DegreeCent
ContWets@data$NodeBetween <- OneAndHalfKMNodeBetweenness
ContWets@data$NodeBetweenRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWets@data$EdgeBetweenRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWets@data$BetweenRemCent <- BetweennessCentralizationRemoval$BetweenCent
ContWets@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWets@data$NoClustersRem <- NumberClustersRemoval$NoClusters
ContWets@data$ModRem <- ModularityRemoval$Modularity
ContWets@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWets, "ContWetsOneAndHalfKMNetwork", "ContWetsOneAndHalfKMNetwork", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that closeness centrality can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/OneAndHalfKM/ContWetsOneAndHalfKMNetwork/ContWetsOneAndHalfKMNetwork.shp", "ContWetsOneAndHalfKMNetwork", verbose = TRUE, p4s = NULL)

ContWets@data$CloseRemCent <- ClosenessCentralityRemoval$CloseCent
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsOneAndHalfKMNetwork1", "ContWetsOneAndHalfKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that degree and betweenness importance percentages can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/OneAndHalfKM/ContWetsOneAndHalfKMNetwork1/ContWetsOneAndHalfKMNetwork1.shp", "ContWetsOneAndHalfKMNetwork1", verbose = TRUE, p4s = NULL)

ContWets@data$DegCentImp <- DegCentImp$centralization
ContWets@data$BtwCentImp <- BtwCentImp$centralization
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsOneAndHalfKMNetwork3", "ContWetsOneAndHalfKMNetwork3", driver = 'ESRI Shapefile', verbose = TRUE)

#####
#####
#####
#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos <- list(NA)
ToNode <- list(NA)
FromNode <- list(NA)
for(i in 1:length(TwoKMConnections)){
	NodeCombos[[i]] <- as.matrix(cbind(c(TwoKMConnections[[i]]$FromNode, TwoKMConnections[[i]]$ToNode),
	c(TwoKMConnections[[i]]$FromNode, TwoKMConnections[[i]]$ToNode)))
	j1 <- nrow(NodeCombos[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos[[i]])
	ToNode[[i]] <- NodeCombos[[i]][j2:j3, ]
	FromNode[[i]] <- data.frame(rbind(NodeCombos[[i]][j1, ]))
	FromNode[[i]][1:j1, ] <- FromNode[[i]]
}

#prepare beginning nodes
FromNodes <- data.frame(unlist(FromNode))
FromNodes <- as.matrix(FromNodes)

#prepare ending nodes
ToNodes <- data.frame(unlist(ToNode))
ToNodes <- as.matrix(ToNodes)

#bring nodes together as edges
TwoKMPaths <- cbind(FromNodes, ToNodes)
TwoKMPaths <- unique(TwoKMPaths, incomparables = FALSE)
class(TwoKMPaths)

#create graph object
TwoKMNetwork <- graph(n = 1856, edges = TwoKMPaths, directed = FALSE)
class(TwoKMNetwork)
plot(TwoKMNetwork)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
TwoKMNodeBetweenness <- betweenness(TwoKMNetwork, v = V(TwoKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
TwoKMNodeBetweenness
MeanNodeBetweennessTwoKM <- mean(TwoKMNodeBetweenness)
MeanNodeBetweennessTwoKM

TwoKMEdgeBetweenness <- edge.betweenness(TwoKMNetwork, e = E(TwoKMNetwork), directed = FALSE, weights = NULL)
TwoKMEdgeBetweenness
MeanEdgeBetweennessTwoKM <- mean(TwoKMEdgeBetweenness)
MeanEdgeBetweennessTwoKM

#calculate degree (number of adjacent edges for each node)
DegreeTwoKMNetwork <- degree(TwoKMNetwork, v = V(TwoKMNetwork), loops = TRUE)
DegreeTwoKMNetwork
MeanDegreeTwoKMNetwork <- mean(DegreeTwoKMNetwork)
MeanDegreeTwoKMNetwork

#find number of clusters (groups of connected graph components)
TwoKMNetworkNumberClusters <- no.clusters(TwoKMNetwork)
TwoKMNetworkNumberClusters

#find mean number of vertices per cluster
TwoKMNetworkClusters <- clusters(TwoKMNetwork)
summary(TwoKMNetworkClusters$csize)
TwoKMNetworkMeanClusterSize <- mean(TwoKMNetworkClusters$csize)
TwoKMNetworkMeanClusterSize

#calculate modularity
TwoKMNetworkModularity <- modularity(TwoKMNetwork, V(TwoKMNetwork))
TwoKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
TwoKMNetworkSC <- list(NA)
NumberReachedTwoKM <- list(NA)
for(i in 1:nrow(ContWets@data)){
	TwoKMNetworkSC[[i]] <- subcomponent(TwoKMNetwork, v = i)
	NumberReachedTwoKM[[i]] <- length(TwoKMNetworkSC[[i]]) - 1
}
NumberReachedTwoKM <- unlist(NumberReachedTwoKM)
NumberReachedTwoKMMean <- mean(NumberReachedTwoKM)
NumberReachedTwoKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
TwoKMNetworkEBC <- edge.betweenness.community(TwoKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
TwoKMNetworkEVCENT <- evcent(TwoKMNetwork, directed = FALSE, scale = FALSE)
TwoKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
TwoKMNetworkGraphDensity <- graph.density(TwoKMNetwork, loops = TRUE)
TwoKMNetworkGraphDensity

#identify neighbors of each vertice
TwoKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWets@data)){
	TwoKMNetworkNeighbors[[i]] <- neighbors(TwoKMNetwork, v = i)
}
TwoKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
TwoKMNetworkNeighborSize <- neighborhood.size(TwoKMNetwork, order = 1, nodes = V(TwoKMNetwork))
TwoKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
TwoKMNetworkGraphCohesion <- graph.cohesion(TwoKMNetwork)
TwoKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
TwoKMNetworkAPL <- average.path.length(TwoKMNetwork, directed = FALSE, unconnected = TRUE)
TwoKMNetworkAPL

#generate histogram of shortest path lengths
TwoKMNetworkAPLHist <- path.length.hist(TwoKMNetwork, directed = FALSE)
TwoKMNetworkAPLHist

#calculate degree and betweenness centrality for graph, without removing any nodes
TwoKMNetworkDegreeCentrality <- centralization.degree(TwoKMNetwork, loops = TRUE, normalized = TRUE)
TwoKMNetworkDegreeCentrality <- TwoKMNetworkDegreeCentrality$centralization
TwoKMNetworkDegreeCentrality
TwoKMNetworkBetweennessCentrality <- centralization.betweenness(TwoKMNetwork, directed = FALSE, nobigint = FALSE, normalized = TRUE)
TwoKMNetworkBetweennessCentrality <- TwoKMNetworkBetweennessCentrality$centralization
TwoKMNetworkBetweennessCentrality

#output metrics for inclusion in the attribute table
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- TwoKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- TwoKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#add a degree and betweenness centralization importance scores for each vertice
NodeRemove <- list(NA)
DegreeCentralizationRemoval <- list(NA)
DegCentImp <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
BtwCentImp <- list(NA)
for(i in 1:nrow(ContWets@data)){
	NodeRemove[[i]] <- TwoKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = TRUE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	DegCentImp[[i]] <- ((TwoKMNetworkDegreeCentrality - DegreeCentralizationRemoval[[i]])/TwoKMNetworkDegreeCentrality) * 100
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = FALSE, nobigint = FALSE, normalized = TRUE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	BtwCentImp[[i]] <- ((TwoKMNetworkBetweennessCentrality - BetweennessCentralizationRemoval[[i]])/TwoKMNetworkBetweennessCentrality) * 100
}

#unlist degree importance scores for each node
DegCentImp <- unlist(DegCentImp)
DegCentImp <- data.frame(DegCentImp)
DegCentImp$centralization <- DegCentImp[,1]
DegCentImp$NodeID <- ContWets@data$NodeID
DegCentImp$FP_ID <- ContWets@data$FP_ID
DegCentImp <- DegCentImp[,-1]
head(DegCentImp)

#unlist betweenness importance scores for each node
BtwCentImp <- unlist(BtwCentImp)
BtwCentImp <- data.frame(BtwCentImp)
BtwCentImp$centralization <- BtwCentImp[,1]
BtwCentImp$NodeID <- ContWets@data$NodeID
BtwCentImp$FP_ID <- ContWets@data$FP_ID
BtwCentImp <- BtwCentImp[,-1]
head(BtwCentImp)

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWets@data$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWets@data$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWets@data$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWets@data$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWets@data$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWets@data$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWets@data$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWets@data$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWets@data$NodeID
MeanEVCENTRemoval$FP_ID <- ContWets@data$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWets@data$NodeID
NumberClustersRemoval$FP_ID <- ContWets@data$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWets@data$NodeID
ModularityRemoval$FP_ID <- ContWets@data$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWets@data$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWets@data$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#add new outputs to attribute table
ContWets@data$Degree <- DegreeTwoKMNetwork
ContWets@data$DegRem <- MeanNodeDegreeRemoval$Degree
ContWets@data$DegRemCent <- DegreeCentralizationRemoval$DegreeCent
ContWets@data$NodeBetween <- TwoKMNodeBetweenness
ContWets@data$NodeBetweenRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWets@data$EdgeBetweenRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWets@data$BetweenRemCent <- BetweennessCentralizationRemoval$BetweenCent
ContWets@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWets@data$NoClustersRem <- NumberClustersRemoval$NoClusters
ContWets@data$ModRem <- ModularityRemoval$Modularity
ContWets@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWets, "ContWetsTwoKMNetwork", "ContWetsTwoKMNetwork", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that closeness centrality can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/TwoKM/ContWetsTwoKMNetwork/ContWetsTwoKMNetwork.shp", "ContWetsTwoKMNetwork", verbose = TRUE, p4s = NULL)
head(ContWets@data)

ContWets@data$CloseRemCent <- ClosenessCentralityRemoval$CloseCent
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsTwoKMNetwork1", "ContWetsTwoKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#read in shapefile so that degree and betweenness importance percentages can be added
ContWets <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/Networks/ContemporaryWetlands/TwoKM/ContWetsTwoKMNetwork1/ContWetsTwoKMNetwork1.shp", "ContWetsTwoKMNetwork1", verbose = TRUE, p4s = NULL)

ContWets@data$DegCentImp <- DegCentImp$centralization
ContWets@data$BtwCentImp <- BtwCentImp$centralization
head(ContWets@data)

#write updated shapefile
writeOGR(ContWets, "ContWetsTwoKMNetwork3", "ContWetsTwoKMNetwork3", driver = 'ESRI Shapefile', verbose = TRUE)


