#increase memory limit of R to 3000 MB
memory.limit(size = 4000)

#read in packages
library(rgdal)
library(sp)
library(SDMTools)
library(igraph)

#read in historic wetlands shapefile
HistWets <- readOGR("HistWetsPntsGeographic.shp", "HistWetsPntsGeographic", verbose = TRUE, p4s = NULL)
head(HistWets@data)
HistWets@data$NodeID <- HistWets@data$ORIG_FID + 1
retain <- c("FP_ID", "XCoord", "YCoord", "NodeID")
HistWets@data <- HistWets@data[retain]
head(HistWets@data)

#generate combinations of wetland ids at 4 dispersal distances (0.5, 1, 1.5, 2 km)
#Part1
PathCombinations1 <- list(NA)
for(i in 1:1000){
	PathCombinations1[[i]] <- data.frame(FromNode = HistWets@data[i,]$NodeID)
	PathCombinations1[[i]][1:nrow(HistWets@data),] <- HistWets@data[i,]$NodeID
	PathCombinations1[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations1[[i]]$FromNodeXCoord <- HistWets@data[i,]$XCoord
	PathCombinations1[[i]]$FromNodeYCoord <- HistWets@data[i,]$YCoord
	PathCombinations1[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations1[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations1[[i]]$Repeat <- PathCombinations1[[i]]$FromNode != PathCombinations1[[i]]$ToNode
	PathCombinations1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$Repeat, ]
	PathCombinations1[[i]]$Distance <- distance(PathCombinations1[[i]]$FromNodeYCoord, PathCombinations1[[i]]$FromNodeXCoord, PathCombinations1[[i]]$ToNodeYCoord, PathCombinations1[[i]]$ToNodeXCoord)	
	PathCombinations1[[i]]$HalfKM <- PathCombinations1[[i]]$Distance$distance <= 500
	PathCombinations1[[i]]$OneKM <- PathCombinations1[[i]]$Distance$distance <= 1000
	PathCombinations1[[i]]$OneAndHalfKM <- PathCombinations1[[i]]$Distance$distance <= 1500
	PathCombinations1[[i]]$TwoKM <- PathCombinations1[[i]]$Distance$distance <= 2000
}

#remove backwards duplicates
HalfKMConnections1 <- list(NA)
OneKMConnections1 <- list(NA)
OneAndHalfKMConnections1 <- list(NA)
TwoKMConnections1 <- list(NA)
for(i in 1:1000){
	PathCombinations1[[i]] <- PathCombinations1[[i]][i:nrow(PathCombinations1[[i]]), ]
	HalfKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$HalfKM, ]
	OneKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$OneKM, ]
	OneAndHalfKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$OneAndHalfKM, ]
	TwoKMConnections1[[i]] <- PathCombinations1[[i]][PathCombinations1[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections1 <- HalfKMConnections1[sapply(HalfKMConnections1, function(x) dim(x)[1]) > 0]
OneKMConnections1 <- OneKMConnections1[sapply(OneKMConnections1, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections1 <- OneAndHalfKMConnections1[sapply(OneAndHalfKMConnections1, function(x) dim(x)[1]) > 0]
TwoKMConnections1 <- TwoKMConnections1[sapply(TwoKMConnections1, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(HalfKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(HalfKMConnections1[[i]]$FromNode, HalfKMConnections1[[i]]$ToNode),
	c(HalfKMConnections1[[i]]$FromNode, HalfKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
HalfKMPaths1 <- cbind(FromNodes1, ToNodes1)
HalfKMPaths1 <- unique(HalfKMPaths1, incomparables = FALSE)
class(HalfKMPaths1)
write.csv(HalfKMPaths1, "HalfKMPaths1.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(OneKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(OneKMConnections1[[i]]$FromNode, OneKMConnections1[[i]]$ToNode),
	c(OneKMConnections1[[i]]$FromNode, OneKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
OneKMPaths1 <- cbind(FromNodes1, ToNodes1)
OneKMPaths1 <- unique(OneKMPaths1, incomparables = FALSE)
class(OneKMPaths1)
write.csv(OneKMPaths1, "OneKMPaths1.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections1[[i]]$FromNode, OneAndHalfKMConnections1[[i]]$ToNode),
	c(OneAndHalfKMConnections1[[i]]$FromNode, OneAndHalfKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
OneAndHalfKMPaths1 <- cbind(FromNodes1, ToNodes1)
OneAndHalfKMPaths1 <- unique(OneAndHalfKMPaths1, incomparables = FALSE)
class(OneAndHalfKMPaths1)
write.csv(OneAndHalfKMPaths1, "OneAndHalfKMPaths1.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos1 <- list(NA)
ToNode1 <- list(NA)
FromNode1 <- list(NA)
for(i in 1:length(TwoKMConnections1)){
	NodeCombos1[[i]] <- as.matrix(cbind(c(TwoKMConnections1[[i]]$FromNode, TwoKMConnections1[[i]]$ToNode),
	c(TwoKMConnections1[[i]]$FromNode, TwoKMConnections1[[i]]$ToNode)))
	j1 <- nrow(NodeCombos1[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos1[[i]])
	ToNode1[[i]] <- NodeCombos1[[i]][j2:j3, ]
	FromNode1[[i]] <- data.frame(rbind(NodeCombos1[[i]][j1, ]))
	FromNode1[[i]][1:j1, ] <- FromNode1[[i]]
}

#prepare beginning nodes
FromNodes1 <- data.frame(unlist(FromNode1))
FromNodes1 <- as.matrix(FromNodes1)

#prepare ending nodes
ToNodes1 <- data.frame(unlist(ToNode1))
ToNodes1 <- as.matrix(ToNodes1)

#bring nodes together as edges
TwoKMPaths1 <- cbind(FromNodes1, ToNodes1)
TwoKMPaths1 <- unique(TwoKMPaths1, incomparables = FALSE)
class(TwoKMPaths1)
write.csv(TwoKMPaths1, "TwoKMPaths1.csv")

#Part2
PathCombinations2 <- list(NA)
for(i in 1:1000){
	PathCombinations2[[i]] <- data.frame(FromNode = HistWets@data[1000 + i,]$NodeID)
	PathCombinations2[[i]][1:nrow(HistWets@data),] <- HistWets@data[1000 + i,]$NodeID
	PathCombinations2[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations2[[i]]$FromNodeXCoord <- HistWets@data[1000 + i,]$XCoord
	PathCombinations2[[i]]$FromNodeYCoord <- HistWets@data[1000 + i,]$YCoord
	PathCombinations2[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations2[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations2[[i]]$Repeat <- PathCombinations2[[i]]$FromNode != PathCombinations2[[i]]$ToNode
	PathCombinations2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$Repeat, ]
	PathCombinations2[[i]]$Distance <- distance(PathCombinations2[[i]]$FromNodeYCoord, PathCombinations2[[i]]$FromNodeXCoord, PathCombinations2[[i]]$ToNodeYCoord, PathCombinations2[[i]]$ToNodeXCoord)	
	PathCombinations2[[i]]$HalfKM <- PathCombinations2[[i]]$Distance$distance <= 500
	PathCombinations2[[i]]$OneKM <- PathCombinations2[[i]]$Distance$distance <= 1000
	PathCombinations2[[i]]$OneAndHalfKM <- PathCombinations2[[i]]$Distance$distance <= 1500
	PathCombinations2[[i]]$TwoKM <- PathCombinations2[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections2 <- list(NA)
OneKMConnections2 <- list(NA)
OneAndHalfKMConnections2 <- list(NA)
TwoKMConnections2 <- list(NA)
for(i in 1:1000){
	PathCombinations2[[i]] <- PathCombinations2[[i]][(1000 + i):nrow(PathCombinations2[[i]]), ]
	HalfKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$HalfKM, ]
	OneKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$OneKM, ]
	OneAndHalfKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$OneAndHalfKM, ]
	TwoKMConnections2[[i]] <- PathCombinations2[[i]][PathCombinations2[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections2 <- HalfKMConnections2[sapply(HalfKMConnections2, function(x) dim(x)[1]) > 0]
OneKMConnections2 <- OneKMConnections2[sapply(OneKMConnections2, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections2 <- OneAndHalfKMConnections2[sapply(OneAndHalfKMConnections2, function(x) dim(x)[1]) > 0]
TwoKMConnections2 <- TwoKMConnections2[sapply(TwoKMConnections2, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(HalfKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(HalfKMConnections2[[i]]$FromNode, HalfKMConnections2[[i]]$ToNode),
	c(HalfKMConnections2[[i]]$FromNode, HalfKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
HalfKMPaths2 <- cbind(FromNodes2, ToNodes2)
HalfKMPaths2 <- unique(HalfKMPaths2, incomparables = FALSE)
class(HalfKMPaths2)
write.csv(HalfKMPaths2, "HalfKMPaths2.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(OneKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(OneKMConnections2[[i]]$FromNode, OneKMConnections2[[i]]$ToNode),
	c(OneKMConnections2[[i]]$FromNode, OneKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
OneKMPaths2 <- cbind(FromNodes2, ToNodes2)
OneKMPaths2 <- unique(OneKMPaths2, incomparables = FALSE)
class(OneKMPaths2)
write.csv(OneKMPaths2, "OneKMPaths2.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections2[[i]]$FromNode, OneAndHalfKMConnections2[[i]]$ToNode),
	c(OneAndHalfKMConnections2[[i]]$FromNode, OneAndHalfKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
OneAndHalfKMPaths2 <- cbind(FromNodes2, ToNodes2)
OneAndHalfKMPaths2 <- unique(OneAndHalfKMPaths2, incomparables = FALSE)
class(OneAndHalfKMPaths2)
write.csv(OneAndHalfKMPaths2, "OneAndHalfKMPaths2.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos2 <- list(NA)
ToNode2 <- list(NA)
FromNode2 <- list(NA)
for(i in 1:length(TwoKMConnections2)){
	NodeCombos2[[i]] <- as.matrix(cbind(c(TwoKMConnections2[[i]]$FromNode, TwoKMConnections2[[i]]$ToNode),
	c(TwoKMConnections2[[i]]$FromNode, TwoKMConnections2[[i]]$ToNode)))
	j1 <- nrow(NodeCombos2[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos2[[i]])
	ToNode2[[i]] <- NodeCombos2[[i]][j2:j3, ]
	FromNode2[[i]] <- data.frame(rbind(NodeCombos2[[i]][j1, ]))
	FromNode2[[i]][1:j1, ] <- FromNode2[[i]]
}

#prepare beginning nodes
FromNodes2 <- data.frame(unlist(FromNode2))
FromNodes2 <- as.matrix(FromNodes2)

#prepare ending nodes
ToNodes2 <- data.frame(unlist(ToNode2))
ToNodes2 <- as.matrix(ToNodes2)

#bring nodes together as edges
TwoKMPaths2 <- cbind(FromNodes2, ToNodes2)
TwoKMPaths2 <- unique(TwoKMPaths2, incomparables = FALSE)
class(TwoKMPaths2)
write.csv(TwoKMPaths2, "TwoKMPaths2.csv")

#Part3
PathCombinations3 <- list(NA)
for(i in 1:1000){
	PathCombinations3[[i]] <- data.frame(FromNode = HistWets@data[2000 + i,]$NodeID)
	PathCombinations3[[i]][1:nrow(HistWets@data),] <- HistWets@data[2000 + i,]$NodeID
	PathCombinations3[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations3[[i]]$FromNodeXCoord <- HistWets@data[2000 + i,]$XCoord
	PathCombinations3[[i]]$FromNodeYCoord <- HistWets@data[2000 + i,]$YCoord
	PathCombinations3[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations3[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations3[[i]]$Repeat <- PathCombinations3[[i]]$FromNode != PathCombinations3[[i]]$ToNode
	PathCombinations3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$Repeat, ]
	PathCombinations3[[i]]$Distance <- distance(PathCombinations3[[i]]$FromNodeYCoord, PathCombinations3[[i]]$FromNodeXCoord, PathCombinations3[[i]]$ToNodeYCoord, PathCombinations3[[i]]$ToNodeXCoord)	
	PathCombinations3[[i]]$HalfKM <- PathCombinations3[[i]]$Distance$distance <= 500
	PathCombinations3[[i]]$OneKM <- PathCombinations3[[i]]$Distance$distance <= 1000
	PathCombinations3[[i]]$OneAndHalfKM <- PathCombinations3[[i]]$Distance$distance <= 1500
	PathCombinations3[[i]]$TwoKM <- PathCombinations3[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections3 <- list(NA)
OneKMConnections3 <- list(NA)
OneAndHalfKMConnections3 <- list(NA)
TwoKMConnections3 <- list(NA)
for(i in 1:1000){
	PathCombinations3[[i]] <- PathCombinations3[[i]][(2000 + i):nrow(PathCombinations3[[i]]), ]
	HalfKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$HalfKM, ]
	OneKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$OneKM, ]
	OneAndHalfKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$OneAndHalfKM, ]
	TwoKMConnections3[[i]] <- PathCombinations3[[i]][PathCombinations3[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections3 <- HalfKMConnections3[sapply(HalfKMConnections3, function(x) dim(x)[1]) > 0]
OneKMConnections3 <- OneKMConnections3[sapply(OneKMConnections3, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections3 <- OneAndHalfKMConnections3[sapply(OneAndHalfKMConnections3, function(x) dim(x)[1]) > 0]
TwoKMConnections3 <- TwoKMConnections3[sapply(TwoKMConnections3, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(HalfKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(HalfKMConnections3[[i]]$FromNode, HalfKMConnections3[[i]]$ToNode),
	c(HalfKMConnections3[[i]]$FromNode, HalfKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
HalfKMPaths3 <- cbind(FromNodes3, ToNodes3)
HalfKMPaths3 <- unique(HalfKMPaths3, incomparables = FALSE)
class(HalfKMPaths3)
write.csv(HalfKMPaths3, "HalfKMPaths3.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(OneKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(OneKMConnections3[[i]]$FromNode, OneKMConnections3[[i]]$ToNode),
	c(OneKMConnections3[[i]]$FromNode, OneKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
OneKMPaths3 <- cbind(FromNodes3, ToNodes3)
OneKMPaths3 <- unique(OneKMPaths3, incomparables = FALSE)
class(OneKMPaths3)
write.csv(OneKMPaths3, "OneKMPaths3.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections3[[i]]$FromNode, OneAndHalfKMConnections3[[i]]$ToNode),
	c(OneAndHalfKMConnections3[[i]]$FromNode, OneAndHalfKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
OneAndHalfKMPaths3 <- cbind(FromNodes3, ToNodes3)
OneAndHalfKMPaths3 <- unique(OneAndHalfKMPaths3, incomparables = FALSE)
class(OneAndHalfKMPaths3)
write.csv(OneAndHalfKMPaths3, "OneAndHalfKMPaths3.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos3 <- list(NA)
ToNode3 <- list(NA)
FromNode3 <- list(NA)
for(i in 1:length(TwoKMConnections3)){
	NodeCombos3[[i]] <- as.matrix(cbind(c(TwoKMConnections3[[i]]$FromNode, TwoKMConnections3[[i]]$ToNode),
	c(TwoKMConnections3[[i]]$FromNode, TwoKMConnections3[[i]]$ToNode)))
	j1 <- nrow(NodeCombos3[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos3[[i]])
	ToNode3[[i]] <- NodeCombos3[[i]][j2:j3, ]
	FromNode3[[i]] <- data.frame(rbind(NodeCombos3[[i]][j1, ]))
	FromNode3[[i]][1:j1, ] <- FromNode3[[i]]
}

#prepare beginning nodes
FromNodes3 <- data.frame(unlist(FromNode3))
FromNodes3 <- as.matrix(FromNodes3)

#prepare ending nodes
ToNodes3 <- data.frame(unlist(ToNode3))
ToNodes3 <- as.matrix(ToNodes3)

#bring nodes together as edges
TwoKMPaths3 <- cbind(FromNodes3, ToNodes3)
TwoKMPaths3 <- unique(TwoKMPaths3, incomparables = FALSE)
class(TwoKMPaths3)
write.csv(TwoKMPaths3, "TwoKMPaths3.csv")

#Part4
PathCombinations4 <- list(NA)
for(i in 1:1000){
	PathCombinations4[[i]] <- data.frame(FromNode = HistWets@data[3000 + i,]$NodeID)
	PathCombinations4[[i]][1:nrow(HistWets@data),] <- HistWets@data[3000 + i,]$NodeID
	PathCombinations4[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations4[[i]]$FromNodeXCoord <- HistWets@data[3000 + i,]$XCoord
	PathCombinations4[[i]]$FromNodeYCoord <- HistWets@data[3000 + i,]$YCoord
	PathCombinations4[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations4[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations4[[i]]$Repeat <- PathCombinations4[[i]]$FromNode != PathCombinations4[[i]]$ToNode
	PathCombinations4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$Repeat, ]
	PathCombinations4[[i]]$Distance <- distance(PathCombinations4[[i]]$FromNodeYCoord, PathCombinations4[[i]]$FromNodeXCoord, PathCombinations4[[i]]$ToNodeYCoord, PathCombinations4[[i]]$ToNodeXCoord)	
	PathCombinations4[[i]]$HalfKM <- PathCombinations4[[i]]$Distance$distance <= 500
	PathCombinations4[[i]]$OneKM <- PathCombinations4[[i]]$Distance$distance <= 1000
	PathCombinations4[[i]]$OneAndHalfKM <- PathCombinations4[[i]]$Distance$distance <= 1500
	PathCombinations4[[i]]$TwoKM <- PathCombinations4[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections4 <- list(NA)
OneKMConnections4 <- list(NA)
OneAndHalfKMConnections4 <- list(NA)
TwoKMConnections4 <- list(NA)
for(i in 1:1000){
	PathCombinations4[[i]] <- PathCombinations4[[i]][(3000 + i):nrow(PathCombinations4[[i]]), ]
	HalfKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$HalfKM, ]
	OneKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$OneKM, ]
	OneAndHalfKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$OneAndHalfKM, ]
	TwoKMConnections4[[i]] <- PathCombinations4[[i]][PathCombinations4[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections4 <- HalfKMConnections4[sapply(HalfKMConnections4, function(x) dim(x)[1]) > 0]
OneKMConnections4 <- OneKMConnections4[sapply(OneKMConnections4, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections4 <- OneAndHalfKMConnections4[sapply(OneAndHalfKMConnections4, function(x) dim(x)[1]) > 0]
TwoKMConnections4 <- TwoKMConnections4[sapply(TwoKMConnections4, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(HalfKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(HalfKMConnections4[[i]]$FromNode, HalfKMConnections4[[i]]$ToNode),
	c(HalfKMConnections4[[i]]$FromNode, HalfKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
HalfKMPaths4 <- cbind(FromNodes4, ToNodes4)
HalfKMPaths4 <- unique(HalfKMPaths4, incomparables = FALSE)
class(HalfKMPaths4)
write.csv(HalfKMPaths4, "HalfKMPaths4.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(OneKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(OneKMConnections4[[i]]$FromNode, OneKMConnections4[[i]]$ToNode),
	c(OneKMConnections4[[i]]$FromNode, OneKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
OneKMPaths4 <- cbind(FromNodes4, ToNodes4)
OneKMPaths4 <- unique(OneKMPaths4, incomparables = FALSE)
class(OneKMPaths4)
write.csv(OneKMPaths4, "OneKMPaths4.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections4[[i]]$FromNode, OneAndHalfKMConnections4[[i]]$ToNode),
	c(OneAndHalfKMConnections4[[i]]$FromNode, OneAndHalfKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
OneAndHalfKMPaths4 <- cbind(FromNodes4, ToNodes4)
OneAndHalfKMPaths4 <- unique(OneAndHalfKMPaths4, incomparables = FALSE)
class(OneAndHalfKMPaths4)
write.csv(OneAndHalfKMPaths4, "OneAndHalfKMPaths4.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos4 <- list(NA)
ToNode4 <- list(NA)
FromNode4 <- list(NA)
for(i in 1:length(TwoKMConnections4)){
	NodeCombos4[[i]] <- as.matrix(cbind(c(TwoKMConnections4[[i]]$FromNode, TwoKMConnections4[[i]]$ToNode),
	c(TwoKMConnections4[[i]]$FromNode, TwoKMConnections4[[i]]$ToNode)))
	j1 <- nrow(NodeCombos4[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos4[[i]])
	ToNode4[[i]] <- NodeCombos4[[i]][j2:j3, ]
	FromNode4[[i]] <- data.frame(rbind(NodeCombos4[[i]][j1, ]))
	FromNode4[[i]][1:j1, ] <- FromNode4[[i]]
}

#prepare beginning nodes
FromNodes4 <- data.frame(unlist(FromNode4))
FromNodes4 <- as.matrix(FromNodes4)

#prepare ending nodes
ToNodes4 <- data.frame(unlist(ToNode4))
ToNodes4 <- as.matrix(ToNodes4)

#bring nodes together as edges
TwoKMPaths4 <- cbind(FromNodes4, ToNodes4)
TwoKMPaths4 <- unique(TwoKMPaths4, incomparables = FALSE)
class(TwoKMPaths4)
write.csv(TwoKMPaths4, "TwoKMPaths4.csv")

#Part5
PathCombinations5 <- list(NA)
for(i in 1:1000){
	PathCombinations5[[i]] <- data.frame(FromNode = HistWets@data[4000 + i,]$NodeID)
	PathCombinations5[[i]][1:nrow(HistWets@data),] <- HistWets@data[4000 + i,]$NodeID
	PathCombinations5[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations5[[i]]$FromNodeXCoord <- HistWets@data[4000 + i,]$XCoord
	PathCombinations5[[i]]$FromNodeYCoord <- HistWets@data[4000 + i,]$YCoord
	PathCombinations5[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations5[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations5[[i]]$Repeat <- PathCombinations5[[i]]$FromNode != PathCombinations5[[i]]$ToNode
	PathCombinations5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$Repeat, ]
	PathCombinations5[[i]]$Distance <- distance(PathCombinations5[[i]]$FromNodeYCoord, PathCombinations5[[i]]$FromNodeXCoord, PathCombinations5[[i]]$ToNodeYCoord, PathCombinations5[[i]]$ToNodeXCoord)	
	PathCombinations5[[i]]$HalfKM <- PathCombinations5[[i]]$Distance$distance <= 500
	PathCombinations5[[i]]$OneKM <- PathCombinations5[[i]]$Distance$distance <= 1000
	PathCombinations5[[i]]$OneAndHalfKM <- PathCombinations5[[i]]$Distance$distance <= 1500
	PathCombinations5[[i]]$TwoKM <- PathCombinations5[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections5 <- list(NA)
OneKMConnections5 <- list(NA)
OneAndHalfKMConnections5 <- list(NA)
TwoKMConnections5 <- list(NA)
for(i in 1:1000){
	PathCombinations5[[i]] <- PathCombinations5[[i]][(4000 + i):nrow(PathCombinations5[[i]]), ]
	HalfKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$HalfKM, ]
	OneKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$OneKM, ]
	OneAndHalfKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$OneAndHalfKM, ]
	TwoKMConnections5[[i]] <- PathCombinations5[[i]][PathCombinations5[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections5 <- HalfKMConnections5[sapply(HalfKMConnections5, function(x) dim(x)[1]) > 0]
OneKMConnections5 <- OneKMConnections5[sapply(OneKMConnections5, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections5 <- OneAndHalfKMConnections5[sapply(OneAndHalfKMConnections5, function(x) dim(x)[1]) > 0]
TwoKMConnections5 <- TwoKMConnections5[sapply(TwoKMConnections5, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(HalfKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(HalfKMConnections5[[i]]$FromNode, HalfKMConnections5[[i]]$ToNode),
	c(HalfKMConnections5[[i]]$FromNode, HalfKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
HalfKMPaths5 <- cbind(FromNodes5, ToNodes5)
HalfKMPaths5 <- unique(HalfKMPaths5, incomparables = FALSE)
class(HalfKMPaths5)
write.csv(HalfKMPaths5, "HalfKMPaths5.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(OneKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(OneKMConnections5[[i]]$FromNode, OneKMConnections5[[i]]$ToNode),
	c(OneKMConnections5[[i]]$FromNode, OneKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
OneKMPaths5 <- cbind(FromNodes5, ToNodes5)
OneKMPaths5 <- unique(OneKMPaths5, incomparables = FALSE)
class(OneKMPaths5)
write.csv(OneKMPaths5, "OneKMPaths5.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections5[[i]]$FromNode, OneAndHalfKMConnections5[[i]]$ToNode),
	c(OneAndHalfKMConnections5[[i]]$FromNode, OneAndHalfKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
OneAndHalfKMPaths5 <- cbind(FromNodes5, ToNodes5)
OneAndHalfKMPaths5 <- unique(OneAndHalfKMPaths5, incomparables = FALSE)
class(OneAndHalfKMPaths5)
write.csv(OneAndHalfKMPaths5, "OneAndHalfKMPaths5.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos5 <- list(NA)
ToNode5 <- list(NA)
FromNode5 <- list(NA)
for(i in 1:length(TwoKMConnections5)){
	NodeCombos5[[i]] <- as.matrix(cbind(c(TwoKMConnections5[[i]]$FromNode, TwoKMConnections5[[i]]$ToNode),
	c(TwoKMConnections5[[i]]$FromNode, TwoKMConnections5[[i]]$ToNode)))
	j1 <- nrow(NodeCombos5[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos5[[i]])
	ToNode5[[i]] <- NodeCombos5[[i]][j2:j3, ]
	FromNode5[[i]] <- data.frame(rbind(NodeCombos5[[i]][j1, ]))
	FromNode5[[i]][1:j1, ] <- FromNode5[[i]]
}

#prepare beginning nodes
FromNodes5 <- data.frame(unlist(FromNode5))
FromNodes5 <- as.matrix(FromNodes5)

#prepare ending nodes
ToNodes5 <- data.frame(unlist(ToNode5))
ToNodes5 <- as.matrix(ToNodes5)

#bring nodes together as edges
TwoKMPaths5 <- cbind(FromNodes5, ToNodes5)
TwoKMPaths5 <- unique(TwoKMPaths5, incomparables = FALSE)
class(TwoKMPaths5)
write.csv(TwoKMPaths5, "TwoKMPaths5.csv")

#Part6
PathCombinations6 <- list(NA)
for(i in 1:1000){
	PathCombinations6[[i]] <- data.frame(FromNode = HistWets@data[5000 + i,]$NodeID)
	PathCombinations6[[i]][1:nrow(HistWets@data),] <- HistWets@data[5000 + i,]$NodeID
	PathCombinations6[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations6[[i]]$FromNodeXCoord <- HistWets@data[5000 + i,]$XCoord
	PathCombinations6[[i]]$FromNodeYCoord <- HistWets@data[5000 + i,]$YCoord
	PathCombinations6[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations6[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations6[[i]]$Repeat <- PathCombinations6[[i]]$FromNode != PathCombinations6[[i]]$ToNode
	PathCombinations6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$Repeat, ]
	PathCombinations6[[i]]$Distance <- distance(PathCombinations6[[i]]$FromNodeYCoord, PathCombinations6[[i]]$FromNodeXCoord, PathCombinations6[[i]]$ToNodeYCoord, PathCombinations6[[i]]$ToNodeXCoord)	
	PathCombinations6[[i]]$HalfKM <- PathCombinations6[[i]]$Distance$distance <= 500
	PathCombinations6[[i]]$OneKM <- PathCombinations6[[i]]$Distance$distance <= 1000
	PathCombinations6[[i]]$OneAndHalfKM <- PathCombinations6[[i]]$Distance$distance <= 1500
	PathCombinations6[[i]]$TwoKM <- PathCombinations6[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections6 <- list(NA)
OneKMConnections6 <- list(NA)
OneAndHalfKMConnections6 <- list(NA)
TwoKMConnections6 <- list(NA)
for(i in 1:1000){
	PathCombinations6[[i]] <- PathCombinations6[[i]][(5000 + i):nrow(PathCombinations6[[i]]), ]
	HalfKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$HalfKM, ]
	OneKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$OneKM, ]
	OneAndHalfKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$OneAndHalfKM, ]
	TwoKMConnections6[[i]] <- PathCombinations6[[i]][PathCombinations6[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections6 <- HalfKMConnections6[sapply(HalfKMConnections6, function(x) dim(x)[1]) > 0]
OneKMConnections6 <- OneKMConnections6[sapply(OneKMConnections6, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections6 <- OneAndHalfKMConnections6[sapply(OneAndHalfKMConnections6, function(x) dim(x)[1]) > 0]
TwoKMConnections6 <- TwoKMConnections6[sapply(TwoKMConnections6, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(HalfKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(HalfKMConnections6[[i]]$FromNode, HalfKMConnections6[[i]]$ToNode),
	c(HalfKMConnections6[[i]]$FromNode, HalfKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
HalfKMPaths6 <- cbind(FromNodes6, ToNodes6)
HalfKMPaths6 <- unique(HalfKMPaths6, incomparables = FALSE)
class(HalfKMPaths6)
write.csv(HalfKMPaths6, "HalfKMPaths6.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(OneKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(OneKMConnections6[[i]]$FromNode, OneKMConnections6[[i]]$ToNode),
	c(OneKMConnections6[[i]]$FromNode, OneKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
OneKMPaths6 <- cbind(FromNodes6, ToNodes6)
OneKMPaths6 <- unique(OneKMPaths6, incomparables = FALSE)
class(OneKMPaths6)
write.csv(OneKMPaths6, "OneKMPaths6.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections6[[i]]$FromNode, OneAndHalfKMConnections6[[i]]$ToNode),
	c(OneAndHalfKMConnections6[[i]]$FromNode, OneAndHalfKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
OneAndHalfKMPaths6 <- cbind(FromNodes6, ToNodes6)
OneAndHalfKMPaths6 <- unique(OneAndHalfKMPaths6, incomparables = FALSE)
class(OneAndHalfKMPaths6)
write.csv(OneAndHalfKMPaths6, "OneAndHalfKMPaths6.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos6 <- list(NA)
ToNode6 <- list(NA)
FromNode6 <- list(NA)
for(i in 1:length(TwoKMConnections6)){
	NodeCombos6[[i]] <- as.matrix(cbind(c(TwoKMConnections6[[i]]$FromNode, TwoKMConnections6[[i]]$ToNode),
	c(TwoKMConnections6[[i]]$FromNode, TwoKMConnections6[[i]]$ToNode)))
	j1 <- nrow(NodeCombos6[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos6[[i]])
	ToNode6[[i]] <- NodeCombos6[[i]][j2:j3, ]
	FromNode6[[i]] <- data.frame(rbind(NodeCombos6[[i]][j1, ]))
	FromNode6[[i]][1:j1, ] <- FromNode6[[i]]
}

#prepare beginning nodes
FromNodes6 <- data.frame(unlist(FromNode6))
FromNodes6 <- as.matrix(FromNodes6)

#prepare ending nodes
ToNodes6 <- data.frame(unlist(ToNode6))
ToNodes6 <- as.matrix(ToNodes6)

#bring nodes together as edges
TwoKMPaths6 <- cbind(FromNodes6, ToNodes6)
TwoKMPaths6 <- unique(TwoKMPaths6, incomparables = FALSE)
class(TwoKMPaths6)
write.csv(TwoKMPaths6, "TwoKMPaths6.csv")

#Part7
PathCombinations7 <- list(NA)
for(i in 1:1000){
	PathCombinations7[[i]] <- data.frame(FromNode = HistWets@data[6000 + i,]$NodeID)
	PathCombinations7[[i]][1:nrow(HistWets@data),] <- HistWets@data[6000 + i,]$NodeID
	PathCombinations7[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations7[[i]]$FromNodeXCoord <- HistWets@data[6000 + i,]$XCoord
	PathCombinations7[[i]]$FromNodeYCoord <- HistWets@data[6000 + i,]$YCoord
	PathCombinations7[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations7[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations7[[i]]$Repeat <- PathCombinations7[[i]]$FromNode != PathCombinations7[[i]]$ToNode
	PathCombinations7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$Repeat, ]
	PathCombinations7[[i]]$Distance <- distance(PathCombinations7[[i]]$FromNodeYCoord, PathCombinations7[[i]]$FromNodeXCoord, PathCombinations7[[i]]$ToNodeYCoord, PathCombinations7[[i]]$ToNodeXCoord)	
	PathCombinations7[[i]]$HalfKM <- PathCombinations7[[i]]$Distance$distance <= 500
	PathCombinations7[[i]]$OneKM <- PathCombinations7[[i]]$Distance$distance <= 1000
	PathCombinations7[[i]]$OneAndHalfKM <- PathCombinations7[[i]]$Distance$distance <= 1500
	PathCombinations7[[i]]$TwoKM <- PathCombinations7[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections7 <- list(NA)
OneKMConnections7 <- list(NA)
OneAndHalfKMConnections7 <- list(NA)
TwoKMConnections7 <- list(NA)
for(i in 1:1000){
	PathCombinations7[[i]] <- PathCombinations7[[i]][(6000 + i):nrow(PathCombinations7[[i]]), ]
	HalfKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$HalfKM, ]
	OneKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$OneKM, ]
	OneAndHalfKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$OneAndHalfKM, ]
	TwoKMConnections7[[i]] <- PathCombinations7[[i]][PathCombinations7[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections7 <- HalfKMConnections7[sapply(HalfKMConnections7, function(x) dim(x)[1]) > 0]
OneKMConnections7 <- OneKMConnections7[sapply(OneKMConnections7, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections7 <- OneAndHalfKMConnections7[sapply(OneAndHalfKMConnections7, function(x) dim(x)[1]) > 0]
TwoKMConnections7 <- TwoKMConnections7[sapply(TwoKMConnections7, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(HalfKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(HalfKMConnections7[[i]]$FromNode, HalfKMConnections7[[i]]$ToNode),
	c(HalfKMConnections7[[i]]$FromNode, HalfKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
HalfKMPaths7 <- cbind(FromNodes7, ToNodes7)
HalfKMPaths7 <- unique(HalfKMPaths7, incomparables = FALSE)
class(HalfKMPaths7)
write.csv(HalfKMPaths7, "HalfKMPaths7.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(OneKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(OneKMConnections7[[i]]$FromNode, OneKMConnections7[[i]]$ToNode),
	c(OneKMConnections7[[i]]$FromNode, OneKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
OneKMPaths7 <- cbind(FromNodes7, ToNodes7)
OneKMPaths7 <- unique(OneKMPaths7, incomparables = FALSE)
class(OneKMPaths7)
write.csv(OneKMPaths7, "OneKMPaths7.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections7[[i]]$FromNode, OneAndHalfKMConnections7[[i]]$ToNode),
	c(OneAndHalfKMConnections7[[i]]$FromNode, OneAndHalfKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
OneAndHalfKMPaths7 <- cbind(FromNodes7, ToNodes7)
OneAndHalfKMPaths7 <- unique(OneAndHalfKMPaths7, incomparables = FALSE)
class(OneAndHalfKMPaths7)
write.csv(OneAndHalfKMPaths7, "OneAndHalfKMPaths7.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos7 <- list(NA)
ToNode7 <- list(NA)
FromNode7 <- list(NA)
for(i in 1:length(TwoKMConnections7)){
	NodeCombos7[[i]] <- as.matrix(cbind(c(TwoKMConnections7[[i]]$FromNode, TwoKMConnections7[[i]]$ToNode),
	c(TwoKMConnections7[[i]]$FromNode, TwoKMConnections7[[i]]$ToNode)))
	j1 <- nrow(NodeCombos7[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos7[[i]])
	ToNode7[[i]] <- NodeCombos7[[i]][j2:j3, ]
	FromNode7[[i]] <- data.frame(rbind(NodeCombos7[[i]][j1, ]))
	FromNode7[[i]][1:j1, ] <- FromNode7[[i]]
}

#prepare beginning nodes
FromNodes7 <- data.frame(unlist(FromNode7))
FromNodes7 <- as.matrix(FromNodes7)

#prepare ending nodes
ToNodes7 <- data.frame(unlist(ToNode7))
ToNodes7 <- as.matrix(ToNodes7)

#bring nodes together as edges
TwoKMPaths7 <- cbind(FromNodes7, ToNodes7)
TwoKMPaths7 <- unique(TwoKMPaths7, incomparables = FALSE)
class(TwoKMPaths7)
write.csv(TwoKMPaths7, "TwoKMPaths7.csv")

#Part8
PathCombinations8 <- list(NA)
for(i in 1:1000){
	PathCombinations8[[i]] <- data.frame(FromNode = HistWets@data[7000 + i,]$NodeID)
	PathCombinations8[[i]][1:nrow(HistWets@data),] <- HistWets@data[7000 + i,]$NodeID
	PathCombinations8[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations8[[i]]$FromNodeXCoord <- HistWets@data[7000 + i,]$XCoord
	PathCombinations8[[i]]$FromNodeYCoord <- HistWets@data[7000 + i,]$YCoord
	PathCombinations8[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations8[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations8[[i]]$Repeat <- PathCombinations8[[i]]$FromNode != PathCombinations8[[i]]$ToNode
	PathCombinations8[[i]] <- PathCombinations8[[i]][PathCombinations8[[i]]$Repeat, ]
	PathCombinations8[[i]]$Distance <- distance(PathCombinations8[[i]]$FromNodeYCoord, PathCombinations8[[i]]$FromNodeXCoord, PathCombinations8[[i]]$ToNodeYCoord, PathCombinations8[[i]]$ToNodeXCoord)	
	PathCombinations8[[i]]$HalfKM <- PathCombinations8[[i]]$Distance$distance <= 500
	PathCombinations8[[i]]$OneKM <- PathCombinations8[[i]]$Distance$distance <= 1000
	PathCombinations8[[i]]$OneAndHalfKM <- PathCombinations8[[i]]$Distance$distance <= 1500
	PathCombinations8[[i]]$TwoKM <- PathCombinations8[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections8 <- list(NA)
OneKMConnections8 <- list(NA)
OneAndHalfKMConnections8 <- list(NA)
TwoKMConnections8 <- list(NA)
for(i in 1:1000){
	PathCombinations8[[i]] <- PathCombinations8[[i]][(7000 + i):nrow(PathCombinations8[[i]]), ]
	HalfKMConnections8[[i]] <- PathCombinations8[[i]][PathCombinations8[[i]]$HalfKM, ]
	OneKMConnections8[[i]] <- PathCombinations8[[i]][PathCombinations8[[i]]$OneKM, ]
	OneAndHalfKMConnections8[[i]] <- PathCombinations8[[i]][PathCombinations8[[i]]$OneAndHalfKM, ]
	TwoKMConnections8[[i]] <- PathCombinations8[[i]][PathCombinations8[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections8 <- HalfKMConnections8[sapply(HalfKMConnections8, function(x) dim(x)[1]) > 0]
OneKMConnections8 <- OneKMConnections8[sapply(OneKMConnections8, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections8 <- OneAndHalfKMConnections8[sapply(OneAndHalfKMConnections8, function(x) dim(x)[1]) > 0]
TwoKMConnections8 <- TwoKMConnections8[sapply(TwoKMConnections8, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos8 <- list(NA)
ToNode8 <- list(NA)
FromNode8 <- list(NA)
for(i in 1:length(HalfKMConnections8)){
	NodeCombos8[[i]] <- as.matrix(cbind(c(HalfKMConnections8[[i]]$FromNode, HalfKMConnections8[[i]]$ToNode),
	c(HalfKMConnections8[[i]]$FromNode, HalfKMConnections8[[i]]$ToNode)))
	j1 <- nrow(NodeCombos8[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos8[[i]])
	ToNode8[[i]] <- NodeCombos8[[i]][j2:j3, ]
	FromNode8[[i]] <- data.frame(rbind(NodeCombos8[[i]][j1, ]))
	FromNode8[[i]][1:j1, ] <- FromNode8[[i]]
}

#prepare beginning nodes
FromNodes8 <- data.frame(unlist(FromNode8))
FromNodes8 <- as.matrix(FromNodes8)

#prepare ending nodes
ToNodes8 <- data.frame(unlist(ToNode8))
ToNodes8 <- as.matrix(ToNodes8)

#bring nodes together as edges
HalfKMPaths8 <- cbind(FromNodes8, ToNodes8)
HalfKMPaths8 <- unique(HalfKMPaths8, incomparables = FALSE)
class(HalfKMPaths8)
write.csv(HalfKMPaths8, "HalfKMPaths8.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos8 <- list(NA)
ToNode8 <- list(NA)
FromNode8 <- list(NA)
for(i in 1:length(OneKMConnections8)){
	NodeCombos8[[i]] <- as.matrix(cbind(c(OneKMConnections8[[i]]$FromNode, OneKMConnections8[[i]]$ToNode),
	c(OneKMConnections8[[i]]$FromNode, OneKMConnections8[[i]]$ToNode)))
	j1 <- nrow(NodeCombos8[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos8[[i]])
	ToNode8[[i]] <- NodeCombos8[[i]][j2:j3, ]
	FromNode8[[i]] <- data.frame(rbind(NodeCombos8[[i]][j1, ]))
	FromNode8[[i]][1:j1, ] <- FromNode8[[i]]
}

#prepare beginning nodes
FromNodes8 <- data.frame(unlist(FromNode8))
FromNodes8 <- as.matrix(FromNodes8)

#prepare ending nodes
ToNodes8 <- data.frame(unlist(ToNode8))
ToNodes8 <- as.matrix(ToNodes8)

#bring nodes together as edges
OneKMPaths8 <- cbind(FromNodes8, ToNodes8)
OneKMPaths8 <- unique(OneKMPaths8, incomparables = FALSE)
class(OneKMPaths8)
write.csv(OneKMPaths8, "OneKMPaths8.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos8 <- list(NA)
ToNode8 <- list(NA)
FromNode8 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections8)){
	NodeCombos8[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections8[[i]]$FromNode, OneAndHalfKMConnections8[[i]]$ToNode),
	c(OneAndHalfKMConnections8[[i]]$FromNode, OneAndHalfKMConnections8[[i]]$ToNode)))
	j1 <- nrow(NodeCombos8[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos8[[i]])
	ToNode8[[i]] <- NodeCombos8[[i]][j2:j3, ]
	FromNode8[[i]] <- data.frame(rbind(NodeCombos8[[i]][j1, ]))
	FromNode8[[i]][1:j1, ] <- FromNode8[[i]]
}

#prepare beginning nodes
FromNodes8 <- data.frame(unlist(FromNode8))
FromNodes8 <- as.matrix(FromNodes8)

#prepare ending nodes
ToNodes8 <- data.frame(unlist(ToNode8))
ToNodes8 <- as.matrix(ToNodes8)

#bring nodes together as edges
OneAndHalfKMPaths8 <- cbind(FromNodes8, ToNodes8)
OneAndHalfKMPaths8 <- unique(OneAndHalfKMPaths8, incomparables = FALSE)
class(OneAndHalfKMPaths8)
write.csv(OneAndHalfKMPaths8, "OneAndHalfKMPaths8.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos8 <- list(NA)
ToNode8 <- list(NA)
FromNode8 <- list(NA)
for(i in 1:length(TwoKMConnections8)){
	NodeCombos8[[i]] <- as.matrix(cbind(c(TwoKMConnections8[[i]]$FromNode, TwoKMConnections8[[i]]$ToNode),
	c(TwoKMConnections8[[i]]$FromNode, TwoKMConnections8[[i]]$ToNode)))
	j1 <- nrow(NodeCombos8[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos8[[i]])
	ToNode8[[i]] <- NodeCombos8[[i]][j2:j3, ]
	FromNode8[[i]] <- data.frame(rbind(NodeCombos8[[i]][j1, ]))
	FromNode8[[i]][1:j1, ] <- FromNode8[[i]]
}

#prepare beginning nodes
FromNodes8 <- data.frame(unlist(FromNode8))
FromNodes8 <- as.matrix(FromNodes8)

#prepare ending nodes
ToNodes8 <- data.frame(unlist(ToNode8))
ToNodes8 <- as.matrix(ToNodes8)

#bring nodes together as edges
TwoKMPaths8 <- cbind(FromNodes8, ToNodes8)
TwoKMPaths8 <- unique(TwoKMPaths8, incomparables = FALSE)
class(TwoKMPaths8)
write.csv(TwoKMPaths8, "TwoKMPaths8.csv")

#Part9
PathCombinations9 <- list(NA)
for(i in 1:1000){
	PathCombinations9[[i]] <- data.frame(FromNode = HistWets@data[8000 + i,]$NodeID)
	PathCombinations9[[i]][1:nrow(HistWets@data),] <- HistWets@data[8000 + i,]$NodeID
	PathCombinations9[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations9[[i]]$FromNodeXCoord <- HistWets@data[8000 + i,]$XCoord
	PathCombinations9[[i]]$FromNodeYCoord <- HistWets@data[8000 + i,]$YCoord
	PathCombinations9[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations9[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations9[[i]]$Repeat <- PathCombinations9[[i]]$FromNode != PathCombinations9[[i]]$ToNode
	PathCombinations9[[i]] <- PathCombinations9[[i]][PathCombinations9[[i]]$Repeat, ]
	PathCombinations9[[i]]$Distance <- distance(PathCombinations9[[i]]$FromNodeYCoord, PathCombinations9[[i]]$FromNodeXCoord, PathCombinations9[[i]]$ToNodeYCoord, PathCombinations9[[i]]$ToNodeXCoord)	
	PathCombinations9[[i]]$HalfKM <- PathCombinations9[[i]]$Distance$distance <= 500
	PathCombinations9[[i]]$OneKM <- PathCombinations9[[i]]$Distance$distance <= 1000
	PathCombinations9[[i]]$OneAndHalfKM <- PathCombinations9[[i]]$Distance$distance <= 1500
	PathCombinations9[[i]]$TwoKM <- PathCombinations9[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections9 <- list(NA)
OneKMConnections9 <- list(NA)
OneAndHalfKMConnections9 <- list(NA)
TwoKMConnections9 <- list(NA)
for(i in 1:1000){
	PathCombinations9[[i]] <- PathCombinations9[[i]][(8000 + i):nrow(PathCombinations9[[i]]), ]
	HalfKMConnections9[[i]] <- PathCombinations9[[i]][PathCombinations9[[i]]$HalfKM, ]
	OneKMConnections9[[i]] <- PathCombinations9[[i]][PathCombinations9[[i]]$OneKM, ]
	OneAndHalfKMConnections9[[i]] <- PathCombinations9[[i]][PathCombinations9[[i]]$OneAndHalfKM, ]
	TwoKMConnections9[[i]] <- PathCombinations9[[i]][PathCombinations9[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections9 <- HalfKMConnections9[sapply(HalfKMConnections9, function(x) dim(x)[1]) > 0]
OneKMConnections9 <- OneKMConnections9[sapply(OneKMConnections9, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections9 <- OneAndHalfKMConnections9[sapply(OneAndHalfKMConnections9, function(x) dim(x)[1]) > 0]
TwoKMConnections9 <- TwoKMConnections9[sapply(TwoKMConnections9, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos9 <- list(NA)
ToNode9 <- list(NA)
FromNode9 <- list(NA)
for(i in 1:length(HalfKMConnections9)){
	NodeCombos9[[i]] <- as.matrix(cbind(c(HalfKMConnections9[[i]]$FromNode, HalfKMConnections9[[i]]$ToNode),
	c(HalfKMConnections9[[i]]$FromNode, HalfKMConnections9[[i]]$ToNode)))
	j1 <- nrow(NodeCombos9[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos9[[i]])
	ToNode9[[i]] <- NodeCombos9[[i]][j2:j3, ]
	FromNode9[[i]] <- data.frame(rbind(NodeCombos9[[i]][j1, ]))
	FromNode9[[i]][1:j1, ] <- FromNode9[[i]]
}

#prepare beginning nodes
FromNodes9 <- data.frame(unlist(FromNode9))
FromNodes9 <- as.matrix(FromNodes9)

#prepare ending nodes
ToNodes9 <- data.frame(unlist(ToNode9))
ToNodes9 <- as.matrix(ToNodes9)

#bring nodes together as edges
HalfKMPaths9 <- cbind(FromNodes9, ToNodes9)
HalfKMPaths9 <- unique(HalfKMPaths9, incomparables = FALSE)
class(HalfKMPaths9)
write.csv(HalfKMPaths9, "HalfKMPaths9.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos9 <- list(NA)
ToNode9 <- list(NA)
FromNode9 <- list(NA)
for(i in 1:length(OneKMConnections9)){
	NodeCombos9[[i]] <- as.matrix(cbind(c(OneKMConnections9[[i]]$FromNode, OneKMConnections9[[i]]$ToNode),
	c(OneKMConnections9[[i]]$FromNode, OneKMConnections9[[i]]$ToNode)))
	j1 <- nrow(NodeCombos9[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos9[[i]])
	ToNode9[[i]] <- NodeCombos9[[i]][j2:j3, ]
	FromNode9[[i]] <- data.frame(rbind(NodeCombos9[[i]][j1, ]))
	FromNode9[[i]][1:j1, ] <- FromNode9[[i]]
}

#prepare beginning nodes
FromNodes9 <- data.frame(unlist(FromNode9))
FromNodes9 <- as.matrix(FromNodes9)

#prepare ending nodes
ToNodes9 <- data.frame(unlist(ToNode9))
ToNodes9 <- as.matrix(ToNodes9)

#bring nodes together as edges
OneKMPaths9 <- cbind(FromNodes9, ToNodes9)
OneKMPaths9 <- unique(OneKMPaths9, incomparables = FALSE)
class(OneKMPaths9)
write.csv(OneKMPaths9, "OneKMPaths9.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos9 <- list(NA)
ToNode9 <- list(NA)
FromNode9 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections9)){
	NodeCombos9[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections9[[i]]$FromNode, OneAndHalfKMConnections9[[i]]$ToNode),
	c(OneAndHalfKMConnections9[[i]]$FromNode, OneAndHalfKMConnections9[[i]]$ToNode)))
	j1 <- nrow(NodeCombos9[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos9[[i]])
	ToNode9[[i]] <- NodeCombos9[[i]][j2:j3, ]
	FromNode9[[i]] <- data.frame(rbind(NodeCombos9[[i]][j1, ]))
	FromNode9[[i]][1:j1, ] <- FromNode9[[i]]
}

#prepare beginning nodes
FromNodes9 <- data.frame(unlist(FromNode9))
FromNodes9 <- as.matrix(FromNodes9)

#prepare ending nodes
ToNodes9 <- data.frame(unlist(ToNode9))
ToNodes9 <- as.matrix(ToNodes9)

#bring nodes together as edges
OneAndHalfKMPaths9 <- cbind(FromNodes9, ToNodes9)
OneAndHalfKMPaths9 <- unique(OneAndHalfKMPaths9, incomparables = FALSE)
class(OneAndHalfKMPaths9)
write.csv(OneAndHalfKMPaths9, "OneAndHalfKMPaths9.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos9 <- list(NA)
ToNode9 <- list(NA)
FromNode9 <- list(NA)
for(i in 1:length(TwoKMConnections9)){
	NodeCombos9[[i]] <- as.matrix(cbind(c(TwoKMConnections9[[i]]$FromNode, TwoKMConnections9[[i]]$ToNode),
	c(TwoKMConnections9[[i]]$FromNode, TwoKMConnections9[[i]]$ToNode)))
	j1 <- nrow(NodeCombos9[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos9[[i]])
	ToNode9[[i]] <- NodeCombos9[[i]][j2:j3, ]
	FromNode9[[i]] <- data.frame(rbind(NodeCombos9[[i]][j1, ]))
	FromNode9[[i]][1:j1, ] <- FromNode9[[i]]
}

#prepare beginning nodes
FromNodes9 <- data.frame(unlist(FromNode9))
FromNodes9 <- as.matrix(FromNodes9)

#prepare ending nodes
ToNodes9 <- data.frame(unlist(ToNode9))
ToNodes9 <- as.matrix(ToNodes9)

#bring nodes together as edges
TwoKMPaths9 <- cbind(FromNodes9, ToNodes9)
TwoKMPaths9 <- unique(TwoKMPaths9, incomparables = FALSE)
class(TwoKMPaths9)
write.csv(TwoKMPaths9, "TwoKMPaths9.csv")

#Part10
PathCombinations10 <- list(NA)
for(i in 1:1000){
	PathCombinations10[[i]] <- data.frame(FromNode = HistWets@data[9000 + i,]$NodeID)
	PathCombinations10[[i]][1:nrow(HistWets@data),] <- HistWets@data[9000 + i,]$NodeID
	PathCombinations10[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations10[[i]]$FromNodeXCoord <- HistWets@data[9000 + i,]$XCoord
	PathCombinations10[[i]]$FromNodeYCoord <- HistWets@data[9000 + i,]$YCoord
	PathCombinations10[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations10[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations10[[i]]$Repeat <- PathCombinations10[[i]]$FromNode != PathCombinations10[[i]]$ToNode
	PathCombinations10[[i]] <- PathCombinations10[[i]][PathCombinations10[[i]]$Repeat, ]
	PathCombinations10[[i]]$Distance <- distance(PathCombinations10[[i]]$FromNodeYCoord, PathCombinations10[[i]]$FromNodeXCoord, PathCombinations10[[i]]$ToNodeYCoord, PathCombinations10[[i]]$ToNodeXCoord)	
	PathCombinations10[[i]]$HalfKM <- PathCombinations10[[i]]$Distance$distance <= 500
	PathCombinations10[[i]]$OneKM <- PathCombinations10[[i]]$Distance$distance <= 1000
	PathCombinations10[[i]]$OneAndHalfKM <- PathCombinations10[[i]]$Distance$distance <= 1500
	PathCombinations10[[i]]$TwoKM <- PathCombinations10[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections10 <- list(NA)
OneKMConnections10 <- list(NA)
OneAndHalfKMConnections10 <- list(NA)
TwoKMConnections10 <- list(NA)
for(i in 1:1000){
	PathCombinations10[[i]] <- PathCombinations10[[i]][(9000 + i):nrow(PathCombinations10[[i]]), ]
	HalfKMConnections10[[i]] <- PathCombinations10[[i]][PathCombinations10[[i]]$HalfKM, ]
	OneKMConnections10[[i]] <- PathCombinations10[[i]][PathCombinations10[[i]]$OneKM, ]
	OneAndHalfKMConnections10[[i]] <- PathCombinations10[[i]][PathCombinations10[[i]]$OneAndHalfKM, ]
	TwoKMConnections10[[i]] <- PathCombinations10[[i]][PathCombinations10[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections10 <- HalfKMConnections10[sapply(HalfKMConnections10, function(x) dim(x)[1]) > 0]
OneKMConnections10 <- OneKMConnections10[sapply(OneKMConnections10, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections10 <- OneAndHalfKMConnections10[sapply(OneAndHalfKMConnections10, function(x) dim(x)[1]) > 0]
TwoKMConnections10 <- TwoKMConnections10[sapply(TwoKMConnections10, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos10 <- list(NA)
ToNode10 <- list(NA)
FromNode10 <- list(NA)
for(i in 1:length(HalfKMConnections10)){
	NodeCombos10[[i]] <- as.matrix(cbind(c(HalfKMConnections10[[i]]$FromNode, HalfKMConnections10[[i]]$ToNode),
	c(HalfKMConnections10[[i]]$FromNode, HalfKMConnections10[[i]]$ToNode)))
	j1 <- nrow(NodeCombos10[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos10[[i]])
	ToNode10[[i]] <- NodeCombos10[[i]][j2:j3, ]
	FromNode10[[i]] <- data.frame(rbind(NodeCombos10[[i]][j1, ]))
	FromNode10[[i]][1:j1, ] <- FromNode10[[i]]
}

#prepare beginning nodes
FromNodes10 <- data.frame(unlist(FromNode10))
FromNodes10 <- as.matrix(FromNodes10)

#prepare ending nodes
ToNodes10 <- data.frame(unlist(ToNode10))
ToNodes10 <- as.matrix(ToNodes10)

#bring nodes together as edges
HalfKMPaths10 <- cbind(FromNodes10, ToNodes10)
HalfKMPaths10 <- unique(HalfKMPaths10, incomparables = FALSE)
class(HalfKMPaths10)
write.csv(HalfKMPaths10, "HalfKMPaths10.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos10 <- list(NA)
ToNode10 <- list(NA)
FromNode10 <- list(NA)
for(i in 1:length(OneKMConnections10)){
	NodeCombos10[[i]] <- as.matrix(cbind(c(OneKMConnections10[[i]]$FromNode, OneKMConnections10[[i]]$ToNode),
	c(OneKMConnections10[[i]]$FromNode, OneKMConnections10[[i]]$ToNode)))
	j1 <- nrow(NodeCombos10[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos10[[i]])
	ToNode10[[i]] <- NodeCombos10[[i]][j2:j3, ]
	FromNode10[[i]] <- data.frame(rbind(NodeCombos10[[i]][j1, ]))
	FromNode10[[i]][1:j1, ] <- FromNode10[[i]]
}

#prepare beginning nodes
FromNodes10 <- data.frame(unlist(FromNode10))
FromNodes10 <- as.matrix(FromNodes10)

#prepare ending nodes
ToNodes10 <- data.frame(unlist(ToNode10))
ToNodes10 <- as.matrix(ToNodes10)

#bring nodes together as edges
OneKMPaths10 <- cbind(FromNodes10, ToNodes10)
OneKMPaths10 <- unique(OneKMPaths10, incomparables = FALSE)
class(OneKMPaths10)
write.csv(OneKMPaths10, "OneKMPaths10.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos10 <- list(NA)
ToNode10 <- list(NA)
FromNode10 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections10)){
	NodeCombos10[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections10[[i]]$FromNode, OneAndHalfKMConnections10[[i]]$ToNode),
	c(OneAndHalfKMConnections10[[i]]$FromNode, OneAndHalfKMConnections10[[i]]$ToNode)))
	j1 <- nrow(NodeCombos10[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos10[[i]])
	ToNode10[[i]] <- NodeCombos10[[i]][j2:j3, ]
	FromNode10[[i]] <- data.frame(rbind(NodeCombos10[[i]][j1, ]))
	FromNode10[[i]][1:j1, ] <- FromNode10[[i]]
}

#prepare beginning nodes
FromNodes10 <- data.frame(unlist(FromNode10))
FromNodes10 <- as.matrix(FromNodes10)

#prepare ending nodes
ToNodes10 <- data.frame(unlist(ToNode10))
ToNodes10 <- as.matrix(ToNodes10)

#bring nodes together as edges
OneAndHalfKMPaths10 <- cbind(FromNodes10, ToNodes10)
OneAndHalfKMPaths10 <- unique(OneAndHalfKMPaths10, incomparables = FALSE)
class(OneAndHalfKMPaths10)
write.csv(OneAndHalfKMPaths10, "OneAndHalfKMPaths10.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos10 <- list(NA)
ToNode10 <- list(NA)
FromNode10 <- list(NA)
for(i in 1:length(TwoKMConnections10)){
	NodeCombos10[[i]] <- as.matrix(cbind(c(TwoKMConnections10[[i]]$FromNode, TwoKMConnections10[[i]]$ToNode),
	c(TwoKMConnections10[[i]]$FromNode, TwoKMConnections10[[i]]$ToNode)))
	j1 <- nrow(NodeCombos10[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos10[[i]])
	ToNode10[[i]] <- NodeCombos10[[i]][j2:j3, ]
	FromNode10[[i]] <- data.frame(rbind(NodeCombos10[[i]][j1, ]))
	FromNode10[[i]][1:j1, ] <- FromNode10[[i]]
}

#prepare beginning nodes
FromNodes10 <- data.frame(unlist(FromNode10))
FromNodes10 <- as.matrix(FromNodes10)

#prepare ending nodes
ToNodes10 <- data.frame(unlist(ToNode10))
ToNodes10 <- as.matrix(ToNodes10)

#bring nodes together as edges
TwoKMPaths10 <- cbind(FromNodes10, ToNodes10)
TwoKMPaths10 <- unique(TwoKMPaths10, incomparables = FALSE)
class(TwoKMPaths10)
write.csv(TwoKMPaths10, "TwoKMPaths10.csv")

#Part11
PathCombinations11 <- list(NA)
for(i in 1:1000){
	PathCombinations11[[i]] <- data.frame(FromNode = HistWets@data[10000 + i,]$NodeID)
	PathCombinations11[[i]][1:nrow(HistWets@data),] <- HistWets@data[10000 + i,]$NodeID
	PathCombinations11[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations11[[i]]$FromNodeXCoord <- HistWets@data[10000 + i,]$XCoord
	PathCombinations11[[i]]$FromNodeYCoord <- HistWets@data[10000 + i,]$YCoord
	PathCombinations11[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations11[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations11[[i]]$Repeat <- PathCombinations11[[i]]$FromNode != PathCombinations11[[i]]$ToNode
	PathCombinations11[[i]] <- PathCombinations11[[i]][PathCombinations11[[i]]$Repeat, ]
	PathCombinations11[[i]]$Distance <- distance(PathCombinations11[[i]]$FromNodeYCoord, PathCombinations11[[i]]$FromNodeXCoord, PathCombinations11[[i]]$ToNodeYCoord, PathCombinations11[[i]]$ToNodeXCoord)	
	PathCombinations11[[i]]$HalfKM <- PathCombinations11[[i]]$Distance$distance <= 500
	PathCombinations11[[i]]$OneKM <- PathCombinations11[[i]]$Distance$distance <= 1000
	PathCombinations11[[i]]$OneAndHalfKM <- PathCombinations11[[i]]$Distance$distance <= 1500
	PathCombinations11[[i]]$TwoKM <- PathCombinations11[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections11 <- list(NA)
OneKMConnections11 <- list(NA)
OneAndHalfKMConnections11 <- list(NA)
TwoKMConnections11 <- list(NA)
for(i in 1:1000){
	PathCombinations11[[i]] <- PathCombinations11[[i]][(10000 + i):nrow(PathCombinations11[[i]]), ]
	HalfKMConnections11[[i]] <- PathCombinations11[[i]][PathCombinations11[[i]]$HalfKM, ]
	OneKMConnections11[[i]] <- PathCombinations11[[i]][PathCombinations11[[i]]$OneKM, ]
	OneAndHalfKMConnections11[[i]] <- PathCombinations11[[i]][PathCombinations11[[i]]$OneAndHalfKM, ]
	TwoKMConnections11[[i]] <- PathCombinations11[[i]][PathCombinations11[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections11 <- HalfKMConnections11[sapply(HalfKMConnections11, function(x) dim(x)[1]) > 0]
OneKMConnections11 <- OneKMConnections11[sapply(OneKMConnections11, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections11 <- OneAndHalfKMConnections11[sapply(OneAndHalfKMConnections11, function(x) dim(x)[1]) > 0]
TwoKMConnections11 <- TwoKMConnections11[sapply(TwoKMConnections11, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos11 <- list(NA)
ToNode11 <- list(NA)
FromNode11 <- list(NA)
for(i in 1:length(HalfKMConnections11)){
	NodeCombos11[[i]] <- as.matrix(cbind(c(HalfKMConnections11[[i]]$FromNode, HalfKMConnections11[[i]]$ToNode),
	c(HalfKMConnections11[[i]]$FromNode, HalfKMConnections11[[i]]$ToNode)))
	j1 <- nrow(NodeCombos11[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos11[[i]])
	ToNode11[[i]] <- NodeCombos11[[i]][j2:j3, ]
	FromNode11[[i]] <- data.frame(rbind(NodeCombos11[[i]][j1, ]))
	FromNode11[[i]][1:j1, ] <- FromNode11[[i]]
}

#prepare beginning nodes
FromNodes11 <- data.frame(unlist(FromNode11))
FromNodes11 <- as.matrix(FromNodes11)

#prepare ending nodes
ToNodes11 <- data.frame(unlist(ToNode11))
ToNodes11 <- as.matrix(ToNodes11)

#bring nodes together as edges
HalfKMPaths11 <- cbind(FromNodes11, ToNodes11)
HalfKMPaths11 <- unique(HalfKMPaths11, incomparables = FALSE)
class(HalfKMPaths11)
write.csv(HalfKMPaths11, "HalfKMPaths11.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos11 <- list(NA)
ToNode11 <- list(NA)
FromNode11 <- list(NA)
for(i in 1:length(OneKMConnections11)){
	NodeCombos11[[i]] <- as.matrix(cbind(c(OneKMConnections11[[i]]$FromNode, OneKMConnections11[[i]]$ToNode),
	c(OneKMConnections11[[i]]$FromNode, OneKMConnections11[[i]]$ToNode)))
	j1 <- nrow(NodeCombos11[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos11[[i]])
	ToNode11[[i]] <- NodeCombos11[[i]][j2:j3, ]
	FromNode11[[i]] <- data.frame(rbind(NodeCombos11[[i]][j1, ]))
	FromNode11[[i]][1:j1, ] <- FromNode11[[i]]
}

#prepare beginning nodes
FromNodes11 <- data.frame(unlist(FromNode11))
FromNodes11 <- as.matrix(FromNodes11)

#prepare ending nodes
ToNodes11 <- data.frame(unlist(ToNode11))
ToNodes11 <- as.matrix(ToNodes11)

#bring nodes together as edges
OneKMPaths11 <- cbind(FromNodes11, ToNodes11)
OneKMPaths11 <- unique(OneKMPaths11, incomparables = FALSE)
class(OneKMPaths11)
write.csv(OneKMPaths11, "OneKMPaths11.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos11 <- list(NA)
ToNode11 <- list(NA)
FromNode11 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections11)){
	NodeCombos11[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections11[[i]]$FromNode, OneAndHalfKMConnections11[[i]]$ToNode),
	c(OneAndHalfKMConnections11[[i]]$FromNode, OneAndHalfKMConnections11[[i]]$ToNode)))
	j1 <- nrow(NodeCombos11[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos11[[i]])
	ToNode11[[i]] <- NodeCombos11[[i]][j2:j3, ]
	FromNode11[[i]] <- data.frame(rbind(NodeCombos11[[i]][j1, ]))
	FromNode11[[i]][1:j1, ] <- FromNode11[[i]]
}

#prepare beginning nodes
FromNodes11 <- data.frame(unlist(FromNode11))
FromNodes11 <- as.matrix(FromNodes11)

#prepare ending nodes
ToNodes11 <- data.frame(unlist(ToNode11))
ToNodes11 <- as.matrix(ToNodes11)

#bring nodes together as edges
OneAndHalfKMPaths11 <- cbind(FromNodes11, ToNodes11)
OneAndHalfKMPaths11 <- unique(OneAndHalfKMPaths11, incomparables = FALSE)
class(OneAndHalfKMPaths11)
write.csv(OneAndHalfKMPaths11, "OneAndHalfKMPaths11.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos11 <- list(NA)
ToNode11 <- list(NA)
FromNode11 <- list(NA)
for(i in 1:length(TwoKMConnections11)){
	NodeCombos11[[i]] <- as.matrix(cbind(c(TwoKMConnections11[[i]]$FromNode, TwoKMConnections11[[i]]$ToNode),
	c(TwoKMConnections11[[i]]$FromNode, TwoKMConnections11[[i]]$ToNode)))
	j1 <- nrow(NodeCombos11[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos11[[i]])
	ToNode11[[i]] <- NodeCombos11[[i]][j2:j3, ]
	FromNode11[[i]] <- data.frame(rbind(NodeCombos11[[i]][j1, ]))
	FromNode11[[i]][1:j1, ] <- FromNode11[[i]]
}

#prepare beginning nodes
FromNodes11 <- data.frame(unlist(FromNode11))
FromNodes11 <- as.matrix(FromNodes11)

#prepare ending nodes
ToNodes11 <- data.frame(unlist(ToNode11))
ToNodes11 <- as.matrix(ToNodes11)

#bring nodes together as edges
TwoKMPaths11 <- cbind(FromNodes11, ToNodes11)
TwoKMPaths11 <- unique(TwoKMPaths11, incomparables = FALSE)
class(TwoKMPaths11)
write.csv(TwoKMPaths11, "TwoKMPaths11.csv")

#Part12
PathCombinations12 <- list(NA)
for(i in 1:711){
	PathCombinations12[[i]] <- data.frame(FromNode = HistWets@data[11000 + i,]$NodeID)
	PathCombinations12[[i]][1:nrow(HistWets@data),] <- HistWets@data[11000 + i,]$NodeID
	PathCombinations12[[i]]$ToNode <- HistWets@data$NodeID
	PathCombinations12[[i]]$FromNodeXCoord <- HistWets@data[11000 + i,]$XCoord
	PathCombinations12[[i]]$FromNodeYCoord <- HistWets@data[11000 + i,]$YCoord
	PathCombinations12[[i]]$ToNodeXCoord <- HistWets@data$XCoord
	PathCombinations12[[i]]$ToNodeYCoord <- HistWets@data$YCoord
	PathCombinations12[[i]]$Repeat <- PathCombinations12[[i]]$FromNode != PathCombinations12[[i]]$ToNode
	PathCombinations12[[i]] <- PathCombinations12[[i]][PathCombinations12[[i]]$Repeat, ]
	PathCombinations12[[i]]$Distance <- distance(PathCombinations12[[i]]$FromNodeYCoord, PathCombinations12[[i]]$FromNodeXCoord, PathCombinations12[[i]]$ToNodeYCoord, PathCombinations12[[i]]$ToNodeXCoord)	
	PathCombinations12[[i]]$HalfKM <- PathCombinations12[[i]]$Distance$distance <= 500
	PathCombinations12[[i]]$OneKM <- PathCombinations12[[i]]$Distance$distance <= 1000
	PathCombinations12[[i]]$OneAndHalfKM <- PathCombinations12[[i]]$Distance$distance <= 1500
	PathCombinations12[[i]]$TwoKM <- PathCombinations12[[i]]$Distance$distance <= 2000
}	

#remove backwards duplicates
HalfKMConnections12 <- list(NA)
OneKMConnections12 <- list(NA)
OneAndHalfKMConnections12 <- list(NA)
TwoKMConnections12 <- list(NA)
for(i in 1:711){
	PathCombinations12[[i]] <- PathCombinations12[[i]][(11000 + i):nrow(PathCombinations12[[i]]), ]
	HalfKMConnections12[[i]] <- PathCombinations12[[i]][PathCombinations12[[i]]$HalfKM, ]
	OneKMConnections12[[i]] <- PathCombinations12[[i]][PathCombinations12[[i]]$OneKM, ]
	OneAndHalfKMConnections12[[i]] <- PathCombinations12[[i]][PathCombinations12[[i]]$OneAndHalfKM, ]
	TwoKMConnections12[[i]] <- PathCombinations12[[i]][PathCombinations12[[i]]$TwoKM, ]
}

#remove empty elements from lists
HalfKMConnections12 <- HalfKMConnections12[sapply(HalfKMConnections12, function(x) dim(x)[1]) > 0]
OneKMConnections12 <- OneKMConnections12[sapply(OneKMConnections12, function(x) dim(x)[1]) > 0]
OneAndHalfKMConnections12 <- OneAndHalfKMConnections12[sapply(OneAndHalfKMConnections12, function(x) dim(x)[1]) > 0]
TwoKMConnections12 <- TwoKMConnections12[sapply(TwoKMConnections12, function(x) dim(x)[1]) > 0]

#0.5 KM
#(Network analysis portion)obtain matrices of point-point combinations for contructing edges
NodeCombos12 <- list(NA)
ToNode12 <- list(NA)
FromNode12 <- list(NA)
for(i in 1:length(HalfKMConnections12)){
	NodeCombos12[[i]] <- as.matrix(cbind(c(HalfKMConnections12[[i]]$FromNode, HalfKMConnections12[[i]]$ToNode),
	c(HalfKMConnections12[[i]]$FromNode, HalfKMConnections12[[i]]$ToNode)))
	j1 <- nrow(NodeCombos12[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos12[[i]])
	ToNode12[[i]] <- NodeCombos12[[i]][j2:j3, ]
	FromNode12[[i]] <- data.frame(rbind(NodeCombos12[[i]][j1, ]))
	FromNode12[[i]][1:j1, ] <- FromNode12[[i]]
}

#prepare beginning nodes
FromNodes12 <- data.frame(unlist(FromNode12))
FromNodes12 <- as.matrix(FromNodes12)

#prepare ending nodes
ToNodes12 <- data.frame(unlist(ToNode12))
ToNodes12 <- as.matrix(ToNodes12)

#bring nodes together as edges
HalfKMPaths12 <- cbind(FromNodes12, ToNodes12)
HalfKMPaths12 <- unique(HalfKMPaths12, incomparables = FALSE)
class(HalfKMPaths12)
write.csv(HalfKMPaths12, "HalfKMPaths12.csv")

#1.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos12 <- list(NA)
ToNode12 <- list(NA)
FromNode12 <- list(NA)
for(i in 1:length(OneKMConnections12)){
	NodeCombos12[[i]] <- as.matrix(cbind(c(OneKMConnections12[[i]]$FromNode, OneKMConnections12[[i]]$ToNode),
	c(OneKMConnections12[[i]]$FromNode, OneKMConnections12[[i]]$ToNode)))
	j1 <- nrow(NodeCombos12[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos12[[i]])
	ToNode12[[i]] <- NodeCombos12[[i]][j2:j3, ]
	FromNode12[[i]] <- data.frame(rbind(NodeCombos12[[i]][j1, ]))
	FromNode12[[i]][1:j1, ] <- FromNode12[[i]]
}

#prepare beginning nodes
FromNodes12 <- data.frame(unlist(FromNode12))
FromNodes12 <- as.matrix(FromNodes12)

#prepare ending nodes
ToNodes12 <- data.frame(unlist(ToNode12))
ToNodes12 <- as.matrix(ToNodes12)

#bring nodes together as edges
OneKMPaths12 <- cbind(FromNodes12, ToNodes12)
OneKMPaths12 <- unique(OneKMPaths12, incomparables = FALSE)
class(OneKMPaths12)
write.csv(OneKMPaths12, "OneKMPaths12.csv")

#1.5 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos12 <- list(NA)
ToNode12 <- list(NA)
FromNode12 <- list(NA)
for(i in 1:length(OneAndHalfKMConnections12)){
	NodeCombos12[[i]] <- as.matrix(cbind(c(OneAndHalfKMConnections12[[i]]$FromNode, OneAndHalfKMConnections12[[i]]$ToNode),
	c(OneAndHalfKMConnections12[[i]]$FromNode, OneAndHalfKMConnections12[[i]]$ToNode)))
	j1 <- nrow(NodeCombos12[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos12[[i]])
	ToNode12[[i]] <- NodeCombos12[[i]][j2:j3, ]
	FromNode12[[i]] <- data.frame(rbind(NodeCombos12[[i]][j1, ]))
	FromNode12[[i]][1:j1, ] <- FromNode12[[i]]
}

#prepare beginning nodes
FromNodes12 <- data.frame(unlist(FromNode12))
FromNodes12 <- as.matrix(FromNodes12)

#prepare ending nodes
ToNodes12 <- data.frame(unlist(ToNode12))
ToNodes12 <- as.matrix(ToNodes12)

#bring nodes together as edges
OneAndHalfKMPaths12 <- cbind(FromNodes12, ToNodes12)
OneAndHalfKMPaths12 <- unique(OneAndHalfKMPaths12, incomparables = FALSE)
class(OneAndHalfKMPaths12)
write.csv(OneAndHalfKMPaths12, "OneAndHalfKMPaths12.csv")

#2.0 KM
#obtain matrices of point-point combinations for contructing edges
NodeCombos12 <- list(NA)
ToNode12 <- list(NA)
FromNode12 <- list(NA)
for(i in 1:length(TwoKMConnections12)){
	NodeCombos12[[i]] <- as.matrix(cbind(c(TwoKMConnections12[[i]]$FromNode, TwoKMConnections12[[i]]$ToNode),
	c(TwoKMConnections12[[i]]$FromNode, TwoKMConnections12[[i]]$ToNode)))
	j1 <- nrow(NodeCombos12[[i]]) / 2
	j2 <- j1 + 1
	j3 <- nrow(NodeCombos12[[i]])
	ToNode12[[i]] <- NodeCombos12[[i]][j2:j3, ]
	FromNode12[[i]] <- data.frame(rbind(NodeCombos12[[i]][j1, ]))
	FromNode12[[i]][1:j1, ] <- FromNode12[[i]]
}

#prepare beginning nodes
FromNodes12 <- data.frame(unlist(FromNode12))
FromNodes12 <- as.matrix(FromNodes12)

#prepare ending nodes
ToNodes12 <- data.frame(unlist(ToNode12))
ToNodes12 <- as.matrix(ToNodes12)

#bring nodes together as edges
TwoKMPaths12 <- cbind(FromNodes12, ToNodes12)
TwoKMPaths12 <- unique(TwoKMPaths12, incomparables = FALSE)
class(TwoKMPaths12)
write.csv(TwoKMPaths12, "TwoKMPaths12.csv")