#increase memory limit of R to 3000 MB
memory.limit(size = 4000)

#read in packages
library(rgdal)
library(sp)
library(SDMTools)
library(igraph)

#read in contemporary wetlands and pits shapefile
ContWetsAndPits <- readOGR("G:/NewBackup/GIS/RWBWetlandConnectivity/base/ContWetsAndPitsPntsGeographic.shp", "ContWetsAndPitsPntsGeographic", verbose = TRUE, p4s = NULL)

#read in and modify csv files of node connections forming dispersal paths at 4 dispersal distances
#####
#####
#####
#0.5 km
retain <- c("FromNode", "ToNode")
HalfKMPaths1 <- read.csv("HalfKMPaths1.csv")
HalfKMPaths1$FromNode <- HalfKMPaths1$unlist.FromNode1.
HalfKMPaths1$ToNode <- HalfKMPaths1$unlist.ToNode1.
HalfKMPaths1 <- HalfKMPaths1[retain]

HalfKMPaths2 <- read.csv("HalfKMPaths2.csv")
HalfKMPaths2$FromNode <- HalfKMPaths2$unlist.FromNode2.
HalfKMPaths2$ToNode <- HalfKMPaths2$unlist.ToNode2.
HalfKMPaths2 <- HalfKMPaths2[retain]

HalfKMPaths3 <- read.csv("HalfKMPaths3.csv")
HalfKMPaths3$FromNode <- HalfKMPaths3$unlist.FromNode3.
HalfKMPaths3$ToNode <- HalfKMPaths3$unlist.ToNode3.
HalfKMPaths3 <- HalfKMPaths3[retain]

HalfKMPaths4 <- read.csv("HalfKMPaths4.csv")
HalfKMPaths4$FromNode <- HalfKMPaths4$unlist.FromNode4.
HalfKMPaths4$ToNode <- HalfKMPaths4$unlist.ToNode4.
HalfKMPaths4 <- HalfKMPaths4[retain]

HalfKMPaths5 <- read.csv("HalfKMPaths5.csv")
HalfKMPaths5$FromNode <- HalfKMPaths5$unlist.FromNode5.
HalfKMPaths5$ToNode <- HalfKMPaths5$unlist.ToNode5.
HalfKMPaths5 <- HalfKMPaths5[retain]

HalfKMPaths6 <- read.csv("HalfKMPaths6.csv")
HalfKMPaths6$FromNode <- HalfKMPaths6$unlist.FromNode6.
HalfKMPaths6$ToNode <- HalfKMPaths6$unlist.ToNode6.
HalfKMPaths6 <- HalfKMPaths6[retain]

HalfKMPaths7 <- read.csv("HalfKMPaths7.csv")
HalfKMPaths7$FromNode <- HalfKMPaths7$unlist.FromNode7.
HalfKMPaths7$ToNode <- HalfKMPaths7$unlist.ToNode7.
HalfKMPaths7 <- HalfKMPaths7[retain]

#combine 0.5 km connections into 1 data frame
HalfKMPathsCombined <- rbind(HalfKMPaths1, HalfKMPaths2, HalfKMPaths3, HalfKMPaths4, HalfKMPaths5, HalfKMPaths6, HalfKMPaths7)
HalfKMPathsCombined <- as.matrix(HalfKMPathsCombined[-3318,])
HalfKMPathsCombined

#create network with nodes and associated edges
HalfKMNetwork <- graph(n = 10161, edges = HalfKMPathsCombined, directed = FALSE)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
HalfKMNodeBetweenness <- betweenness(HalfKMNetwork, v = V(HalfKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
HalfKMNodeBetweenness
MeanNodeBetweennessHalfKM <- mean(HalfKMNodeBetweenness)
MeanNodeBetweennessHalfKM

HalfKMEdgeBetweenness <- edge.betweenness(HalfKMNetwork, e = E(HalfKMNetwork), directed = FALSE, weights = NULL)
HalfKMEdgeBetweenness
MeanEdgeBetweennessHalfKM <- mean(HalfKMEdgeBetweenness)
MeanEdgeBetweennessHalfKM

#calculate degree (number of adjacent edges for each node)
DegreeHalfKMNetwork <- degree(HalfKMNetwork, v = V(HalfKMNetwork), loops = TRUE)
DegreeHalfKMNetwork
MeanDegreeHalfKMNetwork <- mean(DegreeHalfKMNetwork)
MeanDegreeHalfKMNetwork

#find number of clusters (groups of connected graph components)
HalfKMNetworkNumberClusters <- no.clusters(HalfKMNetwork)
HalfKMNetworkNumberClusters

#find mean number of vertices per cluster
HalfKMNetworkClusters <- clusters(HalfKMNetwork)
summary(HalfKMNetworkClusters$csize)
HalfKMNetworkMeanClusterSize <- mean(HalfKMNetworkClusters$csize)
HalfKMNetworkMeanClusterSize

#calculate modularity
HalfKMNetworkModularity <- modularity(HalfKMNetwork, V(HalfKMNetwork))
HalfKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
HalfKMNetworkSC <- list(NA)
NumberReachedHalfKM <- list(NA)
for(i in 1:nrow(ContWetsAndPits@data)){
	HalfKMNetworkSC[[i]] <- subcomponent(HalfKMNetwork, v = i)
	NumberReachedHalfKM[[i]] <- length(HalfKMNetworkSC[[i]]) - 1
}
NumberReachedHalfKM <- unlist(NumberReachedHalfKM)
NumberReachedHalfKMMean <- mean(NumberReachedHalfKM)
NumberReachedHalfKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
HalfKMNetworkEBC <- edge.betweenness.community(HalfKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
HalfKMNetworkEVCENT <- evcent(HalfKMNetwork, directed = FALSE, scale = FALSE)
HalfKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
HalfKMNetworkGraphDensity <- graph.density(HalfKMNetwork, loops = TRUE)
HalfKMNetworkGraphDensity

#identify neighbors of each vertice
HalfKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWetsAndPits@data)){
	HalfKMNetworkNeighbors[[i]] <- neighbors(HalfKMNetwork, v = i)
}
HalfKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
HalfKMNetworkNeighborSize <- neighborhood.size(HalfKMNetwork, order = 1, nodes = V(HalfKMNetwork))
HalfKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
HalfKMNetworkGraphCohesion <- graph.cohesion(HalfKMNetwork)
HalfKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
HalfKMNetworkAPL <- average.path.length(HalfKMNetwork, directed = FALSE, unconnected = TRUE)
HalfKMNetworkAPL

#generate histogram of shortest path lengths
HalfKMNetworkAPLHist <- path.length.hist(HalfKMNetwork, directed = FALSE)
HalfKMNetworkAPLHist

#update and re-write attribute table, prior to dealing with memory allocation issues
ContWetsAndPits@data$Degree <- DegreeHalfKMNetwork
ContWetsAndPits@data$NodeBetween <- HalfKMNodeBetweenness
writeOGR(ContWetsAndPits, "ContWetsAndPitsHalfKMNetwork1", "ContWetsAndPitsHalfKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#experiment with deleting vertices/edges
#####
#####
#####
#part 1
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval1.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval1.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval1.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval1.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval1.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval1.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval1.csv")
write.csv(ModularityRemoval, "ModularityRemoval1.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval1.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval1.csv")

#####
#####
#####
#part 2
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (1000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (1000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[1001:2000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[1001:2000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval2.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval2.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval2.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval2.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval2.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval2.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval2.csv")
write.csv(ModularityRemoval, "ModularityRemoval2.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval2.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval2.csv")

#####
#####
#####
#part 3
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (2000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (2000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[2001:3000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[2001:3000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval3.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval3.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval3.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval3.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval3.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval3.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval3.csv")
write.csv(ModularityRemoval, "ModularityRemoval3.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval3.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval3.csv")

#####
#####
#####
#part 4
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (3000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (3000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[3001:4000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[3001:4000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval4.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval4.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval4.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval4.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval4.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval4.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval4.csv")
write.csv(ModularityRemoval, "ModularityRemoval4.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval4.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval4.csv")

#####
#####
#####
#part 5
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (4000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (4000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[4001:5000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[4001:5000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval5.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval5.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval5.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval5.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval5.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval5.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval5.csv")
write.csv(ModularityRemoval, "ModularityRemoval5.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval5.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval5.csv")

#####
#####
#####
#part 6
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (5000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (5000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[5001:6000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[5001:6000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval6.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval6.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval6.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval6.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval6.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval6.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval6.csv")
write.csv(ModularityRemoval, "ModularityRemoval6.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval6.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval6.csv")

#####
#####
#####
#part 7
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (6000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (6000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[6001:7000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[6001:7000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval7.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval7.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval7.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval7.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval7.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval7.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval7.csv")
write.csv(ModularityRemoval, "ModularityRemoval7.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval7.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval7.csv")

#####
#####
#####
#part 8
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (7000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (7000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[7001:8000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[7001:8000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval8.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval8.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval8.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval8.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval8.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval8.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval8.csv")
write.csv(ModularityRemoval, "ModularityRemoval8.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval8.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval8.csv")

#####
#####
#####
#part 9
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (8000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (8000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[8001:9000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[8001:9000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval9.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval9.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval9.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval9.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval9.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval9.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval9.csv")
write.csv(ModularityRemoval, "ModularityRemoval9.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval9.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval9.csv")

#####
#####
#####
#part 10
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (9000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (9000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[9001:10000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[9001:10000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval10.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval10.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval10.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval10.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval10.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval10.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval10.csv")
write.csv(ModularityRemoval, "ModularityRemoval10.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval10.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval10.csv")

#####
#####
#####
#part 11
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:161){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (10000 + i)
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:161){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - (10000 + i)
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[10001:10161,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[10001:10161,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval11.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval11.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval11.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval11.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval11.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval11.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval11.csv")
write.csv(ModularityRemoval, "ModularityRemoval11.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval11.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval11.csv")

#read back in outputs from 11 parts
#MeanNodeDegreeRemoval
MeanNodeDegreeRemoval1 <- read.csv("MeanNodeDegreeRemoval1.csv", header = TRUE)
MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[,-1]
MeanNodeDegreeRemoval2 <- read.csv("MeanNodeDegreeRemoval2.csv", header = TRUE)
MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[,-1]
MeanNodeDegreeRemoval3 <- read.csv("MeanNodeDegreeRemoval3.csv", header = TRUE)
MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[,-1]
MeanNodeDegreeRemoval4 <- read.csv("MeanNodeDegreeRemoval4.csv", header = TRUE)
MeanNodeDegreeRemoval4 <- MeanNodeDegreeRemoval4[,-1]
MeanNodeDegreeRemoval5 <- read.csv("MeanNodeDegreeRemoval5.csv", header = TRUE)
MeanNodeDegreeRemoval5 <- MeanNodeDegreeRemoval5[,-1]
MeanNodeDegreeRemoval6 <- read.csv("MeanNodeDegreeRemoval6.csv", header = TRUE)
MeanNodeDegreeRemoval6 <- MeanNodeDegreeRemoval6[,-1]
MeanNodeDegreeRemoval7 <- read.csv("MeanNodeDegreeRemoval7.csv", header = TRUE)
MeanNodeDegreeRemoval7 <- MeanNodeDegreeRemoval7[,-1]
MeanNodeDegreeRemoval8 <- read.csv("MeanNodeDegreeRemoval8.csv", header = TRUE)
MeanNodeDegreeRemoval8 <- MeanNodeDegreeRemoval8[,-1]
MeanNodeDegreeRemoval9 <- read.csv("MeanNodeDegreeRemoval9.csv", header = TRUE)
MeanNodeDegreeRemoval9 <- MeanNodeDegreeRemoval9[,-1]
MeanNodeDegreeRemoval10 <- read.csv("MeanNodeDegreeRemoval10.csv", header = TRUE)
MeanNodeDegreeRemoval10 <- MeanNodeDegreeRemoval10[,-1]
MeanNodeDegreeRemoval11 <- read.csv("MeanNodeDegreeRemoval11.csv", header = TRUE)
MeanNodeDegreeRemoval11 <- MeanNodeDegreeRemoval11[,-1]

#DegreeCentralizationRemoval
DegreeCentralizationRemoval1 <- read.csv("DegreeCentralizationRemoval1.csv", header = TRUE)
DegreeCentralizationRemoval1 <- DegreeCentralizationRemoval1[,-1]
DegreeCentralizationRemoval2 <- read.csv("DegreeCentralizationRemoval2.csv", header = TRUE)
DegreeCentralizationRemoval2 <- DegreeCentralizationRemoval2[,-1]
DegreeCentralizationRemoval3 <- read.csv("DegreeCentralizationRemoval3.csv", header = TRUE)
DegreeCentralizationRemoval3 <- DegreeCentralizationRemoval3[,-1]
DegreeCentralizationRemoval4 <- read.csv("DegreeCentralizationRemoval4.csv", header = TRUE)
DegreeCentralizationRemoval4 <- DegreeCentralizationRemoval4[,-1]
DegreeCentralizationRemoval5 <- read.csv("DegreeCentralizationRemoval5.csv", header = TRUE)
DegreeCentralizationRemoval5 <- DegreeCentralizationRemoval5[,-1]
DegreeCentralizationRemoval6 <- read.csv("DegreeCentralizationRemoval6.csv", header = TRUE)
DegreeCentralizationRemoval6 <- DegreeCentralizationRemoval6[,-1]
DegreeCentralizationRemoval7 <- read.csv("DegreeCentralizationRemoval7.csv", header = TRUE)
DegreeCentralizationRemoval7 <- DegreeCentralizationRemoval7[,-1]
DegreeCentralizationRemoval8 <- read.csv("DegreeCentralizationRemoval8.csv", header = TRUE)
DegreeCentralizationRemoval8 <- DegreeCentralizationRemoval8[,-1]
DegreeCentralizationRemoval9 <- read.csv("DegreeCentralizationRemoval9.csv", header = TRUE)
DegreeCentralizationRemoval9 <- DegreeCentralizationRemoval9[,-1]
DegreeCentralizationRemoval10 <- read.csv("DegreeCentralizationRemoval10.csv", header = TRUE)
DegreeCentralizationRemoval10 <- DegreeCentralizationRemoval10[,-1]
DegreeCentralizationRemoval11 <- read.csv("DegreeCentralizationRemoval11.csv", header = TRUE)
DegreeCentralizationRemoval11 <- DegreeCentralizationRemoval11[,-1]

#MeanNodeBetweennessRemoval
MeanNodeBetweennessRemoval1 <- read.csv("MeanNodeBetweennessRemoval1.csv", header = TRUE)
MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[,-1]
MeanNodeBetweennessRemoval2 <- read.csv("MeanNodeBetweennessRemoval2.csv", header = TRUE)
MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[,-1]
MeanNodeBetweennessRemoval3 <- read.csv("MeanNodeBetweennessRemoval3.csv", header = TRUE)
MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[,-1]
MeanNodeBetweennessRemoval4 <- read.csv("MeanNodeBetweennessRemoval4.csv", header = TRUE)
MeanNodeBetweennessRemoval4 <- MeanNodeBetweennessRemoval4[,-1]
MeanNodeBetweennessRemoval5 <- read.csv("MeanNodeBetweennessRemoval5.csv", header = TRUE)
MeanNodeBetweennessRemoval5 <- MeanNodeBetweennessRemoval5[,-1]
MeanNodeBetweennessRemoval6 <- read.csv("MeanNodeBetweennessRemoval6.csv", header = TRUE)
MeanNodeBetweennessRemoval6 <- MeanNodeBetweennessRemoval6[,-1]
MeanNodeBetweennessRemoval7 <- read.csv("MeanNodeBetweennessRemoval7.csv", header = TRUE)
MeanNodeBetweennessRemoval7 <- MeanNodeBetweennessRemoval7[,-1]
MeanNodeBetweennessRemoval8 <- read.csv("MeanNodeBetweennessRemoval8.csv", header = TRUE)
MeanNodeBetweennessRemoval8 <- MeanNodeBetweennessRemoval8[,-1]
MeanNodeBetweennessRemoval9 <- read.csv("MeanNodeBetweennessRemoval9.csv", header = TRUE)
MeanNodeBetweennessRemoval9 <- MeanNodeBetweennessRemoval9[,-1]
MeanNodeBetweennessRemoval10 <- read.csv("MeanNodeBetweennessRemoval10.csv", header = TRUE)
MeanNodeBetweennessRemoval10 <- MeanNodeBetweennessRemoval10[,-1]
MeanNodeBetweennessRemoval11 <- read.csv("MeanNodeBetweennessRemoval11.csv", header = TRUE)
MeanNodeBetweennessRemoval11 <- MeanNodeBetweennessRemoval11[,-1]

#MeanEdgeBetweennessRemoval
MeanEdgeBetweennessRemoval1 <- read.csv("MeanEdgeBetweennessRemoval1.csv", header = TRUE)
MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[,-1]
MeanEdgeBetweennessRemoval2 <- read.csv("MeanEdgeBetweennessRemoval2.csv", header = TRUE)
MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[,-1]
MeanEdgeBetweennessRemoval3 <- read.csv("MeanEdgeBetweennessRemoval3.csv", header = TRUE)
MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[,-1]
MeanEdgeBetweennessRemoval4 <- read.csv("MeanEdgeBetweennessRemoval4.csv", header = TRUE)
MeanEdgeBetweennessRemoval4 <- MeanEdgeBetweennessRemoval4[,-1]
MeanEdgeBetweennessRemoval5 <- read.csv("MeanEdgeBetweennessRemoval5.csv", header = TRUE)
MeanEdgeBetweennessRemoval5 <- MeanEdgeBetweennessRemoval5[,-1]
MeanEdgeBetweennessRemoval6 <- read.csv("MeanEdgeBetweennessRemoval6.csv", header = TRUE)
MeanEdgeBetweennessRemoval6 <- MeanEdgeBetweennessRemoval6[,-1]
MeanEdgeBetweennessRemoval7 <- read.csv("MeanEdgeBetweennessRemoval7.csv", header = TRUE)
MeanEdgeBetweennessRemoval7 <- MeanEdgeBetweennessRemoval7[,-1]
MeanEdgeBetweennessRemoval8 <- read.csv("MeanEdgeBetweennessRemoval8.csv", header = TRUE)
MeanEdgeBetweennessRemoval8 <- MeanEdgeBetweennessRemoval8[,-1]
MeanEdgeBetweennessRemoval9 <- read.csv("MeanEdgeBetweennessRemoval9.csv", header = TRUE)
MeanEdgeBetweennessRemoval9 <- MeanEdgeBetweennessRemoval9[,-1]
MeanEdgeBetweennessRemoval10 <- read.csv("MeanEdgeBetweennessRemoval10.csv", header = TRUE)
MeanEdgeBetweennessRemoval10 <- MeanEdgeBetweennessRemoval10[,-1]
MeanEdgeBetweennessRemoval11 <- read.csv("MeanEdgeBetweennessRemoval11.csv", header = TRUE)
MeanEdgeBetweennessRemoval11 <- MeanEdgeBetweennessRemoval11[,-1]

#BetweennessCentralizationRemoval
BetweennessCentralizationRemoval1 <- read.csv("BetweennessCentralizationRemoval1.csv", header = TRUE)
BetweennessCentralizationRemoval1 <- BetweennessCentralizationRemoval1[,-1]
BetweennessCentralizationRemoval2 <- read.csv("BetweennessCentralizationRemoval2.csv", header = TRUE)
BetweennessCentralizationRemoval2 <- BetweennessCentralizationRemoval2[,-1]
BetweennessCentralizationRemoval3 <- read.csv("BetweennessCentralizationRemoval3.csv", header = TRUE)
BetweennessCentralizationRemoval3 <- BetweennessCentralizationRemoval3[,-1]
BetweennessCentralizationRemoval4 <- read.csv("BetweennessCentralizationRemoval4.csv", header = TRUE)
BetweennessCentralizationRemoval4 <- BetweennessCentralizationRemoval4[,-1]
BetweennessCentralizationRemoval5 <- read.csv("BetweennessCentralizationRemoval5.csv", header = TRUE)
BetweennessCentralizationRemoval5 <- BetweennessCentralizationRemoval5[,-1]
BetweennessCentralizationRemoval6 <- read.csv("BetweennessCentralizationRemoval6.csv", header = TRUE)
BetweennessCentralizationRemoval6 <- BetweennessCentralizationRemoval6[,-1]
BetweennessCentralizationRemoval7 <- read.csv("BetweennessCentralizationRemoval7.csv", header = TRUE)
BetweennessCentralizationRemoval7 <- BetweennessCentralizationRemoval7[,-1]
BetweennessCentralizationRemoval8 <- read.csv("BetweennessCentralizationRemoval8.csv", header = TRUE)
BetweennessCentralizationRemoval8 <- BetweennessCentralizationRemoval8[,-1]
BetweennessCentralizationRemoval9 <- read.csv("BetweennessCentralizationRemoval9.csv", header = TRUE)
BetweennessCentralizationRemoval9 <- BetweennessCentralizationRemoval9[,-1]
BetweennessCentralizationRemoval10 <- read.csv("BetweennessCentralizationRemoval10.csv", header = TRUE)
BetweennessCentralizationRemoval10 <- BetweennessCentralizationRemoval10[,-1]
BetweennessCentralizationRemoval11 <- read.csv("BetweennessCentralizationRemoval11.csv", header = TRUE)
BetweennessCentralizationRemoval11 <- BetweennessCentralizationRemoval11[,-1]

#MeanEVCENTRemoval
MeanEVCENTRemoval1 <- read.csv("MeanEVCENTRemoval1.csv", header = TRUE)
MeanEVCENTRemoval1 <- MeanEVCENTRemoval1[,-1]
MeanEVCENTRemoval2 <- read.csv("MeanEVCENTRemoval2.csv", header = TRUE)
MeanEVCENTRemoval2 <- MeanEVCENTRemoval2[,-1]
MeanEVCENTRemoval3 <- read.csv("MeanEVCENTRemoval3.csv", header = TRUE)
MeanEVCENTRemoval3 <- MeanEVCENTRemoval3[,-1]
MeanEVCENTRemoval4 <- read.csv("MeanEVCENTRemoval4.csv", header = TRUE)
MeanEVCENTRemoval4 <- MeanEVCENTRemoval4[,-1]
MeanEVCENTRemoval5 <- read.csv("MeanEVCENTRemoval5.csv", header = TRUE)
MeanEVCENTRemoval5 <- MeanEVCENTRemoval5[,-1]
MeanEVCENTRemoval6 <- read.csv("MeanEVCENTRemoval6.csv", header = TRUE)
MeanEVCENTRemoval6 <- MeanEVCENTRemoval6[,-1]
MeanEVCENTRemoval7 <- read.csv("MeanEVCENTRemoval7.csv", header = TRUE)
MeanEVCENTRemoval7 <- MeanEVCENTRemoval7[,-1]
MeanEVCENTRemoval8 <- read.csv("MeanEVCENTRemoval8.csv", header = TRUE)
MeanEVCENTRemoval8 <- MeanEVCENTRemoval8[,-1]
MeanEVCENTRemoval9 <- read.csv("MeanEVCENTRemoval9.csv", header = TRUE)
MeanEVCENTRemoval9 <- MeanEVCENTRemoval9[,-1]
MeanEVCENTRemoval10 <- read.csv("MeanEVCENTRemoval10.csv", header = TRUE)
MeanEVCENTRemoval10 <- MeanEVCENTRemoval10[,-1]
MeanEVCENTRemoval11 <- read.csv("MeanEVCENTRemoval11.csv", header = TRUE)
MeanEVCENTRemoval11 <- MeanEVCENTRemoval11[,-1]

#NumberClustersRemoval
NumberClustersRemoval1 <- read.csv("NumberClustersRemoval1.csv", header = TRUE)
NumberClustersRemoval1 <- NumberClustersRemoval1[,-1]
NumberClustersRemoval2 <- read.csv("NumberClustersRemoval2.csv", header = TRUE)
NumberClustersRemoval2 <- NumberClustersRemoval2[,-1]
NumberClustersRemoval3 <- read.csv("NumberClustersRemoval3.csv", header = TRUE)
NumberClustersRemoval3 <- NumberClustersRemoval3[,-1]
NumberClustersRemoval4 <- read.csv("NumberClustersRemoval4.csv", header = TRUE)
NumberClustersRemoval4 <- NumberClustersRemoval4[,-1]
NumberClustersRemoval5 <- read.csv("NumberClustersRemoval5.csv", header = TRUE)
NumberClustersRemoval5 <- NumberClustersRemoval5[,-1]
NumberClustersRemoval6 <- read.csv("NumberClustersRemoval6.csv", header = TRUE)
NumberClustersRemoval6 <- NumberClustersRemoval6[,-1]
NumberClustersRemoval7 <- read.csv("NumberClustersRemoval7.csv", header = TRUE)
NumberClustersRemoval7 <- NumberClustersRemoval7[,-1]
NumberClustersRemoval8 <- read.csv("NumberClustersRemoval8.csv", header = TRUE)
NumberClustersRemoval8 <- NumberClustersRemoval8[,-1]
NumberClustersRemoval9 <- read.csv("NumberClustersRemoval9.csv", header = TRUE)
NumberClustersRemoval9 <- NumberClustersRemoval9[,-1]
NumberClustersRemoval10 <- read.csv("NumberClustersRemoval10.csv", header = TRUE)
NumberClustersRemoval10 <- NumberClustersRemoval10[,-1]
NumberClustersRemoval11 <- read.csv("NumberClustersRemoval11.csv", header = TRUE)
NumberClustersRemoval11 <- NumberClustersRemoval11[,-1]

#ModularityRemoval
ModularityRemoval1 <- read.csv("ModularityRemoval1.csv", header = TRUE)
ModularityRemoval1 <- ModularityRemoval1[,-1]
ModularityRemoval2 <- read.csv("ModularityRemoval2.csv", header = TRUE)
ModularityRemoval2 <- ModularityRemoval2[,-1]
ModularityRemoval3 <- read.csv("ModularityRemoval3.csv", header = TRUE)
ModularityRemoval3 <- ModularityRemoval3[,-1]
ModularityRemoval4 <- read.csv("ModularityRemoval4.csv", header = TRUE)
ModularityRemoval4 <- ModularityRemoval4[,-1]
ModularityRemoval5 <- read.csv("ModularityRemoval5.csv", header = TRUE)
ModularityRemoval5 <- ModularityRemoval5[,-1]
ModularityRemoval6 <- read.csv("ModularityRemoval6.csv", header = TRUE)
ModularityRemoval6 <- ModularityRemoval6[,-1]
ModularityRemoval7 <- read.csv("ModularityRemoval7.csv", header = TRUE)
ModularityRemoval7 <- ModularityRemoval7[,-1]
ModularityRemoval8 <- read.csv("ModularityRemoval8.csv", header = TRUE)
ModularityRemoval8 <- ModularityRemoval8[,-1]
ModularityRemoval9 <- read.csv("ModularityRemoval9.csv", header = TRUE)
ModularityRemoval9 <- ModularityRemoval9[,-1]
ModularityRemoval10 <- read.csv("ModularityRemoval10.csv", header = TRUE)
ModularityRemoval10 <- ModularityRemoval10[,-1]
ModularityRemoval11 <- read.csv("ModularityRemoval11.csv", header = TRUE)
ModularityRemoval11 <- ModularityRemoval11[,-1]

#MeanNumberReached
MeanNumberReachedRemoval1 <- read.csv("MeanNumberReachedRemoval1.csv", header = TRUE)
MeanNumberReachedRemoval1 <- MeanNumberReachedRemoval1[,-1]
MeanNumberReachedRemoval2 <- read.csv("MeanNumberReachedRemoval2.csv", header = TRUE)
MeanNumberReachedRemoval2 <- MeanNumberReachedRemoval2[,-1]
MeanNumberReachedRemoval3 <- read.csv("MeanNumberReachedRemoval3.csv", header = TRUE)
MeanNumberReachedRemoval3 <- MeanNumberReachedRemoval3[,-1]
MeanNumberReachedRemoval4 <- read.csv("MeanNumberReachedRemoval4.csv", header = TRUE)
MeanNumberReachedRemoval4 <- MeanNumberReachedRemoval4[,-1]
MeanNumberReachedRemoval5 <- read.csv("MeanNumberReachedRemoval5.csv", header = TRUE)
MeanNumberReachedRemoval5 <- MeanNumberReachedRemoval5[,-1]
MeanNumberReachedRemoval6 <- read.csv("MeanNumberReachedRemoval6.csv", header = TRUE)
MeanNumberReachedRemoval6 <- MeanNumberReachedRemoval6[,-1]
MeanNumberReachedRemoval7 <- read.csv("MeanNumberReachedRemoval7.csv", header = TRUE)
MeanNumberReachedRemoval7 <- MeanNumberReachedRemoval7[,-1]
MeanNumberReachedRemoval8 <- read.csv("MeanNumberReachedRemoval8.csv", header = TRUE)
MeanNumberReachedRemoval8 <- MeanNumberReachedRemoval8[,-1]
MeanNumberReachedRemoval9 <- read.csv("MeanNumberReachedRemoval9.csv", header = TRUE)
MeanNumberReachedRemoval9 <- MeanNumberReachedRemoval9[,-1]
MeanNumberReachedRemoval10 <- read.csv("MeanNumberReachedRemoval10.csv", header = TRUE)
MeanNumberReachedRemoval10 <- MeanNumberReachedRemoval10[,-1]
MeanNumberReachedRemoval11 <- read.csv("MeanNumberReachedRemoval11.csv", header = TRUE)
MeanNumberReachedRemoval11 <- MeanNumberReachedRemoval11[,-1]

#ClosenessCentralizationRemoval
ClosenessCentralizationRemoval1 <- read.csv("ClosenessCentralizationRemoval1.csv", header = TRUE)
ClosenessCentralizationRemoval1 <- ClosenessCentralizationRemoval1[,-1]
ClosenessCentralizationRemoval2 <- read.csv("ClosenessCentralizationRemoval2.csv", header = TRUE)
ClosenessCentralizationRemoval2 <- ClosenessCentralizationRemoval2[,-1]
ClosenessCentralizationRemoval3 <- read.csv("ClosenessCentralizationRemoval3.csv", header = TRUE)
ClosenessCentralizationRemoval3 <- ClosenessCentralizationRemoval3[,-1]
ClosenessCentralizationRemoval4 <- read.csv("ClosenessCentralizationRemoval4.csv", header = TRUE)
ClosenessCentralizationRemoval4 <- ClosenessCentralizationRemoval4[,-1]
ClosenessCentralizationRemoval5 <- read.csv("ClosenessCentralizationRemoval5.csv", header = TRUE)
ClosenessCentralizationRemoval5 <- ClosenessCentralizationRemoval5[,-1]
ClosenessCentralizationRemoval6 <- read.csv("ClosenessCentralizationRemoval6.csv", header = TRUE)
ClosenessCentralizationRemoval6 <- ClosenessCentralizationRemoval6[,-1]
ClosenessCentralizationRemoval7 <- read.csv("ClosenessCentralizationRemoval7.csv", header = TRUE)
ClosenessCentralizationRemoval7 <- ClosenessCentralizationRemoval7[,-1]
ClosenessCentralizationRemoval8 <- read.csv("ClosenessCentralizationRemoval8.csv", header = TRUE)
ClosenessCentralizationRemoval8 <- ClosenessCentralizationRemoval8[,-1]
ClosenessCentralizationRemoval9 <- read.csv("ClosenessCentralizationRemoval9.csv", header = TRUE)
ClosenessCentralizationRemoval9 <- ClosenessCentralizationRemoval9[,-1]
ClosenessCentralizationRemoval10 <- read.csv("ClosenessCentralizationRemoval10.csv", header = TRUE)
ClosenessCentralizationRemoval10 <- ClosenessCentralizationRemoval10[,-1]
ClosenessCentralizationRemoval11 <- read.csv("ClosenessCentralizationRemoval11.csv", header = TRUE)
ClosenessCentralizationRemoval11 <- ClosenessCentralizationRemoval11[,-1]

#combine output data frames
MeanNodeDegreeRemoval <- rbind(MeanNodeDegreeRemoval1, MeanNodeDegreeRemoval2, MeanNodeDegreeRemoval3, MeanNodeDegreeRemoval4,
MeanNodeDegreeRemoval5, MeanNodeDegreeRemoval6, MeanNodeDegreeRemoval7, MeanNodeDegreeRemoval8, MeanNodeDegreeRemoval9,
MeanNodeDegreeRemoval10, MeanNodeDegreeRemoval11)

DegreeCentralizationRemoval <- rbind(DegreeCentralizationRemoval1, DegreeCentralizationRemoval2, DegreeCentralizationRemoval3, DegreeCentralizationRemoval4,
DegreeCentralizationRemoval5, DegreeCentralizationRemoval6, DegreeCentralizationRemoval7, DegreeCentralizationRemoval8, DegreeCentralizationRemoval9,
DegreeCentralizationRemoval10, DegreeCentralizationRemoval11)

MeanNodeBetweennessRemoval <- rbind(MeanNodeBetweennessRemoval1, MeanNodeBetweennessRemoval2, MeanNodeBetweennessRemoval3, MeanNodeBetweennessRemoval4,
MeanNodeBetweennessRemoval5, MeanNodeBetweennessRemoval6, MeanNodeBetweennessRemoval7, MeanNodeBetweennessRemoval8, MeanNodeBetweennessRemoval9,
MeanNodeBetweennessRemoval10, MeanNodeBetweennessRemoval11)

MeanEdgeBetweennessRemoval <- rbind(MeanEdgeBetweennessRemoval1, MeanEdgeBetweennessRemoval2, MeanEdgeBetweennessRemoval3, MeanEdgeBetweennessRemoval4,
MeanEdgeBetweennessRemoval5, MeanEdgeBetweennessRemoval6, MeanEdgeBetweennessRemoval7, MeanEdgeBetweennessRemoval8, MeanEdgeBetweennessRemoval9,
MeanEdgeBetweennessRemoval10, MeanEdgeBetweennessRemoval11)

BetweennessCentralizationRemoval <- rbind(BetweennessCentralizationRemoval1, BetweennessCentralizationRemoval2, BetweennessCentralizationRemoval3, BetweennessCentralizationRemoval4,
BetweennessCentralizationRemoval5, BetweennessCentralizationRemoval6, BetweennessCentralizationRemoval7, BetweennessCentralizationRemoval8, BetweennessCentralizationRemoval9,
BetweennessCentralizationRemoval10, BetweennessCentralizationRemoval11)

MeanEVCENTRemoval <- rbind(MeanEVCENTRemoval1, MeanEVCENTRemoval2, MeanEVCENTRemoval3, MeanEVCENTRemoval4,
MeanEVCENTRemoval5, MeanEVCENTRemoval6, MeanEVCENTRemoval7, MeanEVCENTRemoval8, MeanEVCENTRemoval9,
MeanEVCENTRemoval10, MeanEVCENTRemoval11)

NumberClustersRemoval <- rbind(NumberClustersRemoval1, NumberClustersRemoval2, NumberClustersRemoval3, NumberClustersRemoval4,
NumberClustersRemoval5, NumberClustersRemoval6, NumberClustersRemoval7, NumberClustersRemoval8, NumberClustersRemoval9,
NumberClustersRemoval10, NumberClustersRemoval11)

ModularityRemoval <- rbind(ModularityRemoval1, ModularityRemoval2, ModularityRemoval3, ModularityRemoval4,
ModularityRemoval5, ModularityRemoval6, ModularityRemoval7, ModularityRemoval8, ModularityRemoval9,
ModularityRemoval10, ModularityRemoval11)

MeanNumberReachedRemoval <- rbind(MeanNumberReachedRemoval1, MeanNumberReachedRemoval2, MeanNumberReachedRemoval3, MeanNumberReachedRemoval4,
MeanNumberReachedRemoval5, MeanNumberReachedRemoval6, MeanNumberReachedRemoval7, MeanNumberReachedRemoval8, MeanNumberReachedRemoval9,
MeanNumberReachedRemoval10, MeanNumberReachedRemoval11)

ClosenessCentralizationRemoval <- rbind(ClosenessCentralizationRemoval1, ClosenessCentralizationRemoval2, ClosenessCentralizationRemoval3, ClosenessCentralizationRemoval4,
ClosenessCentralizationRemoval5, ClosenessCentralizationRemoval6, ClosenessCentralizationRemoval7, ClosenessCentralizationRemoval8, ClosenessCentralizationRemoval9,
ClosenessCentralizationRemoval10, ClosenessCentralizationRemoval11)

#read in updated contemporary wetlands and pits shapefile
ContWetsAndPits <- readOGR("ContWetsAndPitsHalfKMNetwork1.shp", "ContWetsAndPitsHalfKMNetwork1", verbose = TRUE, p4s = NULL)

#add new outputs to attribute table
#ContWetsAndPits@data$Degree <- DegreeHalfKMNetwork
#ContWetsAndPits@data$NodeBetween <- HalfKMNodeBetweenness
ContWetsAndPits@data$RemDeg <- MeanNodeDegreeRemoval$Degree
ContWetsAndPits@data$DegCentRem <- DegreeCentralizationRemoval$DegreeCent
ContWetsAndPits@data$NodeBtwRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWetsAndPits@data$EdgeBetRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWetsAndPits@data$BtwCentRem <- BetweennessCentralizationRemoval$BetweenCent
ContWetsAndPits@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWetsAndPits@data$NumClustRem <- NumberClustersRemoval$NoClusters
ContWetsAndPits@data$ModRem <- ModularityRemoval$Modularity
ContWetsAndPits@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached
ContWetsAndPits@data$CloseCentRem <- ClosenessCentralizationRemoval$CloseCent

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWetsAndPits, "ContWetsAndPitsHalfKMNetwork2", "ContWetsAndPitsHalfKMNetwork2", driver = 'ESRI Shapefile', verbose = TRUE)


#####
#####
#####
#1.0 km
retain <- c("FromNode", "ToNode")
OneKMPaths1 <- read.csv("OneKMPaths1.csv")
OneKMPaths1$FromNode <- OneKMPaths1$unlist.FromNode1.
OneKMPaths1$ToNode <- OneKMPaths1$unlist.ToNode1.
OneKMPaths1 <- OneKMPaths1[retain]

OneKMPaths2 <- read.csv("OneKMPaths2.csv")
OneKMPaths2$FromNode <- OneKMPaths2$unlist.FromNode2.
OneKMPaths2$ToNode <- OneKMPaths2$unlist.ToNode2.
OneKMPaths2 <- OneKMPaths2[retain]

OneKMPaths3 <- read.csv("OneKMPaths3.csv")
OneKMPaths3$FromNode <- OneKMPaths3$unlist.FromNode3.
OneKMPaths3$ToNode <- OneKMPaths3$unlist.ToNode3.
OneKMPaths3 <- OneKMPaths3[retain]

OneKMPaths4 <- read.csv("OneKMPaths4.csv")
OneKMPaths4$FromNode <- OneKMPaths4$unlist.FromNode4.
OneKMPaths4$ToNode <- OneKMPaths4$unlist.ToNode4.
OneKMPaths4 <- OneKMPaths4[retain]

OneKMPaths5 <- read.csv("OneKMPaths5.csv")
OneKMPaths5$FromNode <- OneKMPaths5$unlist.FromNode5.
OneKMPaths5$ToNode <- OneKMPaths5$unlist.ToNode5.
OneKMPaths5 <- OneKMPaths5[retain]

OneKMPaths6 <- read.csv("OneKMPaths6.csv")
OneKMPaths6$FromNode <- OneKMPaths6$unlist.FromNode6.
OneKMPaths6$ToNode <- OneKMPaths6$unlist.ToNode6.
OneKMPaths6 <- OneKMPaths6[retain]

OneKMPaths7 <- read.csv("OneKMPaths7.csv")
OneKMPaths7$FromNode <- OneKMPaths7$unlist.FromNode7.
OneKMPaths7$ToNode <- OneKMPaths7$unlist.ToNode7.
OneKMPaths7 <- OneKMPaths7[retain]

#combine 1.0 km connections into 1 data frame
OneKMPathsCombined <- rbind(OneKMPaths1, OneKMPaths2, OneKMPaths3, OneKMPaths4, OneKMPaths5, OneKMPaths6, OneKMPaths7)
OneKMPathsCombined <- as.matrix(OneKMPathsCombined[-13182,])

#create network with nodes and associated edges
OneKMNetwork <- graph(n = 10161, edges = OneKMPathsCombined, directed = FALSE)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
OneKMNodeBetweenness <- betweenness(OneKMNetwork, v = V(OneKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
OneKMNodeBetweenness
MeanNodeBetweennessOneKM <- mean(OneKMNodeBetweenness)
MeanNodeBetweennessOneKM

OneKMEdgeBetweenness <- edge.betweenness(OneKMNetwork, e = E(OneKMNetwork), directed = FALSE, weights = NULL)
OneKMEdgeBetweenness
MeanEdgeBetweennessOneKM <- mean(OneKMEdgeBetweenness)
MeanEdgeBetweennessOneKM

#calculate degree (number of adjacent edges for each node)
DegreeOneKMNetwork <- degree(OneKMNetwork, v = V(OneKMNetwork), loops = TRUE)
DegreeOneKMNetwork
MeanDegreeOneKMNetwork <- mean(DegreeOneKMNetwork)
MeanDegreeOneKMNetwork

#find number of clusters (groups of connected graph components)
OneKMNetworkNumberClusters <- no.clusters(OneKMNetwork)
OneKMNetworkNumberClusters

#find mean number of vertices per cluster
OneKMNetworkClusters <- clusters(OneKMNetwork)
summary(OneKMNetworkClusters$csize)
OneKMNetworkMeanClusterSize <- mean(OneKMNetworkClusters$csize)
OneKMNetworkMeanClusterSize

#calculate modularity
OneKMNetworkModularity <- modularity(OneKMNetwork, V(OneKMNetwork))
OneKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
OneKMNetworkSC <- list(NA)
NumberReachedOneKM <- list(NA)
for(i in 1:nrow(ContWetsAndPits@data)){
	OneKMNetworkSC[[i]] <- subcomponent(OneKMNetwork, v = i)
	NumberReachedOneKM[[i]] <- length(OneKMNetworkSC[[i]]) - 1
}
NumberReachedOneKM <- unlist(NumberReachedOneKM)
NumberReachedOneKMMean <- mean(NumberReachedOneKM)
NumberReachedOneKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
OneKMNetworkEBC <- edge.betweenness.community(OneKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
OneKMNetworkEVCENT <- evcent(OneKMNetwork, directed = FALSE, scale = FALSE)
OneKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
OneKMNetworkGraphDensity <- graph.density(OneKMNetwork, loops = TRUE)
OneKMNetworkGraphDensity

#identify neighbors of each vertice
OneKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWetsAndPits@data)){
	OneKMNetworkNeighbors[[i]] <- neighbors(OneKMNetwork, v = i)
}
OneKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
OneKMNetworkNeighborSize <- neighborhood.size(OneKMNetwork, order = 1, nodes = V(OneKMNetwork))
OneKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
OneKMNetworkGraphCohesion <- graph.cohesion(OneKMNetwork)
OneKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
OneKMNetworkAPL <- average.path.length(OneKMNetwork, directed = FALSE, unconnected = TRUE)
OneKMNetworkAPL

#generate histogram of shortest path lengths
OneKMNetworkAPLHist <- path.length.hist(OneKMNetwork, directed = FALSE)
OneKMNetworkAPLHist

#update and re-write attribute table, prior to dealing with memory allocation issues
ContWetsAndPits@data$Degree <- DegreeOneKMNetwork
ContWetsAndPits@data$NodeBetween <- OneKMNodeBetweenness
writeOGR(ContWetsAndPits, "ContWetsAndPitsOneKMNetwork1", "ContWetsAndPitsOneKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#experiment with deleting vertices/edges
#####
#####
#####
#part 1
NodeRemove <- list(NA)
MeanNodeDegreeRemoval <- list(NA)
DegreeCentralizationRemoval <- list(NA)
MeanNodeBetweennessRemoval <- list(NA)
MeanEdgeBetweennessRemoval <- list(NA)
BetweennessCentralizationRemoval <- list(NA)
EVCENTRemoval <- list(NA)
MeanEVCENTRemoval <- list(NA)
NumberClustersRemoval <- list(NA)
ModularityRemoval <- list(NA)
NumberReachedRemoval <- list(NA)
MeanNumberReachedRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	MeanNodeDegreeRemoval[[i]] <- mean(degree(NodeRemove[[i]], v = V(NodeRemove[[i]]), loops = TRUE))
	DegreeCentralizationRemoval[[i]] <- centralization.degree(NodeRemove[[i]], loops = TRUE, normalized = FALSE)
	DegreeCentralizationRemoval[[i]] <- DegreeCentralizationRemoval[[i]]$centralization
	MeanNodeBetweennessRemoval[[i]] <- mean(betweenness(NodeRemove[[i]], v = V(NodeRemove[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval[[i]] <- mean(edge.betweenness(NodeRemove[[i]], e = E(NodeRemove[[i]]), directed = FALSE, weights = NULL))
	BetweennessCentralizationRemoval[[i]] <- centralization.betweenness(NodeRemove[[i]], directed = TRUE, nobigint = FALSE, normalized = FALSE)
	BetweennessCentralizationRemoval[[i]] <- BetweennessCentralizationRemoval[[i]]$centralization
	EVCENTRemoval[[i]] <- evcent(NodeRemove[[i]], directed = FALSE, scale = TRUE)
	MeanEVCENTRemoval[[i]] <- EVCENTRemoval[[i]]$value
	NumberClustersRemoval[[i]] <- no.clusters(NodeRemove[[i]])
	ModularityRemoval[[i]] <- modularity(NodeRemove[[i]], V(NodeRemove[[i]]))
	HalfKMNetworkSC <- list(NA)
	NumberReachedRemoval1 <- list(NA)
	for(x in 1:length(V(NodeRemove[[i]]))){
		HalfKMNetworkSC[[x]] <- subcomponent(NodeRemove[[i]], v = x)
		NumberReachedRemoval1[[x]] <- length(HalfKMNetworkSC[[x]]) - 1
	}
	NumberReachedRemoval[[i]] <- unlist(NumberReachedRemoval1)
	MeanNumberReachedRemoval[[i]] <- mean(NumberReachedRemoval[[i]])
}

#add in closeness centrality loop
NodeRemove <- list(NA)
ClosenessCentralityRemoval <- list(NA)
for(i in 1:1000){
	NodeRemove[[i]] <- HalfKMNetwork
	NodeRemove[[i]] <- NodeRemove[[i]] - i
	ClosenessCentralityRemoval[[i]] <- centralization.closeness(NodeRemove[[i]], normalized = FALSE)
	ClosenessCentralityRemoval[[i]] <- ClosenessCentralityRemoval[[i]]$centralization
}

#unlist closenesscentrality after removing each node
ClosenessCentralityRemoval <- unlist(ClosenessCentralityRemoval)
ClosenessCentralityRemoval <- data.frame(ClosenessCentralityRemoval)
ClosenessCentralityRemoval$CloseCent <- ClosenessCentralityRemoval[,1]
ClosenessCentralityRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
ClosenessCentralityRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
ClosenessCentralityRemoval <- ClosenessCentralityRemoval[,-1]
head(ClosenessCentralityRemoval)

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval <- unlist(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval <- data.frame(MeanNodeDegreeRemoval)
MeanNodeDegreeRemoval$Degree <- MeanNodeDegreeRemoval[,1]
MeanNodeDegreeRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNodeDegreeRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNodeDegreeRemoval <- MeanNodeDegreeRemoval[,-1]
head(MeanNodeDegreeRemoval)

#unlist degree centralizations after removing each node
DegreeCentralizationRemoval <- unlist(DegreeCentralizationRemoval)
DegreeCentralizationRemoval <- data.frame(DegreeCentralizationRemoval)
DegreeCentralizationRemoval$DegreeCent <- DegreeCentralizationRemoval[,1]
DegreeCentralizationRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
DegreeCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
DegreeCentralizationRemoval <- DegreeCentralizationRemoval[,-1]
head(DegreeCentralizationRemoval)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval <- unlist(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval <- data.frame(MeanNodeBetweennessRemoval)
MeanNodeBetweennessRemoval$NodeBetweenness <- MeanNodeBetweennessRemoval[,1]
MeanNodeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNodeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNodeBetweennessRemoval <- MeanNodeBetweennessRemoval[,-1]
head(MeanNodeBetweennessRemoval)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval <- unlist(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval <- data.frame(MeanEdgeBetweennessRemoval)
MeanEdgeBetweennessRemoval$EdgeBetweenness <- MeanEdgeBetweennessRemoval[,1]
MeanEdgeBetweennessRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanEdgeBetweennessRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanEdgeBetweennessRemoval <- MeanEdgeBetweennessRemoval[,-1]
head(MeanEdgeBetweennessRemoval)

#unlist betweenness centralizations after removing each node sequentially
BetweennessCentralizationRemoval <- unlist(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval <- data.frame(BetweennessCentralizationRemoval)
BetweennessCentralizationRemoval$BetweenCent <- BetweennessCentralizationRemoval[,1]
BetweennessCentralizationRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
BetweennessCentralizationRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
BetweennessCentralizationRemoval <- BetweennessCentralizationRemoval[,-1]
head(BetweennessCentralizationRemoval)

#unlist mean eigenvector centrality scores after removing and replacing each node sequentially
MeanEVCENTRemoval <- unlist(MeanEVCENTRemoval)
MeanEVCENTRemoval <- data.frame(MeanEVCENTRemoval)
MeanEVCENTRemoval$evcent <- MeanEVCENTRemoval[,1]
MeanEVCENTRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanEVCENTRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanEVCENTRemoval <- MeanEVCENTRemoval[,-1]
head(MeanEVCENTRemoval)

#unlist number of clusters...
NumberClustersRemoval <- unlist(NumberClustersRemoval)
NumberClustersRemoval <- data.frame(NumberClustersRemoval)
NumberClustersRemoval$NoClusters <- NumberClustersRemoval[,1]
NumberClustersRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
NumberClustersRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
NumberClustersRemoval <- NumberClustersRemoval[,-1]
head(NumberClustersRemoval)

#unlist modularity scores...
ModularityRemoval <- unlist(ModularityRemoval)
ModularityRemoval <- data.frame(ModularityRemoval)
ModularityRemoval$Modularity <- ModularityRemoval[,1]
ModularityRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
ModularityRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
ModularityRemoval <- ModularityRemoval[,-1]
head(ModularityRemoval)

#unlist mean number of vertices reached...
MeanNumberReachedRemoval <- unlist(MeanNumberReachedRemoval)
MeanNumberReachedRemoval <- data.frame(MeanNumberReachedRemoval)
MeanNumberReachedRemoval$MeanNumReached <- MeanNumberReachedRemoval[,1]
MeanNumberReachedRemoval$NodeID <- ContWetsAndPits@data[1:1000,]$NodeID
MeanNumberReachedRemoval$FP_ID <- ContWetsAndPits@data[1:1000,]$FP_ID
MeanNumberReachedRemoval <- MeanNumberReachedRemoval[,-1]
head(MeanNumberReachedRemoval)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval, "MeanNodeDegreeRemoval1.csv")
write.csv(DegreeCentralizationRemoval, "DegreeCentralizationRemoval1.csv")
write.csv(MeanNodeBetweennessRemoval, "MeanNodeBetweennessRemoval1.csv")
write.csv(MeanEdgeBetweennessRemoval, "MeanEdgeBetweennessRemoval1.csv")
write.csv(BetweennessCentralizationRemoval, "BetweennessCentralizationRemoval1.csv")
write.csv(MeanEVCENTRemoval, "MeanEVCENTRemoval1.csv")
write.csv(NumberClustersRemoval, "NumberClustersRemoval1.csv")
write.csv(ModularityRemoval, "ModularityRemoval1.csv")
write.csv(MeanNumberReachedRemoval, "MeanNumberReachedRemoval1.csv")
write.csv(ClosenessCentralityRemoval, "ClosenessCentralizationRemoval1.csv")

#read back in outputs from 11 parts
#MeanNodeDegreeRemoval
MeanNodeDegreeRemoval1 <- read.csv("MeanNodeDegreeRemoval1.csv", header = TRUE)
MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[,-1]
MeanNodeDegreeRemoval2 <- read.csv("MeanNodeDegreeRemoval2.csv", header = TRUE)
MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[,-1]
MeanNodeDegreeRemoval3 <- read.csv("MeanNodeDegreeRemoval3.csv", header = TRUE)
MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[,-1]
MeanNodeDegreeRemoval4 <- read.csv("MeanNodeDegreeRemoval4.csv", header = TRUE)
MeanNodeDegreeRemoval4 <- MeanNodeDegreeRemoval4[,-1]
MeanNodeDegreeRemoval5 <- read.csv("MeanNodeDegreeRemoval5.csv", header = TRUE)
MeanNodeDegreeRemoval5 <- MeanNodeDegreeRemoval5[,-1]
MeanNodeDegreeRemoval6 <- read.csv("MeanNodeDegreeRemoval6.csv", header = TRUE)
MeanNodeDegreeRemoval6 <- MeanNodeDegreeRemoval6[,-1]
MeanNodeDegreeRemoval7 <- read.csv("MeanNodeDegreeRemoval7.csv", header = TRUE)
MeanNodeDegreeRemoval7 <- MeanNodeDegreeRemoval7[,-1]
MeanNodeDegreeRemoval8 <- read.csv("MeanNodeDegreeRemoval8.csv", header = TRUE)
MeanNodeDegreeRemoval8 <- MeanNodeDegreeRemoval8[,-1]
MeanNodeDegreeRemoval9 <- read.csv("MeanNodeDegreeRemoval9.csv", header = TRUE)
MeanNodeDegreeRemoval9 <- MeanNodeDegreeRemoval9[,-1]
MeanNodeDegreeRemoval10 <- read.csv("MeanNodeDegreeRemoval10.csv", header = TRUE)
MeanNodeDegreeRemoval10 <- MeanNodeDegreeRemoval10[,-1]
MeanNodeDegreeRemoval11 <- read.csv("MeanNodeDegreeRemoval11.csv", header = TRUE)
MeanNodeDegreeRemoval11 <- MeanNodeDegreeRemoval11[,-1]

#DegreeCentralizationRemoval
DegreeCentralizationRemoval1 <- read.csv("DegreeCentralizationRemoval1.csv", header = TRUE)
DegreeCentralizationRemoval1 <- DegreeCentralizationRemoval1[,-1]
DegreeCentralizationRemoval2 <- read.csv("DegreeCentralizationRemoval2.csv", header = TRUE)
DegreeCentralizationRemoval2 <- DegreeCentralizationRemoval2[,-1]
DegreeCentralizationRemoval3 <- read.csv("DegreeCentralizationRemoval3.csv", header = TRUE)
DegreeCentralizationRemoval3 <- DegreeCentralizationRemoval3[,-1]
DegreeCentralizationRemoval4 <- read.csv("DegreeCentralizationRemoval4.csv", header = TRUE)
DegreeCentralizationRemoval4 <- DegreeCentralizationRemoval4[,-1]
DegreeCentralizationRemoval5 <- read.csv("DegreeCentralizationRemoval5.csv", header = TRUE)
DegreeCentralizationRemoval5 <- DegreeCentralizationRemoval5[,-1]
DegreeCentralizationRemoval6 <- read.csv("DegreeCentralizationRemoval6.csv", header = TRUE)
DegreeCentralizationRemoval6 <- DegreeCentralizationRemoval6[,-1]
DegreeCentralizationRemoval7 <- read.csv("DegreeCentralizationRemoval7.csv", header = TRUE)
DegreeCentralizationRemoval7 <- DegreeCentralizationRemoval7[,-1]
DegreeCentralizationRemoval8 <- read.csv("DegreeCentralizationRemoval8.csv", header = TRUE)
DegreeCentralizationRemoval8 <- DegreeCentralizationRemoval8[,-1]
DegreeCentralizationRemoval9 <- read.csv("DegreeCentralizationRemoval9.csv", header = TRUE)
DegreeCentralizationRemoval9 <- DegreeCentralizationRemoval9[,-1]
DegreeCentralizationRemoval10 <- read.csv("DegreeCentralizationRemoval10.csv", header = TRUE)
DegreeCentralizationRemoval10 <- DegreeCentralizationRemoval10[,-1]
DegreeCentralizationRemoval11 <- read.csv("DegreeCentralizationRemoval11.csv", header = TRUE)
DegreeCentralizationRemoval11 <- DegreeCentralizationRemoval11[,-1]

#MeanNodeBetweennessRemoval
MeanNodeBetweennessRemoval1 <- read.csv("MeanNodeBetweennessRemoval1.csv", header = TRUE)
MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[,-1]
MeanNodeBetweennessRemoval2 <- read.csv("MeanNodeBetweennessRemoval2.csv", header = TRUE)
MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[,-1]
MeanNodeBetweennessRemoval3 <- read.csv("MeanNodeBetweennessRemoval3.csv", header = TRUE)
MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[,-1]
MeanNodeBetweennessRemoval4 <- read.csv("MeanNodeBetweennessRemoval4.csv", header = TRUE)
MeanNodeBetweennessRemoval4 <- MeanNodeBetweennessRemoval4[,-1]
MeanNodeBetweennessRemoval5 <- read.csv("MeanNodeBetweennessRemoval5.csv", header = TRUE)
MeanNodeBetweennessRemoval5 <- MeanNodeBetweennessRemoval5[,-1]
MeanNodeBetweennessRemoval6 <- read.csv("MeanNodeBetweennessRemoval6.csv", header = TRUE)
MeanNodeBetweennessRemoval6 <- MeanNodeBetweennessRemoval6[,-1]
MeanNodeBetweennessRemoval7 <- read.csv("MeanNodeBetweennessRemoval7.csv", header = TRUE)
MeanNodeBetweennessRemoval7 <- MeanNodeBetweennessRemoval7[,-1]
MeanNodeBetweennessRemoval8 <- read.csv("MeanNodeBetweennessRemoval8.csv", header = TRUE)
MeanNodeBetweennessRemoval8 <- MeanNodeBetweennessRemoval8[,-1]
MeanNodeBetweennessRemoval9 <- read.csv("MeanNodeBetweennessRemoval9.csv", header = TRUE)
MeanNodeBetweennessRemoval9 <- MeanNodeBetweennessRemoval9[,-1]
MeanNodeBetweennessRemoval10 <- read.csv("MeanNodeBetweennessRemoval10.csv", header = TRUE)
MeanNodeBetweennessRemoval10 <- MeanNodeBetweennessRemoval10[,-1]
MeanNodeBetweennessRemoval11 <- read.csv("MeanNodeBetweennessRemoval11.csv", header = TRUE)
MeanNodeBetweennessRemoval11 <- MeanNodeBetweennessRemoval11[,-1]

#MeanEdgeBetweennessRemoval
MeanEdgeBetweennessRemoval1 <- read.csv("MeanEdgeBetweennessRemoval1.csv", header = TRUE)
MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[,-1]
MeanEdgeBetweennessRemoval2 <- read.csv("MeanEdgeBetweennessRemoval2.csv", header = TRUE)
MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[,-1]
MeanEdgeBetweennessRemoval3 <- read.csv("MeanEdgeBetweennessRemoval3.csv", header = TRUE)
MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[,-1]
MeanEdgeBetweennessRemoval4 <- read.csv("MeanEdgeBetweennessRemoval4.csv", header = TRUE)
MeanEdgeBetweennessRemoval4 <- MeanEdgeBetweennessRemoval4[,-1]
MeanEdgeBetweennessRemoval5 <- read.csv("MeanEdgeBetweennessRemoval5.csv", header = TRUE)
MeanEdgeBetweennessRemoval5 <- MeanEdgeBetweennessRemoval5[,-1]
MeanEdgeBetweennessRemoval6 <- read.csv("MeanEdgeBetweennessRemoval6.csv", header = TRUE)
MeanEdgeBetweennessRemoval6 <- MeanEdgeBetweennessRemoval6[,-1]
MeanEdgeBetweennessRemoval7 <- read.csv("MeanEdgeBetweennessRemoval7.csv", header = TRUE)
MeanEdgeBetweennessRemoval7 <- MeanEdgeBetweennessRemoval7[,-1]
MeanEdgeBetweennessRemoval8 <- read.csv("MeanEdgeBetweennessRemoval8.csv", header = TRUE)
MeanEdgeBetweennessRemoval8 <- MeanEdgeBetweennessRemoval8[,-1]
MeanEdgeBetweennessRemoval9 <- read.csv("MeanEdgeBetweennessRemoval9.csv", header = TRUE)
MeanEdgeBetweennessRemoval9 <- MeanEdgeBetweennessRemoval9[,-1]
MeanEdgeBetweennessRemoval10 <- read.csv("MeanEdgeBetweennessRemoval10.csv", header = TRUE)
MeanEdgeBetweennessRemoval10 <- MeanEdgeBetweennessRemoval10[,-1]
MeanEdgeBetweennessRemoval11 <- read.csv("MeanEdgeBetweennessRemoval11.csv", header = TRUE)
MeanEdgeBetweennessRemoval11 <- MeanEdgeBetweennessRemoval11[,-1]

#BetweennessCentralizationRemoval
BetweennessCentralizationRemoval1 <- read.csv("BetweennessCentralizationRemoval1.csv", header = TRUE)
BetweennessCentralizationRemoval1 <- BetweennessCentralizationRemoval1[,-1]
BetweennessCentralizationRemoval2 <- read.csv("BetweennessCentralizationRemoval2.csv", header = TRUE)
BetweennessCentralizationRemoval2 <- BetweennessCentralizationRemoval2[,-1]
BetweennessCentralizationRemoval3 <- read.csv("BetweennessCentralizationRemoval3.csv", header = TRUE)
BetweennessCentralizationRemoval3 <- BetweennessCentralizationRemoval3[,-1]
BetweennessCentralizationRemoval4 <- read.csv("BetweennessCentralizationRemoval4.csv", header = TRUE)
BetweennessCentralizationRemoval4 <- BetweennessCentralizationRemoval4[,-1]
BetweennessCentralizationRemoval5 <- read.csv("BetweennessCentralizationRemoval5.csv", header = TRUE)
BetweennessCentralizationRemoval5 <- BetweennessCentralizationRemoval5[,-1]
BetweennessCentralizationRemoval6 <- read.csv("BetweennessCentralizationRemoval6.csv", header = TRUE)
BetweennessCentralizationRemoval6 <- BetweennessCentralizationRemoval6[,-1]
BetweennessCentralizationRemoval7 <- read.csv("BetweennessCentralizationRemoval7.csv", header = TRUE)
BetweennessCentralizationRemoval7 <- BetweennessCentralizationRemoval7[,-1]
BetweennessCentralizationRemoval8 <- read.csv("BetweennessCentralizationRemoval8.csv", header = TRUE)
BetweennessCentralizationRemoval8 <- BetweennessCentralizationRemoval8[,-1]
BetweennessCentralizationRemoval9 <- read.csv("BetweennessCentralizationRemoval9.csv", header = TRUE)
BetweennessCentralizationRemoval9 <- BetweennessCentralizationRemoval9[,-1]
BetweennessCentralizationRemoval10 <- read.csv("BetweennessCentralizationRemoval10.csv", header = TRUE)
BetweennessCentralizationRemoval10 <- BetweennessCentralizationRemoval10[,-1]
BetweennessCentralizationRemoval11 <- read.csv("BetweennessCentralizationRemoval11.csv", header = TRUE)
BetweennessCentralizationRemoval11 <- BetweennessCentralizationRemoval11[,-1]

#MeanEVCENTRemoval
MeanEVCENTRemoval1 <- read.csv("MeanEVCENTRemoval1.csv", header = TRUE)
MeanEVCENTRemoval1 <- MeanEVCENTRemoval1[,-1]
MeanEVCENTRemoval2 <- read.csv("MeanEVCENTRemoval2.csv", header = TRUE)
MeanEVCENTRemoval2 <- MeanEVCENTRemoval2[,-1]
MeanEVCENTRemoval3 <- read.csv("MeanEVCENTRemoval3.csv", header = TRUE)
MeanEVCENTRemoval3 <- MeanEVCENTRemoval3[,-1]
MeanEVCENTRemoval4 <- read.csv("MeanEVCENTRemoval4.csv", header = TRUE)
MeanEVCENTRemoval4 <- MeanEVCENTRemoval4[,-1]
MeanEVCENTRemoval5 <- read.csv("MeanEVCENTRemoval5.csv", header = TRUE)
MeanEVCENTRemoval5 <- MeanEVCENTRemoval5[,-1]
MeanEVCENTRemoval6 <- read.csv("MeanEVCENTRemoval6.csv", header = TRUE)
MeanEVCENTRemoval6 <- MeanEVCENTRemoval6[,-1]
MeanEVCENTRemoval7 <- read.csv("MeanEVCENTRemoval7.csv", header = TRUE)
MeanEVCENTRemoval7 <- MeanEVCENTRemoval7[,-1]
MeanEVCENTRemoval8 <- read.csv("MeanEVCENTRemoval8.csv", header = TRUE)
MeanEVCENTRemoval8 <- MeanEVCENTRemoval8[,-1]
MeanEVCENTRemoval9 <- read.csv("MeanEVCENTRemoval9.csv", header = TRUE)
MeanEVCENTRemoval9 <- MeanEVCENTRemoval9[,-1]
MeanEVCENTRemoval10 <- read.csv("MeanEVCENTRemoval10.csv", header = TRUE)
MeanEVCENTRemoval10 <- MeanEVCENTRemoval10[,-1]
MeanEVCENTRemoval11 <- read.csv("MeanEVCENTRemoval11.csv", header = TRUE)
MeanEVCENTRemoval11 <- MeanEVCENTRemoval11[,-1]

#NumberClustersRemoval
NumberClustersRemoval1 <- read.csv("NumberClustersRemoval1.csv", header = TRUE)
NumberClustersRemoval1 <- NumberClustersRemoval1[,-1]
NumberClustersRemoval2 <- read.csv("NumberClustersRemoval2.csv", header = TRUE)
NumberClustersRemoval2 <- NumberClustersRemoval2[,-1]
NumberClustersRemoval3 <- read.csv("NumberClustersRemoval3.csv", header = TRUE)
NumberClustersRemoval3 <- NumberClustersRemoval3[,-1]
NumberClustersRemoval4 <- read.csv("NumberClustersRemoval4.csv", header = TRUE)
NumberClustersRemoval4 <- NumberClustersRemoval4[,-1]
NumberClustersRemoval5 <- read.csv("NumberClustersRemoval5.csv", header = TRUE)
NumberClustersRemoval5 <- NumberClustersRemoval5[,-1]
NumberClustersRemoval6 <- read.csv("NumberClustersRemoval6.csv", header = TRUE)
NumberClustersRemoval6 <- NumberClustersRemoval6[,-1]
NumberClustersRemoval7 <- read.csv("NumberClustersRemoval7.csv", header = TRUE)
NumberClustersRemoval7 <- NumberClustersRemoval7[,-1]
NumberClustersRemoval8 <- read.csv("NumberClustersRemoval8.csv", header = TRUE)
NumberClustersRemoval8 <- NumberClustersRemoval8[,-1]
NumberClustersRemoval9 <- read.csv("NumberClustersRemoval9.csv", header = TRUE)
NumberClustersRemoval9 <- NumberClustersRemoval9[,-1]
NumberClustersRemoval10 <- read.csv("NumberClustersRemoval10.csv", header = TRUE)
NumberClustersRemoval10 <- NumberClustersRemoval10[,-1]
NumberClustersRemoval11 <- read.csv("NumberClustersRemoval11.csv", header = TRUE)
NumberClustersRemoval11 <- NumberClustersRemoval11[,-1]

#ModularityRemoval
ModularityRemoval1 <- read.csv("ModularityRemoval1.csv", header = TRUE)
ModularityRemoval1 <- ModularityRemoval1[,-1]
ModularityRemoval2 <- read.csv("ModularityRemoval2.csv", header = TRUE)
ModularityRemoval2 <- ModularityRemoval2[,-1]
ModularityRemoval3 <- read.csv("ModularityRemoval3.csv", header = TRUE)
ModularityRemoval3 <- ModularityRemoval3[,-1]
ModularityRemoval4 <- read.csv("ModularityRemoval4.csv", header = TRUE)
ModularityRemoval4 <- ModularityRemoval4[,-1]
ModularityRemoval5 <- read.csv("ModularityRemoval5.csv", header = TRUE)
ModularityRemoval5 <- ModularityRemoval5[,-1]
ModularityRemoval6 <- read.csv("ModularityRemoval6.csv", header = TRUE)
ModularityRemoval6 <- ModularityRemoval6[,-1]
ModularityRemoval7 <- read.csv("ModularityRemoval7.csv", header = TRUE)
ModularityRemoval7 <- ModularityRemoval7[,-1]
ModularityRemoval8 <- read.csv("ModularityRemoval8.csv", header = TRUE)
ModularityRemoval8 <- ModularityRemoval8[,-1]
ModularityRemoval9 <- read.csv("ModularityRemoval9.csv", header = TRUE)
ModularityRemoval9 <- ModularityRemoval9[,-1]
ModularityRemoval10 <- read.csv("ModularityRemoval10.csv", header = TRUE)
ModularityRemoval10 <- ModularityRemoval10[,-1]
ModularityRemoval11 <- read.csv("ModularityRemoval11.csv", header = TRUE)
ModularityRemoval11 <- ModularityRemoval11[,-1]

#MeanNumberReached
MeanNumberReachedRemoval1 <- read.csv("MeanNumberReachedRemoval1.csv", header = TRUE)
MeanNumberReachedRemoval1 <- MeanNumberReachedRemoval1[,-1]
MeanNumberReachedRemoval2 <- read.csv("MeanNumberReachedRemoval2.csv", header = TRUE)
MeanNumberReachedRemoval2 <- MeanNumberReachedRemoval2[,-1]
MeanNumberReachedRemoval3 <- read.csv("MeanNumberReachedRemoval3.csv", header = TRUE)
MeanNumberReachedRemoval3 <- MeanNumberReachedRemoval3[,-1]
MeanNumberReachedRemoval4 <- read.csv("MeanNumberReachedRemoval4.csv", header = TRUE)
MeanNumberReachedRemoval4 <- MeanNumberReachedRemoval4[,-1]
MeanNumberReachedRemoval5 <- read.csv("MeanNumberReachedRemoval5.csv", header = TRUE)
MeanNumberReachedRemoval5 <- MeanNumberReachedRemoval5[,-1]
MeanNumberReachedRemoval6 <- read.csv("MeanNumberReachedRemoval6.csv", header = TRUE)
MeanNumberReachedRemoval6 <- MeanNumberReachedRemoval6[,-1]
MeanNumberReachedRemoval7 <- read.csv("MeanNumberReachedRemoval7.csv", header = TRUE)
MeanNumberReachedRemoval7 <- MeanNumberReachedRemoval7[,-1]
MeanNumberReachedRemoval8 <- read.csv("MeanNumberReachedRemoval8.csv", header = TRUE)
MeanNumberReachedRemoval8 <- MeanNumberReachedRemoval8[,-1]
MeanNumberReachedRemoval9 <- read.csv("MeanNumberReachedRemoval9.csv", header = TRUE)
MeanNumberReachedRemoval9 <- MeanNumberReachedRemoval9[,-1]
MeanNumberReachedRemoval10 <- read.csv("MeanNumberReachedRemoval10.csv", header = TRUE)
MeanNumberReachedRemoval10 <- MeanNumberReachedRemoval10[,-1]
MeanNumberReachedRemoval11 <- read.csv("MeanNumberReachedRemoval11.csv", header = TRUE)
MeanNumberReachedRemoval11 <- MeanNumberReachedRemoval11[,-1]

#ClosenessCentralizationRemoval
ClosenessCentralizationRemoval1 <- read.csv("ClosenessCentralizationRemoval1.csv", header = TRUE)
ClosenessCentralizationRemoval1 <- ClosenessCentralizationRemoval1[,-1]
ClosenessCentralizationRemoval2 <- read.csv("ClosenessCentralizationRemoval2.csv", header = TRUE)
ClosenessCentralizationRemoval2 <- ClosenessCentralizationRemoval2[,-1]
ClosenessCentralizationRemoval3 <- read.csv("ClosenessCentralizationRemoval3.csv", header = TRUE)
ClosenessCentralizationRemoval3 <- ClosenessCentralizationRemoval3[,-1]
ClosenessCentralizationRemoval4 <- read.csv("ClosenessCentralizationRemoval4.csv", header = TRUE)
ClosenessCentralizationRemoval4 <- ClosenessCentralizationRemoval4[,-1]
ClosenessCentralizationRemoval5 <- read.csv("ClosenessCentralizationRemoval5.csv", header = TRUE)
ClosenessCentralizationRemoval5 <- ClosenessCentralizationRemoval5[,-1]
ClosenessCentralizationRemoval6 <- read.csv("ClosenessCentralizationRemoval6.csv", header = TRUE)
ClosenessCentralizationRemoval6 <- ClosenessCentralizationRemoval6[,-1]
ClosenessCentralizationRemoval7 <- read.csv("ClosenessCentralizationRemoval7.csv", header = TRUE)
ClosenessCentralizationRemoval7 <- ClosenessCentralizationRemoval7[,-1]
ClosenessCentralizationRemoval8 <- read.csv("ClosenessCentralizationRemoval8.csv", header = TRUE)
ClosenessCentralizationRemoval8 <- ClosenessCentralizationRemoval8[,-1]
ClosenessCentralizationRemoval9 <- read.csv("ClosenessCentralizationRemoval9.csv", header = TRUE)
ClosenessCentralizationRemoval9 <- ClosenessCentralizationRemoval9[,-1]
ClosenessCentralizationRemoval10 <- read.csv("ClosenessCentralizationRemoval10.csv", header = TRUE)
ClosenessCentralizationRemoval10 <- ClosenessCentralizationRemoval10[,-1]
ClosenessCentralizationRemoval11 <- read.csv("ClosenessCentralizationRemoval11.csv", header = TRUE)
ClosenessCentralizationRemoval11 <- ClosenessCentralizationRemoval11[,-1]

#combine output data frames
MeanNodeDegreeRemoval <- rbind(MeanNodeDegreeRemoval1, MeanNodeDegreeRemoval2, MeanNodeDegreeRemoval3, MeanNodeDegreeRemoval4,
MeanNodeDegreeRemoval5, MeanNodeDegreeRemoval6, MeanNodeDegreeRemoval7, MeanNodeDegreeRemoval8, MeanNodeDegreeRemoval9,
MeanNodeDegreeRemoval10, MeanNodeDegreeRemoval11)

DegreeCentralizationRemoval <- rbind(DegreeCentralizationRemoval1, DegreeCentralizationRemoval2, DegreeCentralizationRemoval3, DegreeCentralizationRemoval4,
DegreeCentralizationRemoval5, DegreeCentralizationRemoval6, DegreeCentralizationRemoval7, DegreeCentralizationRemoval8, DegreeCentralizationRemoval9,
DegreeCentralizationRemoval10, DegreeCentralizationRemoval11)

MeanNodeBetweennessRemoval <- rbind(MeanNodeBetweennessRemoval1, MeanNodeBetweennessRemoval2, MeanNodeBetweennessRemoval3, MeanNodeBetweennessRemoval4,
MeanNodeBetweennessRemoval5, MeanNodeBetweennessRemoval6, MeanNodeBetweennessRemoval7, MeanNodeBetweennessRemoval8, MeanNodeBetweennessRemoval9,
MeanNodeBetweennessRemoval10, MeanNodeBetweennessRemoval11)

MeanEdgeBetweennessRemoval <- rbind(MeanEdgeBetweennessRemoval1, MeanEdgeBetweennessRemoval2, MeanEdgeBetweennessRemoval3, MeanEdgeBetweennessRemoval4,
MeanEdgeBetweennessRemoval5, MeanEdgeBetweennessRemoval6, MeanEdgeBetweennessRemoval7, MeanEdgeBetweennessRemoval8, MeanEdgeBetweennessRemoval9,
MeanEdgeBetweennessRemoval10, MeanEdgeBetweennessRemoval11)

BetweennessCentralizationRemoval <- rbind(BetweennessCentralizationRemoval1, BetweennessCentralizationRemoval2, BetweennessCentralizationRemoval3, BetweennessCentralizationRemoval4,
BetweennessCentralizationRemoval5, BetweennessCentralizationRemoval6, BetweennessCentralizationRemoval7, BetweennessCentralizationRemoval8, BetweennessCentralizationRemoval9,
BetweennessCentralizationRemoval10, BetweennessCentralizationRemoval11)

MeanEVCENTRemoval <- rbind(MeanEVCENTRemoval1, MeanEVCENTRemoval2, MeanEVCENTRemoval3, MeanEVCENTRemoval4,
MeanEVCENTRemoval5, MeanEVCENTRemoval6, MeanEVCENTRemoval7, MeanEVCENTRemoval8, MeanEVCENTRemoval9,
MeanEVCENTRemoval10, MeanEVCENTRemoval11)

NumberClustersRemoval <- rbind(NumberClustersRemoval1, NumberClustersRemoval2, NumberClustersRemoval3, NumberClustersRemoval4,
NumberClustersRemoval5, NumberClustersRemoval6, NumberClustersRemoval7, NumberClustersRemoval8, NumberClustersRemoval9,
NumberClustersRemoval10, NumberClustersRemoval11)

ModularityRemoval <- rbind(ModularityRemoval1, ModularityRemoval2, ModularityRemoval3, ModularityRemoval4,
ModularityRemoval5, ModularityRemoval6, ModularityRemoval7, ModularityRemoval8, ModularityRemoval9,
ModularityRemoval10, ModularityRemoval11)

MeanNumberReachedRemoval <- rbind(MeanNumberReachedRemoval1, MeanNumberReachedRemoval2, MeanNumberReachedRemoval3, MeanNumberReachedRemoval4,
MeanNumberReachedRemoval5, MeanNumberReachedRemoval6, MeanNumberReachedRemoval7, MeanNumberReachedRemoval8, MeanNumberReachedRemoval9,
MeanNumberReachedRemoval10, MeanNumberReachedRemoval11)

ClosenessCentralizationRemoval <- rbind(ClosenessCentralizationRemoval1, ClosenessCentralizationRemoval2, ClosenessCentralizationRemoval3, ClosenessCentralizationRemoval4,
ClosenessCentralizationRemoval5, ClosenessCentralizationRemoval6, ClosenessCentralizationRemoval7, ClosenessCentralizationRemoval8, ClosenessCentralizationRemoval9,
ClosenessCentralizationRemoval10, ClosenessCentralizationRemoval11)

#read in updated contemporary wetlands and pits shapefile
ContWetsAndPits <- readOGR("ContWetsAndPitsOneKMNetwork1.shp", "ContWetsAndPitsOneKMNetwork1", verbose = TRUE, p4s = NULL)

#add new outputs to attribute table
#ContWetsAndPits@data$Degree <- DegreeHalfKMNetwork
#ContWetsAndPits@data$NodeBetween <- HalfKMNodeBetweenness
ContWetsAndPits@data$RemDeg <- MeanNodeDegreeRemoval$Degree
ContWetsAndPits@data$DegCentRem <- DegreeCentralizationRemoval$DegreeCent
ContWetsAndPits@data$NodeBtwRem <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWetsAndPits@data$EdgeBetRem <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWetsAndPits@data$BtwCentRem <- BetweennessCentralizationRemoval$BetweenCent
ContWetsAndPits@data$evcentRem <- MeanEVCENTRemoval$evcent
ContWetsAndPits@data$NumClustRem <- NumberClustersRemoval$NoClusters
ContWetsAndPits@data$ModRem <- ModularityRemoval$Modularity
ContWetsAndPits@data$NumReachRem <- MeanNumberReachedRemoval$MeanNumReached
ContWetsAndPits@data$CloseCentRem <- ClosenessCentralizationRemoval$CloseCent

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWetsAndPits, "ContWetsAndPitsOneKMNetwork2", "ContWetsAndPitsOneKMNetwork2", driver = 'ESRI Shapefile', verbose = TRUE)

#####
#####
#####
#1.5 km
retain <- c("FromNode", "ToNode")
OneAndHalfKMPaths1 <- read.csv("OneAndHalfKMPaths1.csv")
OneAndHalfKMPaths1$FromNode <- OneAndHalfKMPaths1$unlist.FromNode1.
OneAndHalfKMPaths1$ToNode <- OneAndHalfKMPaths1$unlist.ToNode1.
OneAndHalfKMPaths1 <- OneAndHalfKMPaths1[retain]

OneAndHalfKMPaths2 <- read.csv("OneAndHalfKMPaths2.csv")
OneAndHalfKMPaths2$FromNode <- OneAndHalfKMPaths2$unlist.FromNode2.
OneAndHalfKMPaths2$ToNode <- OneAndHalfKMPaths2$unlist.ToNode2.
OneAndHalfKMPaths2 <- OneAndHalfKMPaths2[retain]

OneAndHalfKMPaths3 <- read.csv("OneAndHalfKMPaths3.csv")
OneAndHalfKMPaths3$FromNode <- OneAndHalfKMPaths3$unlist.FromNode3.
OneAndHalfKMPaths3$ToNode <- OneAndHalfKMPaths3$unlist.ToNode3.
OneAndHalfKMPaths3 <- OneAndHalfKMPaths3[retain]

OneAndHalfKMPaths4 <- read.csv("OneAndHalfKMPaths4.csv")
OneAndHalfKMPaths4$FromNode <- OneAndHalfKMPaths4$unlist.FromNode4.
OneAndHalfKMPaths4$ToNode <- OneAndHalfKMPaths4$unlist.ToNode4.
OneAndHalfKMPaths4 <- OneAndHalfKMPaths4[retain]

OneAndHalfKMPaths5 <- read.csv("OneAndHalfKMPaths5.csv")
OneAndHalfKMPaths5$FromNode <- OneAndHalfKMPaths5$unlist.FromNode5.
OneAndHalfKMPaths5$ToNode <- OneAndHalfKMPaths5$unlist.ToNode5.
OneAndHalfKMPaths5 <- OneAndHalfKMPaths5[retain]

OneAndHalfKMPaths6 <- read.csv("OneAndHalfKMPaths6.csv")
OneAndHalfKMPaths6$FromNode <- OneAndHalfKMPaths6$unlist.FromNode6.
OneAndHalfKMPaths6$ToNode <- OneAndHalfKMPaths6$unlist.ToNode6.
OneAndHalfKMPaths6 <- OneAndHalfKMPaths6[retain]

OneAndHalfKMPaths7 <- read.csv("OneAndHalfKMPaths7.csv")
OneAndHalfKMPaths7$FromNode <- OneAndHalfKMPaths7$unlist.FromNode7.
OneAndHalfKMPaths7$ToNode <- OneAndHalfKMPaths7$unlist.ToNode7.
OneAndHalfKMPaths7 <- OneAndHalfKMPaths7[retain]

#combine 1.5 km connections into 1 data frame
OneAndHalfKMPathsCombined <- rbind(OneAndHalfKMPaths1, OneAndHalfKMPaths2, OneAndHalfKMPaths3, OneAndHalfKMPaths4, OneAndHalfKMPaths5, OneAndHalfKMPaths6, OneAndHalfKMPaths7)
OneAndHalfKMPathsCombined <- as.matrix(OneAndHalfKMPathsCombined[-28379,])

#create network with nodes and associated edges
OneAndHalfKMNetwork <- graph(n = 10161, edges = OneAndHalfKMPathsCombined, directed = FALSE)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
OneAndHalfKMNodeBetweenness <- betweenness(OneAndHalfKMNetwork, v = V(OneAndHalfKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
OneAndHalfKMNodeBetweenness
MeanNodeBetweennessOneAndHalfKM <- mean(OneAndHalfKMNodeBetweenness)
MeanNodeBetweennessOneAndHalfKM

OneAndHalfKMEdgeBetweenness <- edge.betweenness(OneAndHalfKMNetwork, e = E(OneAndHalfKMNetwork), directed = FALSE, weights = NULL)
OneAndHalfKMEdgeBetweenness
MeanEdgeBetweennessOneAndHalfKM <- mean(OneAndHalfKMEdgeBetweenness)
MeanEdgeBetweennessOneAndHalfKM

#calculate degree (number of adjacent edges for each node)
DegreeOneAndHalfKMNetwork <- degree(OneAndHalfKMNetwork, v = V(OneAndHalfKMNetwork), loops = TRUE)
DegreeOneAndHalfKMNetwork
MeanDegreeOneAndHalfKMNetwork <- mean(DegreeOneAndHalfKMNetwork)
MeanDegreeOneAndHalfKMNetwork

#find number of clusters (groups of connected graph components)
OneAndHalfKMNetworkNumberClusters <- no.clusters(OneAndHalfKMNetwork)
OneAndHalfKMNetworkNumberClusters

#find mean number of vertices per cluster
OneAndHalfKMNetworkClusters <- clusters(OneAndHalfKMNetwork)
summary(OneAndHalfKMNetworkClusters$csize)
OneAndHalfKMNetworkMeanClusterSize <- mean(OneAndHalfKMNetworkClusters$csize)
OneAndHalfKMNetworkMeanClusterSize

#calculate modularity
OneAndHalfKMNetworkModularity <- modularity(OneAndHalfKMNetwork, V(OneAndHalfKMNetwork))
OneAndHalfKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
OneAndHalfKMNetworkSC <- list(NA)
NumberReachedOneAndHalfKM <- list(NA)
for(i in 1:nrow(ContWetsAndPits@data)){
	OneAndHalfKMNetworkSC[[i]] <- subcomponent(OneAndHalfKMNetwork, v = i)
	NumberReachedOneAndHalfKM[[i]] <- length(OneAndHalfKMNetworkSC[[i]]) - 1
}
NumberReachedOneAndHalfKM <- unlist(NumberReachedOneAndHalfKM)
NumberReachedOneAndHalfKMMean <- mean(NumberReachedOneAndHalfKM)
NumberReachedOneAndHalfKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
OneAndHalfKMNetworkEBC <- edge.betweenness.community(OneAndHalfKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
OneAndHalfKMNetworkEVCENT <- evcent(OneAndHalfKMNetwork, directed = FALSE, scale = FALSE)
OneAndHalfKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
OneAndHalfKMNetworkGraphDensity <- graph.density(OneAndHalfKMNetwork, loops = TRUE)
OneAndHalfKMNetworkGraphDensity

#identify neighbors of each vertice
OneAndHalfKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWetsAndPits@data)){
	OneAndHalfKMNetworkNeighbors[[i]] <- neighbors(OneAndHalfKMNetwork, v = i)
}
OneAndHalfKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
OneAndHalfKMNetworkNeighborSize <- neighborhood.size(OneAndHalfKMNetwork, order = 1, nodes = V(OneAndHalfKMNetwork))
OneAndHalfKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
OneAndHalfKMNetworkGraphCohesion <- graph.cohesion(OneAndHalfKMNetwork)
OneAndHalfKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
OneAndHalfKMNetworkAPL <- average.path.length(OneAndHalfKMNetwork, directed = FALSE, unconnected = TRUE)
OneAndHalfKMNetworkAPL

#generate histogram of shortest path lengths
OneAndHalfKMNetworkAPLHist <- path.length.hist(OneAndHalfKMNetwork, directed = FALSE)
OneAndHalfKMNetworkAPLHist

#update and re-write attribute table, prior to dealing with memory allocation issues
ContWetsAndPits@data$Degree <- DegreeOneAndHalfKMNetwork
ContWetsAndPits@data$NodeBetween <- OneAndHalfKMNodeBetweenness
writeOGR(ContWetsAndPits, "ContWetsAndPitsOneAndHalfKMNetwork1", "ContWetsAndPitsOneAndHalfKMNetwork1", driver = 'ESRI Shapefile', verbose = TRUE)

#experiment with deleting vertices/edges
#####
#####
#####
#part 1
NodeRemove1 <- list(NA)
MeanNodeDegreeRemoval1 <- list(NA)
MeanNodeBetweennessRemoval1 <- list(NA)
MeanEdgeBetweennessRemoval1 <- list(NA)
GraphDensityRemoval1 <- list(NA)
MeanShortPathLengthRemoval1 <- list(NA)
for(i in 1:3387){
	NodeRemove1[[i]] <- OneAndHalfHalfKMNetwork
	NodeRemove1[[i]][i] <- FALSE
	MeanNodeDegreeRemoval1[[i]] <- mean(degree(NodeRemove1[[i]], v = V(NodeRemove1[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval1[[i]] <- mean(betweenness(NodeRemove1[[i]], v = V(NodeRemove1[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval1[[i]] <- mean(edge.betweenness(NodeRemove1[[i]], e = E(NodeRemove1[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval1[[i]] <- graph.density(NodeRemove1[[i]], loops = TRUE)
	MeanShortPathLengthRemoval1[[i]] <- average.path.length(NodeRemove1[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval1 <- unlist(MeanNodeDegreeRemoval1)
MeanNodeDegreeRemoval1 <- data.frame(MeanNodeDegreeRemoval1)
MeanNodeDegreeRemoval1$Degree <- MeanNodeDegreeRemoval1[,1]
MeanNodeDegreeRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanNodeDegreeRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[retain]
head(MeanNodeDegreeRemoval1)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval1 <- unlist(MeanNodeBetweennessRemoval1)
MeanNodeBetweennessRemoval1 <- data.frame(MeanNodeBetweennessRemoval1)
MeanNodeBetweennessRemoval1$NodeBetweenness <- MeanNodeBetweennessRemoval1[,1]
MeanNodeBetweennessRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanNodeBetweennessRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[retain]
head(MeanNodeBetweennessRemoval1)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval1 <- unlist(MeanEdgeBetweennessRemoval1)
MeanEdgeBetweennessRemoval1 <- data.frame(MeanEdgeBetweennessRemoval1)
MeanEdgeBetweennessRemoval1$EdgeBetweenness <- MeanEdgeBetweennessRemoval1[,1]
MeanEdgeBetweennessRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanEdgeBetweennessRemoval1$FP_ID <- ContWetAndPitss@data[1:3387,]$FP_ID
#MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[retain]
head(MeanEdgeBetweennessRemoval1)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval1 <- unlist(GraphDensityRemoval1)
GraphDensityRemoval1 <- data.frame(GraphDensityRemoval1)
GraphDensityRemoval1$GraphDensity <- GraphDensityRemoval1[,1]
GraphDensityRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
GraphDensityRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#GraphDensityRemoval1 <- GraphDensityRemoval1[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval1 <- GraphDensityRemoval1[retain]
head(GraphDensityRemoval1)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval1 <- unlist(MeanShortPathLengthRemoval1)
MeanShortPathLengthRemoval1 <- data.frame(MeanShortPathLengthRemoval1)
MeanShortPathLengthRemoval1$MeanPathLength <- MeanShortPathLengthRemoval1[,1]
MeanShortPathLengthRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanShortPathLengthRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanShortPathLengthRemoval1 <- MeanShortPathLengthRemoval1[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval1 <- MeanShortPathLengthRemoval1[retain]
head(MeanShortPathLengthRemoval1)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval1, "MeanNodeDegreeRemoval1.csv")
write.csv(MeanNodeBetweennessRemoval1, "MeanNodeBetweennessRemoval1.csv")
write.csv(MeanEdgeBetweennessRemoval1, "MeanEdgeBetweennessRemoval1.csv")
write.csv(GraphDensityRemoval1, "GraphDensityRemoval1.csv")
write.csv(MeanShortPathLengthRemoval1, "MeanShortPathLengthRemoval1.csv")

#####
#####
#####
#part 2
NodeRemove2 <- list(NA)
MeanNodeDegreeRemoval2 <- list(NA)
MeanNodeBetweennessRemoval2 <- list(NA)
MeanEdgeBetweennessRemoval2 <- list(NA)
GraphDensityRemoval2 <- list(NA)
MeanShortPathLengthRemoval2 <- list(NA)
for(i in 1:3387){
	NodeRemove2[[i]] <- HalfKMNetwork
	NodeRemove2[[i]][3387 + i] <- FALSE
	MeanNodeDegreeRemoval2[[i]] <- mean(degree(NodeRemove2[[i]], v = V(NodeRemove2[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval2[[i]] <- mean(betweenness(NodeRemove2[[i]], v = V(NodeRemove2[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval2[[i]] <- mean(edge.betweenness(NodeRemove2[[i]], e = E(NodeRemove2[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval2[[i]] <- graph.density(NodeRemove2[[i]], loops = TRUE)
	MeanShortPathLengthRemoval2[[i]] <- average.path.length(NodeRemove2[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval2 <- unlist(MeanNodeDegreeRemoval2)
MeanNodeDegreeRemoval2 <- data.frame(MeanNodeDegreeRemoval2)
MeanNodeDegreeRemoval2$Degree <- MeanNodeDegreeRemoval2[,1]
MeanNodeDegreeRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanNodeDegreeRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[retain]
head(MeanNodeDegreeRemoval2)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval2 <- unlist(MeanNodeBetweennessRemoval2)
MeanNodeBetweennessRemoval2 <- data.frame(MeanNodeBetweennessRemoval2)
MeanNodeBetweennessRemoval2$NodeBetweenness <- MeanNodeBetweennessRemoval2[,1]
MeanNodeBetweennessRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanNodeBetweennessRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[retain]
head(MeanNodeBetweennessRemoval2)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval2 <- unlist(MeanEdgeBetweennessRemoval2)
MeanEdgeBetweennessRemoval2 <- data.frame(MeanEdgeBetweennessRemoval2)
MeanEdgeBetweennessRemoval2$EdgeBetweenness <- MeanEdgeBetweennessRemoval2[,1]
MeanEdgeBetweennessRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanEdgeBetweennessRemoval2$FP_ID <- ContWetAndPitss@data[3388:6774,]$FP_ID
#MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[retain]
head(MeanEdgeBetweennessRemoval2)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval2 <- unlist(GraphDensityRemoval2)
GraphDensityRemoval2 <- data.frame(GraphDensityRemoval2)
GraphDensityRemoval2$GraphDensity <- GraphDensityRemoval2[,1]
GraphDensityRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
GraphDensityRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#GraphDensityRemoval2 <- GraphDensityRemoval2[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval2 <- GraphDensityRemoval2[retain]
head(GraphDensityRemoval2)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval2 <- unlist(MeanShortPathLengthRemoval2)
MeanShortPathLengthRemoval2 <- data.frame(MeanShortPathLengthRemoval2)
MeanShortPathLengthRemoval2$MeanPathLength <- MeanShortPathLengthRemoval2[,1]
MeanShortPathLengthRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanShortPathLengthRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanShortPathLengthRemoval2 <- MeanShortPathLengthRemoval2[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval2 <- MeanShortPathLengthRemoval2[retain]
head(MeanShortPathLengthRemoval2)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval2, "MeanNodeDegreeRemoval2.csv")
write.csv(MeanNodeBetweennessRemoval2, "MeanNodeBetweennessRemoval2.csv")
write.csv(MeanEdgeBetweennessRemoval2, "MeanEdgeBetweennessRemoval2.csv")
write.csv(GraphDensityRemoval2, "GraphDensityRemoval2.csv")
write.csv(MeanShortPathLengthRemoval2, "MeanShortPathLengthRemoval2.csv")

#####
#####
#####
#part 3
NodeRemove3 <- list(NA)
MeanNodeDegreeRemoval3 <- list(NA)
MeanNodeBetweennessRemoval3 <- list(NA)
MeanEdgeBetweennessRemoval3 <- list(NA)
GraphDensityRemoval3 <- list(NA)
MeanShortPathLengthRemoval3 <- list(NA)
for(i in 1:3387){
	NodeRemove3[[i]] <- HalfKMNetwork
	NodeRemove3[[i]][6774 + i] <- FALSE
	MeanNodeDegreeRemoval3[[i]] <- mean(degree(NodeRemove3[[i]], v = V(NodeRemove3[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval3[[i]] <- mean(betweenness(NodeRemove3[[i]], v = V(NodeRemove3[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval3[[i]] <- mean(edge.betweenness(NodeRemove3[[i]], e = E(NodeRemove3[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval3[[i]] <- graph.density(NodeRemove3[[i]], loops = TRUE)
	MeanShortPathLengthRemoval3[[i]] <- average.path.length(NodeRemove3[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval3 <- unlist(MeanNodeDegreeRemoval3)
MeanNodeDegreeRemoval3 <- data.frame(MeanNodeDegreeRemoval3)
MeanNodeDegreeRemoval3$Degree <- MeanNodeDegreeRemoval3[,1]
MeanNodeDegreeRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanNodeDegreeRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[retain]
head(MeanNodeDegreeRemoval3)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval3 <- unlist(MeanNodeBetweennessRemoval3)
MeanNodeBetweennessRemoval3 <- data.frame(MeanNodeBetweennessRemoval3)
MeanNodeBetweennessRemoval3$NodeBetweenness <- MeanNodeBetweennessRemoval3[,1]
MeanNodeBetweennessRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanNodeBetweennessRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[retain]
head(MeanNodeBetweennessRemoval3)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval3 <- unlist(MeanEdgeBetweennessRemoval3)
MeanEdgeBetweennessRemoval3 <- data.frame(MeanEdgeBetweennessRemoval3)
MeanEdgeBetweennessRemoval3$EdgeBetweenness <- MeanEdgeBetweennessRemoval3[,1]
MeanEdgeBetweennessRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanEdgeBetweennessRemoval3$FP_ID <- ContWetAndPitss@data[6775:10161,]$FP_ID
#MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[retain]
head(MeanEdgeBetweennessRemoval3)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval3 <- unlist(GraphDensityRemoval3)
GraphDensityRemoval3 <- data.frame(GraphDensityRemoval3)
GraphDensityRemoval3$GraphDensity <- GraphDensityRemoval3[,1]
GraphDensityRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
GraphDensityRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#GraphDensityRemoval3 <- GraphDensityRemoval3[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval3 <- GraphDensityRemoval3[retain]
head(GraphDensityRemoval3)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval3 <- unlist(MeanShortPathLengthRemoval3)
MeanShortPathLengthRemoval3 <- data.frame(MeanShortPathLengthRemoval3)
MeanShortPathLengthRemoval3$MeanPathLength <- MeanShortPathLengthRemoval3[,1]
MeanShortPathLengthRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanShortPathLengthRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanShortPathLengthRemoval3 <- MeanShortPathLengthRemoval3[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval3 <- MeanShortPathLengthRemoval3[retain]
head(MeanShortPathLengthRemoval3)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval3, "MeanNodeDegreeRemoval3.csv")
write.csv(MeanNodeBetweennessRemoval3, "MeanNodeBetweennessRemoval3.csv")
write.csv(MeanEdgeBetweennessRemoval3, "MeanEdgeBetweennessRemoval3.csv")
write.csv(GraphDensityRemoval3, "GraphDensityRemoval3.csv")
write.csv(MeanShortPathLengthRemoval3, "MeanShortPathLengthRemoval3.csv")

#combine output attributes from 3 parts
MeanNodeDegreeRemoval <- rbind(MeanNodeDegreeRemoval1, MeanNodeDegreeRemoval2, MeanNodeDegreeRemoval3)
MeanNodeBetweennessRemoval <- rbind(MeanNodeBetweennessRemoval1, MeanNodeBetweennessRemoval2, MeanNodeBetweennessRemoval3)
MeanEdgeBetweennessRemoval <- rbind(MeanEdgeBetweennessRemoval1, MeanEdgeBetweennessRemoval2, MeanEdgeBetweennessRemoval3)
GraphDensityRemoval <- rbind(GraphDensityRemoval1, GraphDensityRemoval2, GraphDensityRemoval3)
MeanShortPathLengthRemoval <- rbind(MeanShortPathLengthRemoval1, MeanShortPathLengthRemoval2, MeanShortPathLengthRemoval3)

#read in updated contemporary wetlands and pits shapefile
ContWetsAndPits <- readOGR("ContWetsAndPitsOneAndHalfKMNetwork1.shp", "ContWetsAndPitsOneAndHalfKMNetwork1", verbose = TRUE, p4s = NULL)

#add new outputs to attribute table
ContWetsAndPits@data$Degree <- DegreeOneKMNetwork
ContWetsAndPits@data$NodeBetween <- OneKMNodeBetweenness
ContWetsAndPits@data$RemDeg <- MeanNodeDegreeRemoval$Degree
ContWetsAndPits@data$RemNodeBetween <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWetsAndPits@data$RemEdgeBetween <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWetsAndPits@data$RemGraphDenity <- GraphDensityRemoval$GraphDensity
ContWetsAndPits@data$RemShortPath <- MeanShortPathLengthRemoval$MeanPathLength

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWetsAndPits, "ContWetsAndPitsOneAndHalfKMNetwork2", "ContWetsAndPitsOneAndHalfKMNetwork2", driver = 'ESRI Shapefile', verbose = TRUE)

#####
#####
#####
#2.0 km
retain <- c("FromNode", "ToNode")
TwoKMPaths1 <- read.csv("TwoKMPaths1.csv")
TwoKMPaths1$FromNode <- TwoKMPaths1$unlist.FromNode1.
TwoKMPaths1$ToNode <- TwoKMPaths1$unlist.ToNode1.
TwoKMPaths1 <- TwoKMPaths1[retain]

TwoKMPaths2 <- read.csv("TwoKMPaths2.csv")
TwoKMPaths2$FromNode <- TwoKMPaths2$unlist.FromNode2.
TwoKMPaths2$ToNode <- TwoKMPaths2$unlist.ToNode2.
TwoKMPaths2 <- TwoKMPaths2[retain]

TwoKMPaths3 <- read.csv("TwoKMPaths3.csv")
TwoKMPaths3$FromNode <- TwoKMPaths3$unlist.FromNode3.
TwoKMPaths3$ToNode <- TwoKMPaths3$unlist.ToNode3.
TwoKMPaths3 <- TwoKMPaths3[retain]

TwoKMPaths4 <- read.csv("TwoKMPaths4.csv")
TwoKMPaths4$FromNode <- TwoKMPaths4$unlist.FromNode4.
TwoKMPaths4$ToNode <- TwoKMPaths4$unlist.ToNode4.
TwoKMPaths4 <- TwoKMPaths4[retain]

TwoKMPaths5 <- read.csv("TwoKMPaths5.csv")
TwoKMPaths5$FromNode <- TwoKMPaths5$unlist.FromNode5.
TwoKMPaths5$ToNode <- TwoKMPaths5$unlist.ToNode5.
TwoKMPaths5 <- TwoKMPaths5[retain]

TwoKMPaths6 <- read.csv("TwoKMPaths6.csv")
TwoKMPaths6$FromNode <- TwoKMPaths6$unlist.FromNode6.
TwoKMPaths6$ToNode <- TwoKMPaths6$unlist.ToNode6.
TwoKMPaths6 <- TwoKMPaths6[retain]

TwoKMPaths7 <- read.csv("TwoKMPaths7.csv")
TwoKMPaths7$FromNode <- TwoKMPaths7$unlist.FromNode7.
TwoKMPaths7$ToNode <- TwoKMPaths7$unlist.ToNode7.
TwoKMPaths7 <- TwoKMPaths7[retain]

#combine 2.0 km connections into 1 data frame
TwoKMPathsCombined <- rbind(TwoKMPaths1, TwoKMPaths2, TwoKMPaths3, TwoKMPaths4, TwoKMPaths5, TwoKMPaths6, TwoKMPaths7)
TwoKMPathsCombined <- as.matrix(TwoKMPathsCombined[-49983,])

#create network with nodes and associated edges
TwoKMNetwork <- graph(n = 10161, edges = TwoKMPathsCombined, directed = FALSE)

#calculate node and edge betweeness for graph (number of shortest paths going through node or edge)
TwoKMNodeBetweenness <- betweenness(TwoKMNetwork, v = V(TwoKMNetwork), directed = FALSE, weights = NULL, normalized = FALSE)
TwoKMNodeBetweenness
MeanNodeBetweennessTwoKM <- mean(TwoKMNodeBetweenness)
MeanNodeBetweennessTwoKM

TwoKMEdgeBetweenness <- edge.betweenness(TwoKMNetwork, e = E(TwoKMNetwork), directed = FALSE, weights = NULL)
TwoKMEdgeBetweenness
MeanEdgeBetweennessTwoKM <- mean(TwoKMEdgeBetweenness)
MeanEdgeBetweennessTwoKM

#calculate degree (number of adjacent edges for each node)
DegreeTwoKMNetwork <- degree(TwoKMNetwork, v = V(TwoKMNetwork), loops = TRUE)
DegreeTwoKMNetwork
MeanDegreeTwoKMNetwork <- mean(DegreeTwoKMNetwork)
MeanDegreeTwoKMNetwork

#find number of clusters (groups of connected graph components)
TwoKMNetworkNumberClusters <- no.clusters(TwoKMNetwork)
TwoKMNetworkNumberClusters

#find mean number of vertices per cluster
TwoKMNetworkClusters <- clusters(TwoKMNetwork)
summary(TwoKMNetworkClusters$csize)
TwoKMNetworkMeanClusterSize <- mean(TwoKMNetworkClusters$csize)
TwoKMNetworkMeanClusterSize

#calculate modularity
TwoKMNetworkModularity <- modularity(TwoKMNetwork, V(TwoKMNetwork))
TwoKMNetworkModularity

#find subcomponent (all other vertices reachable from specified vertice)
TwoKMNetworkSC <- list(NA)
NumberReachedTwoKM <- list(NA)
for(i in 1:nrow(ContWetsAndPits@data)){
	TwoKMNetworkSC[[i]] <- subcomponent(TwoKMNetwork, v = i)
	NumberReachedTwoKM[[i]] <- length(TwoKMNetworkSC[[i]]) - 1
}
NumberReachedTwoKM <- unlist(NumberReachedTwoKM)
NumberReachedTwoKMMean <- mean(NumberReachedTwoKM)
NumberReachedTwoKMMean

#edge betweeness community (creates hierarchical graph by removing edges most traveled when reaching other vertices via algorithm)
TwoKMNetworkEBC <- edge.betweenness.community(TwoKMNetwork, edge.betweenness = TRUE, merges = TRUE, bridges = TRUE)

#calculate eigenvector centrality scores of network positions (high scores = vertices connected to other highly connected which are connected to other highly connected etc...)
TwoKMNetworkEVCENT <- evcent(TwoKMNetwork, directed = FALSE, scale = FALSE)
TwoKMNetworkEVCENT

#calculate graph density (ratio of number of edges to number of possible edges)
TwoKMNetworkGraphDensity <- graph.density(TwoKMNetwork, loops = TRUE)
TwoKMNetworkGraphDensity

#identify neighbors of each vertice
TwoKMNetworkNeighbors <- list(NA)
for (i in 1:nrow(ContWetsAndPits@data)){
	TwoKMNetworkNeighbors[[i]] <- neighbors(TwoKMNetwork, v = i)
}
TwoKMNetworkNeighbors

#calculate neighborhood size (number of interconnected vertices in each neighborhood)
TwoKMNetworkNeighborSize <- neighborhood.size(TwoKMNetwork, order = 1, nodes = V(TwoKMNetwork))
TwoKMNetworkNeighborSize

#calculate graph cohesion (vertex connectivity of graph)
TwoKMNetworkGraphCohesion <- graph.cohesion(TwoKMNetwork)
TwoKMNetworkGraphCohesion

#calculate average shortest path length between connected vertices
TwoKMNetworkAPL <- average.path.length(TwoKMNetwork, directed = FALSE, unconnected = TRUE)
TwoKMNetworkAPL

#generate histogram of shortest path lengths
TwoKMNetworkAPLHist <- path.length.hist(TwoKMNetwork, directed = FALSE)
TwoKMNetworkAPLHist

#experiment with deleting vertices/edges
#####
#####
#####
#part 1
NodeRemove1 <- list(NA)
MeanNodeDegreeRemoval1 <- list(NA)
MeanNodeBetweennessRemoval1 <- list(NA)
MeanEdgeBetweennessRemoval1 <- list(NA)
GraphDensityRemoval1 <- list(NA)
MeanShortPathLengthRemoval1 <- list(NA)
for(i in 1:3387){
	NodeRemove1[[i]] <- TwoKMNetwork
	NodeRemove1[[i]][i] <- FALSE
	MeanNodeDegreeRemoval1[[i]] <- mean(degree(NodeRemove1[[i]], v = V(NodeRemove1[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval1[[i]] <- mean(betweenness(NodeRemove1[[i]], v = V(NodeRemove1[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval1[[i]] <- mean(edge.betweenness(NodeRemove1[[i]], e = E(NodeRemove1[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval1[[i]] <- graph.density(NodeRemove1[[i]], loops = TRUE)
	MeanShortPathLengthRemoval1[[i]] <- average.path.length(NodeRemove1[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval1 <- unlist(MeanNodeDegreeRemoval1)
MeanNodeDegreeRemoval1 <- data.frame(MeanNodeDegreeRemoval1)
MeanNodeDegreeRemoval1$Degree <- MeanNodeDegreeRemoval1[,1]
MeanNodeDegreeRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanNodeDegreeRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval1 <- MeanNodeDegreeRemoval1[retain]
head(MeanNodeDegreeRemoval1)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval1 <- unlist(MeanNodeBetweennessRemoval1)
MeanNodeBetweennessRemoval1 <- data.frame(MeanNodeBetweennessRemoval1)
MeanNodeBetweennessRemoval1$NodeBetweenness <- MeanNodeBetweennessRemoval1[,1]
MeanNodeBetweennessRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanNodeBetweennessRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval1 <- MeanNodeBetweennessRemoval1[retain]
head(MeanNodeBetweennessRemoval1)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval1 <- unlist(MeanEdgeBetweennessRemoval1)
MeanEdgeBetweennessRemoval1 <- data.frame(MeanEdgeBetweennessRemoval1)
MeanEdgeBetweennessRemoval1$EdgeBetweenness <- MeanEdgeBetweennessRemoval1[,1]
MeanEdgeBetweennessRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanEdgeBetweennessRemoval1$FP_ID <- ContWetAndPitss@data[1:3387,]$FP_ID
#MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval1 <- MeanEdgeBetweennessRemoval1[retain]
head(MeanEdgeBetweennessRemoval1)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval1 <- unlist(GraphDensityRemoval1)
GraphDensityRemoval1 <- data.frame(GraphDensityRemoval1)
GraphDensityRemoval1$GraphDensity <- GraphDensityRemoval1[,1]
GraphDensityRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
GraphDensityRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#GraphDensityRemoval1 <- GraphDensityRemoval1[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval1 <- GraphDensityRemoval1[retain]
head(GraphDensityRemoval1)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval1 <- unlist(MeanShortPathLengthRemoval1)
MeanShortPathLengthRemoval1 <- data.frame(MeanShortPathLengthRemoval1)
MeanShortPathLengthRemoval1$MeanPathLength <- MeanShortPathLengthRemoval1[,1]
MeanShortPathLengthRemoval1$NodeID <- ContWetsAndPits@data[1:3387,]$NodeID
MeanShortPathLengthRemoval1$FP_ID <- ContWetsAndPits@data[1:3387,]$FP_ID
#MeanShortPathLengthRemoval1 <- MeanShortPathLengthRemoval1[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval1 <- MeanShortPathLengthRemoval1[retain]
head(MeanShortPathLengthRemoval1)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval1, "MeanNodeDegreeRemoval1.csv")
write.csv(MeanNodeBetweennessRemoval1, "MeanNodeBetweennessRemoval1.csv")
write.csv(MeanEdgeBetweennessRemoval1, "MeanEdgeBetweennessRemoval1.csv")
write.csv(GraphDensityRemoval1, "GraphDensityRemoval1.csv")
write.csv(MeanShortPathLengthRemoval1, "MeanShortPathLengthRemoval1.csv")

#####
#####
#####
#part 2
NodeRemove2 <- list(NA)
MeanNodeDegreeRemoval2 <- list(NA)
MeanNodeBetweennessRemoval2 <- list(NA)
MeanEdgeBetweennessRemoval2 <- list(NA)
GraphDensityRemoval2 <- list(NA)
MeanShortPathLengthRemoval2 <- list(NA)
for(i in 1:3387){
	NodeRemove2[[i]] <- HalfKMNetwork
	NodeRemove2[[i]][3387 + i] <- FALSE
	MeanNodeDegreeRemoval2[[i]] <- mean(degree(NodeRemove2[[i]], v = V(NodeRemove2[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval2[[i]] <- mean(betweenness(NodeRemove2[[i]], v = V(NodeRemove2[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval2[[i]] <- mean(edge.betweenness(NodeRemove2[[i]], e = E(NodeRemove2[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval2[[i]] <- graph.density(NodeRemove2[[i]], loops = TRUE)
	MeanShortPathLengthRemoval2[[i]] <- average.path.length(NodeRemove2[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval2 <- unlist(MeanNodeDegreeRemoval2)
MeanNodeDegreeRemoval2 <- data.frame(MeanNodeDegreeRemoval2)
MeanNodeDegreeRemoval2$Degree <- MeanNodeDegreeRemoval2[,1]
MeanNodeDegreeRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanNodeDegreeRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval2 <- MeanNodeDegreeRemoval2[retain]
head(MeanNodeDegreeRemoval2)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval2 <- unlist(MeanNodeBetweennessRemoval2)
MeanNodeBetweennessRemoval2 <- data.frame(MeanNodeBetweennessRemoval2)
MeanNodeBetweennessRemoval2$NodeBetweenness <- MeanNodeBetweennessRemoval2[,1]
MeanNodeBetweennessRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanNodeBetweennessRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval2 <- MeanNodeBetweennessRemoval2[retain]
head(MeanNodeBetweennessRemoval2)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval2 <- unlist(MeanEdgeBetweennessRemoval2)
MeanEdgeBetweennessRemoval2 <- data.frame(MeanEdgeBetweennessRemoval2)
MeanEdgeBetweennessRemoval2$EdgeBetweenness <- MeanEdgeBetweennessRemoval2[,1]
MeanEdgeBetweennessRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanEdgeBetweennessRemoval2$FP_ID <- ContWetAndPitss@data[3388:6774,]$FP_ID
#MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval2 <- MeanEdgeBetweennessRemoval2[retain]
head(MeanEdgeBetweennessRemoval2)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval2 <- unlist(GraphDensityRemoval2)
GraphDensityRemoval2 <- data.frame(GraphDensityRemoval2)
GraphDensityRemoval2$GraphDensity <- GraphDensityRemoval2[,1]
GraphDensityRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
GraphDensityRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#GraphDensityRemoval2 <- GraphDensityRemoval2[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval2 <- GraphDensityRemoval2[retain]
head(GraphDensityRemoval2)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval2 <- unlist(MeanShortPathLengthRemoval2)
MeanShortPathLengthRemoval2 <- data.frame(MeanShortPathLengthRemoval2)
MeanShortPathLengthRemoval2$MeanPathLength <- MeanShortPathLengthRemoval2[,1]
MeanShortPathLengthRemoval2$NodeID <- ContWetsAndPits@data[3388:6774,]$NodeID
MeanShortPathLengthRemoval2$FP_ID <- ContWetsAndPits@data[3388:6774,]$FP_ID
#MeanShortPathLengthRemoval2 <- MeanShortPathLengthRemoval2[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval2 <- MeanShortPathLengthRemoval2[retain]
head(MeanShortPathLengthRemoval2)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval2, "MeanNodeDegreeRemoval2.csv")
write.csv(MeanNodeBetweennessRemoval2, "MeanNodeBetweennessRemoval2.csv")
write.csv(MeanEdgeBetweennessRemoval2, "MeanEdgeBetweennessRemoval2.csv")
write.csv(GraphDensityRemoval2, "GraphDensityRemoval2.csv")
write.csv(MeanShortPathLengthRemoval2, "MeanShortPathLengthRemoval2.csv")

#####
#####
#####
#part 3
NodeRemove3 <- list(NA)
MeanNodeDegreeRemoval3 <- list(NA)
MeanNodeBetweennessRemoval3 <- list(NA)
MeanEdgeBetweennessRemoval3 <- list(NA)
GraphDensityRemoval3 <- list(NA)
MeanShortPathLengthRemoval3 <- list(NA)
for(i in 1:3387){
	NodeRemove3[[i]] <- HalfKMNetwork
	NodeRemove3[[i]][6774 + i] <- FALSE
	MeanNodeDegreeRemoval3[[i]] <- mean(degree(NodeRemove3[[i]], v = V(NodeRemove3[[i]]), loops = TRUE))
	MeanNodeBetweennessRemoval3[[i]] <- mean(betweenness(NodeRemove3[[i]], v = V(NodeRemove3[[i]]), directed = FALSE, weights = NULL, normalized = FALSE))
	MeanEdgeBetweennessRemoval3[[i]] <- mean(edge.betweenness(NodeRemove3[[i]], e = E(NodeRemove3[[i]]), directed = FALSE, weights = NULL))
	GraphDensityRemoval3[[i]] <- graph.density(NodeRemove3[[i]], loops = TRUE)
	MeanShortPathLengthRemoval3[[i]] <- average.path.length(NodeRemove3[[i]], directed = FALSE, unconnected = TRUE)
}

#unlist mean degrees after removing each node
MeanNodeDegreeRemoval3 <- unlist(MeanNodeDegreeRemoval3)
MeanNodeDegreeRemoval3 <- data.frame(MeanNodeDegreeRemoval3)
MeanNodeDegreeRemoval3$Degree <- MeanNodeDegreeRemoval3[,1]
MeanNodeDegreeRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanNodeDegreeRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[,-1]
retain <- c("NodeID", "Degree")
MeanNodeDegreeRemoval3 <- MeanNodeDegreeRemoval3[retain]
head(MeanNodeDegreeRemoval3)

#unlist mean node betweenness after removing and replacing each node sequentially
MeanNodeBetweennessRemoval3 <- unlist(MeanNodeBetweennessRemoval3)
MeanNodeBetweennessRemoval3 <- data.frame(MeanNodeBetweennessRemoval3)
MeanNodeBetweennessRemoval3$NodeBetweenness <- MeanNodeBetweennessRemoval3[,1]
MeanNodeBetweennessRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanNodeBetweennessRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[,-1]
retain <- c("NodeID", "NodeBetweenness")
MeanNodeBetweennessRemoval3 <- MeanNodeBetweennessRemoval3[retain]
head(MeanNodeBetweennessRemoval3)

#unlist mean edge betweenness after removing and replacing each node sequentially
MeanEdgeBetweennessRemoval3 <- unlist(MeanEdgeBetweennessRemoval3)
MeanEdgeBetweennessRemoval3 <- data.frame(MeanEdgeBetweennessRemoval3)
MeanEdgeBetweennessRemoval3$EdgeBetweenness <- MeanEdgeBetweennessRemoval3[,1]
MeanEdgeBetweennessRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanEdgeBetweennessRemoval3$FP_ID <- ContWetAndPitss@data[6775:10161,]$FP_ID
#MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[,-1]
retain <- c("NodeID", "EdgeBetweenness")
MeanEdgeBetweennessRemoval3 <- MeanEdgeBetweennessRemoval3[retain]
head(MeanEdgeBetweennessRemoval3)

#unlist graph density after removing and replacing each node sequentially
GraphDensityRemoval3 <- unlist(GraphDensityRemoval3)
GraphDensityRemoval3 <- data.frame(GraphDensityRemoval3)
GraphDensityRemoval3$GraphDensity <- GraphDensityRemoval3[,1]
GraphDensityRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
GraphDensityRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#GraphDensityRemoval3 <- GraphDensityRemoval3[,-1]
retain <- c("NodeID", "GraphDensity")
GraphDensityRemoval3 <- GraphDensityRemoval3[retain]
head(GraphDensityRemoval3)

#unlist mean shortest path length after removing and replacing each node sequentially
MeanShortPathLengthRemoval3 <- unlist(MeanShortPathLengthRemoval3)
MeanShortPathLengthRemoval3 <- data.frame(MeanShortPathLengthRemoval3)
MeanShortPathLengthRemoval3$MeanPathLength <- MeanShortPathLengthRemoval3[,1]
MeanShortPathLengthRemoval3$NodeID <- ContWetsAndPits@data[6775:10161,]$NodeID
MeanShortPathLengthRemoval3$FP_ID <- ContWetsAndPits@data[6775:10161,]$FP_ID
#MeanShortPathLengthRemoval3 <- MeanShortPathLengthRemoval3[,-1]
retain <- c("NodeID", "MeanPathLength")
MeanShortPathLengthRemoval3 <- MeanShortPathLengthRemoval3[retain]
head(MeanShortPathLengthRemoval3)

#write outputs to csv files for later combination
write.csv(MeanNodeDegreeRemoval3, "MeanNodeDegreeRemoval3.csv")
write.csv(MeanNodeBetweennessRemoval3, "MeanNodeBetweennessRemoval3.csv")
write.csv(MeanEdgeBetweennessRemoval3, "MeanEdgeBetweennessRemoval3.csv")
write.csv(GraphDensityRemoval3, "GraphDensityRemoval3.csv")
write.csv(MeanShortPathLengthRemoval3, "MeanShortPathLengthRemoval3.csv")

#combine output attributes from 3 parts
MeanNodeDegreeRemoval <- rbind(MeanNodeDegreeRemoval1, MeanNodeDegreeRemoval2, MeanNodeDegreeRemoval3)
MeanNodeBetweennessRemoval <- rbind(MeanNodeBetweennessRemoval1, MeanNodeBetweennessRemoval2, MeanNodeBetweennessRemoval3)
MeanEdgeBetweennessRemoval <- rbind(MeanEdgeBetweennessRemoval1, MeanEdgeBetweennessRemoval2, MeanEdgeBetweennessRemoval3)
GraphDensityRemoval <- rbind(GraphDensityRemoval1, GraphDensityRemoval2, GraphDensityRemoval3)
MeanShortPathLengthRemoval <- rbind(MeanShortPathLengthRemoval1, MeanShortPathLengthRemoval2, MeanShortPathLengthRemoval3)

#read in updated contemporary wetlands and pits shapefile
ContWetsAndPits <- readOGR("ContWetsAndPitsTwoKMNetwork1.shp", "ContWetsAndPitsTwoKMNetwork1", verbose = TRUE, p4s = NULL)

#add new outputs to attribute table
ContWetsAndPits@data$Degree <- DegreeOneKMNetwork
ContWetsAndPits@data$NodeBetween <- OneKMNodeBetweenness
ContWetsAndPits@data$RemDeg <- MeanNodeDegreeRemoval$Degree
ContWetsAndPits@data$RemNodeBetween <- MeanNodeBetweennessRemoval$NodeBetweenness
ContWetsAndPits@data$RemEdgeBetween <- MeanEdgeBetweennessRemoval$EdgeBetweenness
ContWetsAndPits@data$RemGraphDenity <- GraphDensityRemoval$GraphDensity
ContWetsAndPits@data$RemShortPath <- MeanShortPathLengthRemoval$MeanPathLength

#write updated spatial polygons data frame as an ESRI shapefile
writeOGR(ContWetsAndPits, "ContWetsAndPitsTwoKMNetwork2", "ContWetsAndPitsTwoKMNetwork2", driver = 'ESRI Shapefile', verbose = TRUE)
